# Changelog

## 0.1.0-alpha.39 (2024-09-13)

Full Changelog: [v0.1.0-alpha.38...v0.1.0-alpha.39](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.38...v0.1.0-alpha.39)

### Features

* datasetbuilder ([a5e1add](https://github.com/scaleapi/sgp-python/commit/a5e1addf6bab476d6ab1658a171b617b3cfc907b))

## 0.1.0-alpha.38 (2024-09-13)

Full Changelog: [v0.1.0-alpha.37...v0.1.0-alpha.38](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.37...v0.1.0-alpha.38)

### Features

* **api:** manual updates ([#1416](https://github.com/scaleapi/sgp-python/issues/1416)) ([4b9d368](https://github.com/scaleapi/sgp-python/commit/4b9d36893a33075e792bd640a7fdb65c3885424a))
* **api:** OpenAPI spec update via Stainless API ([#1419](https://github.com/scaleapi/sgp-python/issues/1419)) ([ff8e528](https://github.com/scaleapi/sgp-python/commit/ff8e528e2595ad0684e425db1029c8cf7f888417))
* datasetbuilder ([7901a6f](https://github.com/scaleapi/sgp-python/commit/7901a6f610564daf8b467f1c34b43a8e3f906cf2))

## 0.1.0-alpha.37 (2024-09-13)

Full Changelog: [v0.1.0-alpha.36...v0.1.0-alpha.37](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.36...v0.1.0-alpha.37)

### Features

* **api:** OpenAPI spec update via Stainless API ([#1411](https://github.com/scaleapi/sgp-python/issues/1411)) ([bd5f1c1](https://github.com/scaleapi/sgp-python/commit/bd5f1c1b2ede5245c3abc54597c20b211a08f9db))
* **api:** OpenAPI spec update via Stainless API ([#1412](https://github.com/scaleapi/sgp-python/issues/1412)) ([2b060e1](https://github.com/scaleapi/sgp-python/commit/2b060e168587706f9d3fb33667f80f535e39bfdc))
* **api:** OpenAPI spec update via Stainless API ([#1413](https://github.com/scaleapi/sgp-python/issues/1413)) ([7bcd313](https://github.com/scaleapi/sgp-python/commit/7bcd313101258fcf4f29c04ff18e38fe89c88b9b))


### Bug Fixes

* **types:** correctly mark stream discriminator as optional ([#1409](https://github.com/scaleapi/sgp-python/issues/1409)) ([708cf45](https://github.com/scaleapi/sgp-python/commit/708cf45bd700d6fff48cc54d0db5cfcec3cde99e))


### Documentation

* update CONTRIBUTING.md ([#1414](https://github.com/scaleapi/sgp-python/issues/1414)) ([a08bfe6](https://github.com/scaleapi/sgp-python/commit/a08bfe630b5ae321c09e4a85998e8ed26f4b08a7))

## 0.1.0-alpha.36 (2024-09-12)

Full Changelog: [v0.1.0-alpha.35...v0.1.0-alpha.36](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.35...v0.1.0-alpha.36)

### Features

* **api:** manual updates ([#1405](https://github.com/scaleapi/sgp-python/issues/1405)) ([5bed280](https://github.com/scaleapi/sgp-python/commit/5bed280d88c74e2d73c8def0906a0525f0667c02))

## 0.1.0-alpha.35 (2024-09-12)

Full Changelog: [v0.1.0-alpha.34...v0.1.0-alpha.35](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.34...v0.1.0-alpha.35)

### Features

* **api:** manual updates ([#1402](https://github.com/scaleapi/sgp-python/issues/1402)) ([a78093c](https://github.com/scaleapi/sgp-python/commit/a78093cc49526e8c3859ee08e58f0c1ecab1e15f))

## 0.1.0-alpha.34 (2024-09-12)

Full Changelog: [v0.1.0-alpha.33...v0.1.0-alpha.34](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.33...v0.1.0-alpha.34)

### Features

* **api:** manual updates ([#1399](https://github.com/scaleapi/sgp-python/issues/1399)) ([a116aa4](https://github.com/scaleapi/sgp-python/commit/a116aa4917a1a902a9215ac973b5ff31e12dcb63))
* **api:** manual updates ([#1400](https://github.com/scaleapi/sgp-python/issues/1400)) ([ec26e29](https://github.com/scaleapi/sgp-python/commit/ec26e29ee02d852dbc55e009651bf87601934038))
* **api:** OpenAPI spec update via Stainless API ([#1393](https://github.com/scaleapi/sgp-python/issues/1393)) ([ce7e829](https://github.com/scaleapi/sgp-python/commit/ce7e8293296135eb591d44d53cbc1f6fceb1c8f1))
* **api:** OpenAPI spec update via Stainless API ([#1394](https://github.com/scaleapi/sgp-python/issues/1394)) ([9e70926](https://github.com/scaleapi/sgp-python/commit/9e70926e33afc459af9d74d879c43522938d5888))
* **api:** OpenAPI spec update via Stainless API ([#1396](https://github.com/scaleapi/sgp-python/issues/1396)) ([e0bab39](https://github.com/scaleapi/sgp-python/commit/e0bab39c20c2c5c1ef69204e3430aa4b908bd7e9))
* **api:** OpenAPI spec update via Stainless API ([#1398](https://github.com/scaleapi/sgp-python/issues/1398)) ([ea54876](https://github.com/scaleapi/sgp-python/commit/ea548765f7390b1602594d95f667d189d423799d))


### Bug Fixes

* change `ExternalApplication` output types from `BaseModel` to `TypedDict` ([50516c2](https://github.com/scaleapi/sgp-python/commit/50516c24aaf2e8ba46ed9e0b9fe4d272cbb05cab))


### Chores

* **internal:** testing updates ([#1395](https://github.com/scaleapi/sgp-python/issues/1395)) ([ee2077f](https://github.com/scaleapi/sgp-python/commit/ee2077f33ac8883269ef36bbff4f5872b6bf810f))

## 0.1.0-alpha.33 (2024-09-09)

Full Changelog: [v0.1.0-alpha.32...v0.1.0-alpha.33](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.32...v0.1.0-alpha.33)

### Features

* fix ([3e4bcce](https://github.com/scaleapi/sgp-python/commit/3e4bcce314b718b96a19600e899635bd7d21ab2d))
* lint ([8568615](https://github.com/scaleapi/sgp-python/commit/8568615c58bb7528b62d458fb795a021747cb65f))


### Chores

* add docstrings to raw response properties ([#1386](https://github.com/scaleapi/sgp-python/issues/1386)) ([81ae8b8](https://github.com/scaleapi/sgp-python/commit/81ae8b846df2f71209ef4eec756360acac8eeaed))


### Documentation

* **readme:** add section on determining installed version ([#1387](https://github.com/scaleapi/sgp-python/issues/1387)) ([27e6ea9](https://github.com/scaleapi/sgp-python/commit/27e6ea99d5bb061b4b2f17654a906451bed91f71))

## 0.1.0-alpha.32 (2024-09-09)

Full Changelog: [v0.1.0-alpha.31...v0.1.0-alpha.32](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.31...v0.1.0-alpha.32)

### Features

* **api:** manual updates ([#1380](https://github.com/scaleapi/sgp-python/issues/1380)) ([b18f335](https://github.com/scaleapi/sgp-python/commit/b18f3359395087375fa06453d5b5e99812ca0b1e))
* **api:** OpenAPI spec update via Stainless API ([#1382](https://github.com/scaleapi/sgp-python/issues/1382)) ([1fe04a9](https://github.com/scaleapi/sgp-python/commit/1fe04a9d195e478a3cc83d07b014355bb26fd750))

## 0.1.0-alpha.31 (2024-09-04)

Full Changelog: [v0.1.0-alpha.30...v0.1.0-alpha.31](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.30...v0.1.0-alpha.31)

### Features

* **api:** manual updates ([#1375](https://github.com/scaleapi/sgp-python/issues/1375)) ([5634603](https://github.com/scaleapi/sgp-python/commit/5634603c7c83592a8a1370dbc569afa1777eab02))

## 0.1.0-alpha.30 (2024-09-04)

Full Changelog: [v0.1.0-alpha.29...v0.1.0-alpha.30](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.29...v0.1.0-alpha.30)

### Features

* Add optional `metrics` and `trace_spans` to ExternalApplication outputs ([1a8ef69](https://github.com/scaleapi/sgp-python/commit/1a8ef691a69cbd4c5f3570136ff0187645881168))
* **api:** Config update for anishxyz/dev ([#1363](https://github.com/scaleapi/sgp-python/issues/1363)) ([d100efe](https://github.com/scaleapi/sgp-python/commit/d100efe7fa296d3ea1103d58e7983bc3d32868d8))
* **api:** manual updates ([#1359](https://github.com/scaleapi/sgp-python/issues/1359)) ([79adfc9](https://github.com/scaleapi/sgp-python/commit/79adfc9b6086a931780495d33acb057f4f3d9176))
* **api:** manual updates ([#1360](https://github.com/scaleapi/sgp-python/issues/1360)) ([de7b961](https://github.com/scaleapi/sgp-python/commit/de7b961a2f0a49b4eaa18485ecee05156a7de94e))
* **api:** manual updates ([#1373](https://github.com/scaleapi/sgp-python/issues/1373)) ([c0b7322](https://github.com/scaleapi/sgp-python/commit/c0b7322be444cfa111b3e86b9e259e5ef3c6d9da))
* **api:** OpenAPI spec update via Stainless API ([a3e6cda](https://github.com/scaleapi/sgp-python/commit/a3e6cda39b1000d2d68c5183e5e4d8f759ddf284))
* **api:** OpenAPI spec update via Stainless API ([b4663b8](https://github.com/scaleapi/sgp-python/commit/b4663b85e5c91c79590324b01a8fa9b09b910cca))
* **api:** OpenAPI spec update via Stainless API ([9663c1e](https://github.com/scaleapi/sgp-python/commit/9663c1e818b85039461bdb6d30cd955afc20d944))
* **api:** OpenAPI spec update via Stainless API ([614caf8](https://github.com/scaleapi/sgp-python/commit/614caf8798061090964a6a88194daa359e6cceff))
* **api:** OpenAPI spec update via Stainless API ([9d7e936](https://github.com/scaleapi/sgp-python/commit/9d7e93633f572f76aa93ed923dd547957b747292))
* **api:** OpenAPI spec update via Stainless API ([046efbc](https://github.com/scaleapi/sgp-python/commit/046efbca087be2d659485a4cc6874295df10976a))
* **api:** OpenAPI spec update via Stainless API ([59ad060](https://github.com/scaleapi/sgp-python/commit/59ad060c3588feb293bfe3ab0253c083aaf0d5af))
* **api:** OpenAPI spec update via Stainless API ([a1b4ba3](https://github.com/scaleapi/sgp-python/commit/a1b4ba373092762f1515dd92f867585b6eb3886c))
* **api:** OpenAPI spec update via Stainless API ([359bae0](https://github.com/scaleapi/sgp-python/commit/359bae0bf4621da5da2b91d309cdeda0cefc4681))
* **api:** OpenAPI spec update via Stainless API ([ea05aa6](https://github.com/scaleapi/sgp-python/commit/ea05aa68d8aee3578727ab363aec155bfeee1afa))
* **api:** OpenAPI spec update via Stainless API ([f67249d](https://github.com/scaleapi/sgp-python/commit/f67249d775b891cc8760cb781c4c90ae04961a82))
* **api:** OpenAPI spec update via Stainless API ([ffada72](https://github.com/scaleapi/sgp-python/commit/ffada72d5b96e27177665c753acf03aabb686305))
* **api:** OpenAPI spec update via Stainless API ([0f5c5f4](https://github.com/scaleapi/sgp-python/commit/0f5c5f49ad9b0d9c4c3e7e7091c6d9746e89bc4c))
* **api:** OpenAPI spec update via Stainless API ([e3e60a8](https://github.com/scaleapi/sgp-python/commit/e3e60a870b14df5f34a6b5021020ef311ab64bcf))
* **api:** OpenAPI spec update via Stainless API ([7d2cd8d](https://github.com/scaleapi/sgp-python/commit/7d2cd8d531653616d6131f9d8db23715fb8eadb2))
* **api:** OpenAPI spec update via Stainless API ([0a49854](https://github.com/scaleapi/sgp-python/commit/0a4985430d37471b4c6690ae900fe1fe51ee1640))
* **api:** OpenAPI spec update via Stainless API ([48f8f56](https://github.com/scaleapi/sgp-python/commit/48f8f5669b9bcbbbf2992b39abdbc6023c323ec4))
* **api:** OpenAPI spec update via Stainless API ([ea7e8a7](https://github.com/scaleapi/sgp-python/commit/ea7e8a74faa7c1d72375de10cc25c486cadfe9da))
* **api:** OpenAPI spec update via Stainless API ([2fb5d76](https://github.com/scaleapi/sgp-python/commit/2fb5d763f08d681d0faf19245a36650ca118647a))
* **api:** OpenAPI spec update via Stainless API ([4fc67c6](https://github.com/scaleapi/sgp-python/commit/4fc67c637b242b8602adb1eadcfa7d10ef49fb75))
* **api:** OpenAPI spec update via Stainless API ([f3925bb](https://github.com/scaleapi/sgp-python/commit/f3925bbf24d0c58b71803e2f6fb9d4ae427cfb14))
* **api:** OpenAPI spec update via Stainless API ([77cc6be](https://github.com/scaleapi/sgp-python/commit/77cc6bef2ca140048564c1e0cadd50aa4dc14983))
* **api:** OpenAPI spec update via Stainless API ([#1209](https://github.com/scaleapi/sgp-python/issues/1209)) ([31f49b3](https://github.com/scaleapi/sgp-python/commit/31f49b31741f28f6bc1deb7ef1814b21a07f7af5))
* **api:** OpenAPI spec update via Stainless API ([#1210](https://github.com/scaleapi/sgp-python/issues/1210)) ([5c4899b](https://github.com/scaleapi/sgp-python/commit/5c4899b87687c2893d9db436242cc20494846615))
* **api:** OpenAPI spec update via Stainless API ([#1211](https://github.com/scaleapi/sgp-python/issues/1211)) ([3804908](https://github.com/scaleapi/sgp-python/commit/380490878219c36fffa9d6cb1b79de1a46aba421))
* **api:** OpenAPI spec update via Stainless API ([#1212](https://github.com/scaleapi/sgp-python/issues/1212)) ([41742d9](https://github.com/scaleapi/sgp-python/commit/41742d9985e3aba72bbe4c416cdff42d3ba3d7c3))
* **api:** OpenAPI spec update via Stainless API ([#1213](https://github.com/scaleapi/sgp-python/issues/1213)) ([defb0f1](https://github.com/scaleapi/sgp-python/commit/defb0f1a403b1ddc42bb6015cc3e3ff853205981))
* **api:** OpenAPI spec update via Stainless API ([#1214](https://github.com/scaleapi/sgp-python/issues/1214)) ([4aa129a](https://github.com/scaleapi/sgp-python/commit/4aa129a4782aa7ec3ecc50ec75988776b94effea))
* **api:** OpenAPI spec update via Stainless API ([#1215](https://github.com/scaleapi/sgp-python/issues/1215)) ([8f4ad16](https://github.com/scaleapi/sgp-python/commit/8f4ad16075ab48dd9d072d8dbbf14029d44fde8e))
* **api:** OpenAPI spec update via Stainless API ([#1216](https://github.com/scaleapi/sgp-python/issues/1216)) ([87cac37](https://github.com/scaleapi/sgp-python/commit/87cac371662abbca70969ffdfd5819fc96fe45ee))
* **api:** OpenAPI spec update via Stainless API ([#1217](https://github.com/scaleapi/sgp-python/issues/1217)) ([8097bb7](https://github.com/scaleapi/sgp-python/commit/8097bb7e91d6a4808bc651a2ebaab5dcb492be39))
* **api:** OpenAPI spec update via Stainless API ([#1218](https://github.com/scaleapi/sgp-python/issues/1218)) ([76ea47a](https://github.com/scaleapi/sgp-python/commit/76ea47a08845e11f5d5aa0529b16c53162cc3a51))
* **api:** OpenAPI spec update via Stainless API ([#1219](https://github.com/scaleapi/sgp-python/issues/1219)) ([bc5e926](https://github.com/scaleapi/sgp-python/commit/bc5e926266e422767dbe5722d3a3b7c9728b0b90))
* **api:** OpenAPI spec update via Stainless API ([#1220](https://github.com/scaleapi/sgp-python/issues/1220)) ([f89b9ec](https://github.com/scaleapi/sgp-python/commit/f89b9ecfb923a78ed467332c4acb22f3e8ff0b57))
* **api:** OpenAPI spec update via Stainless API ([#1221](https://github.com/scaleapi/sgp-python/issues/1221)) ([b6fce75](https://github.com/scaleapi/sgp-python/commit/b6fce756b50a766a313fe2555d95ea4ca80a68d7))
* **api:** OpenAPI spec update via Stainless API ([#1222](https://github.com/scaleapi/sgp-python/issues/1222)) ([994ad18](https://github.com/scaleapi/sgp-python/commit/994ad18e3522c3fb06eab7c75c6ebd9eef24bfd4))
* **api:** OpenAPI spec update via Stainless API ([#1223](https://github.com/scaleapi/sgp-python/issues/1223)) ([81082c0](https://github.com/scaleapi/sgp-python/commit/81082c0559106ad6ce49ebd29cb1b3229f620641))
* **api:** OpenAPI spec update via Stainless API ([#1224](https://github.com/scaleapi/sgp-python/issues/1224)) ([18cabbc](https://github.com/scaleapi/sgp-python/commit/18cabbc37765605d5fec76f53273f7b48fa6fe95))
* **api:** OpenAPI spec update via Stainless API ([#1225](https://github.com/scaleapi/sgp-python/issues/1225)) ([7b3fdae](https://github.com/scaleapi/sgp-python/commit/7b3fdaec8f5f154f6e9fe92e76eea5eb1e48fb12))
* **api:** OpenAPI spec update via Stainless API ([#1226](https://github.com/scaleapi/sgp-python/issues/1226)) ([1b1731c](https://github.com/scaleapi/sgp-python/commit/1b1731cefa15d582f57992b8c6262c8e05503511))
* **api:** OpenAPI spec update via Stainless API ([#1227](https://github.com/scaleapi/sgp-python/issues/1227)) ([994cfff](https://github.com/scaleapi/sgp-python/commit/994cfffb0f45e7c181c3ccdf635ed2e3517b6b38))
* **api:** OpenAPI spec update via Stainless API ([#1228](https://github.com/scaleapi/sgp-python/issues/1228)) ([45d0325](https://github.com/scaleapi/sgp-python/commit/45d0325f01025acb0135728d74fddd6fc0ab8560))
* **api:** OpenAPI spec update via Stainless API ([#1229](https://github.com/scaleapi/sgp-python/issues/1229)) ([8f49fdd](https://github.com/scaleapi/sgp-python/commit/8f49fdd500bc0492ec7d742ae2f86dd55f53cc7a))
* **api:** OpenAPI spec update via Stainless API ([#1230](https://github.com/scaleapi/sgp-python/issues/1230)) ([4e74563](https://github.com/scaleapi/sgp-python/commit/4e74563efe1a8e16abc6ac9c49b723835ca30ff4))
* **api:** OpenAPI spec update via Stainless API ([#1231](https://github.com/scaleapi/sgp-python/issues/1231)) ([fab69ca](https://github.com/scaleapi/sgp-python/commit/fab69cacdcd3ec44db009cdcab393877e66ab84b))
* **api:** OpenAPI spec update via Stainless API ([#1232](https://github.com/scaleapi/sgp-python/issues/1232)) ([49d7a3a](https://github.com/scaleapi/sgp-python/commit/49d7a3ad466de4eb563ee9dc5174ba5cec84a33d))
* **api:** OpenAPI spec update via Stainless API ([#1233](https://github.com/scaleapi/sgp-python/issues/1233)) ([2615cf9](https://github.com/scaleapi/sgp-python/commit/2615cf926365efd3c8286751d4c1e7326b518b3f))
* **api:** OpenAPI spec update via Stainless API ([#1234](https://github.com/scaleapi/sgp-python/issues/1234)) ([7480aff](https://github.com/scaleapi/sgp-python/commit/7480affe80bfe9c90d9aac93fae0570018e96716))
* **api:** OpenAPI spec update via Stainless API ([#1235](https://github.com/scaleapi/sgp-python/issues/1235)) ([03a7886](https://github.com/scaleapi/sgp-python/commit/03a7886f9de8fbe1b228ddfb0f58f954bfa7523c))
* **api:** OpenAPI spec update via Stainless API ([#1236](https://github.com/scaleapi/sgp-python/issues/1236)) ([66bd922](https://github.com/scaleapi/sgp-python/commit/66bd922accf802bab30fb54fe6d9d977cfcff569))
* **api:** OpenAPI spec update via Stainless API ([#1237](https://github.com/scaleapi/sgp-python/issues/1237)) ([37d1d34](https://github.com/scaleapi/sgp-python/commit/37d1d34fef5600b931995d93df2b68310f6744b9))
* **api:** OpenAPI spec update via Stainless API ([#1238](https://github.com/scaleapi/sgp-python/issues/1238)) ([d9fea21](https://github.com/scaleapi/sgp-python/commit/d9fea211d3aa5f16b2902df19c4e0a82f73f7c81))
* **api:** OpenAPI spec update via Stainless API ([#1239](https://github.com/scaleapi/sgp-python/issues/1239)) ([f115e09](https://github.com/scaleapi/sgp-python/commit/f115e09028c2463b4934736a73f38e8a7bcaff32))
* **api:** OpenAPI spec update via Stainless API ([#1240](https://github.com/scaleapi/sgp-python/issues/1240)) ([83383af](https://github.com/scaleapi/sgp-python/commit/83383afae968d774211afc866b2e4f4e9c848c28))
* **api:** OpenAPI spec update via Stainless API ([#1241](https://github.com/scaleapi/sgp-python/issues/1241)) ([854cefa](https://github.com/scaleapi/sgp-python/commit/854cefa1f461c96052a87ab1df5abd70977816dc))
* **api:** OpenAPI spec update via Stainless API ([#1242](https://github.com/scaleapi/sgp-python/issues/1242)) ([806df75](https://github.com/scaleapi/sgp-python/commit/806df750e24067a1255af4ddf2a4bb1a9fd561ce))
* **api:** OpenAPI spec update via Stainless API ([#1243](https://github.com/scaleapi/sgp-python/issues/1243)) ([bf6ef91](https://github.com/scaleapi/sgp-python/commit/bf6ef91ad816eb42e8146671702e856349a13dca))
* **api:** OpenAPI spec update via Stainless API ([#1244](https://github.com/scaleapi/sgp-python/issues/1244)) ([46771e6](https://github.com/scaleapi/sgp-python/commit/46771e690bd7c68ce6434541f0821dc33c50536f))
* **api:** OpenAPI spec update via Stainless API ([#1245](https://github.com/scaleapi/sgp-python/issues/1245)) ([7d71cf6](https://github.com/scaleapi/sgp-python/commit/7d71cf6fdfda4bc706c87cb027f61d37cf816074))
* **api:** OpenAPI spec update via Stainless API ([#1246](https://github.com/scaleapi/sgp-python/issues/1246)) ([83812b7](https://github.com/scaleapi/sgp-python/commit/83812b7ca067875949ad8d858befd698111f44b7))
* **api:** OpenAPI spec update via Stainless API ([#1247](https://github.com/scaleapi/sgp-python/issues/1247)) ([bb0c678](https://github.com/scaleapi/sgp-python/commit/bb0c678d517b372f7b844506d01b55b7d093b50a))
* **api:** OpenAPI spec update via Stainless API ([#1248](https://github.com/scaleapi/sgp-python/issues/1248)) ([eca15a3](https://github.com/scaleapi/sgp-python/commit/eca15a3e8cd46c6a1c306a26f66339428ca9fc96))
* **api:** OpenAPI spec update via Stainless API ([#1249](https://github.com/scaleapi/sgp-python/issues/1249)) ([8b82cb4](https://github.com/scaleapi/sgp-python/commit/8b82cb4b7494e0ed88e3858065d6934b6607b06b))
* **api:** OpenAPI spec update via Stainless API ([#1250](https://github.com/scaleapi/sgp-python/issues/1250)) ([55d8ef3](https://github.com/scaleapi/sgp-python/commit/55d8ef3270aa5db30891ffb83ae74bee738f6aaa))
* **api:** OpenAPI spec update via Stainless API ([#1251](https://github.com/scaleapi/sgp-python/issues/1251)) ([0f0d6f9](https://github.com/scaleapi/sgp-python/commit/0f0d6f9e870914ee057661f0ef097f48d5c102e3))
* **api:** OpenAPI spec update via Stainless API ([#1252](https://github.com/scaleapi/sgp-python/issues/1252)) ([5bf5d9f](https://github.com/scaleapi/sgp-python/commit/5bf5d9f2ebb5c7a90ed9572397a6537f839fa041))
* **api:** OpenAPI spec update via Stainless API ([#1253](https://github.com/scaleapi/sgp-python/issues/1253)) ([8a30518](https://github.com/scaleapi/sgp-python/commit/8a30518153343015480ac8fbd879621c345ea557))
* **api:** OpenAPI spec update via Stainless API ([#1254](https://github.com/scaleapi/sgp-python/issues/1254)) ([55df1dd](https://github.com/scaleapi/sgp-python/commit/55df1dd5a6f86cebce9e4eec3422a1088d06eb30))
* **api:** OpenAPI spec update via Stainless API ([#1255](https://github.com/scaleapi/sgp-python/issues/1255)) ([37d798f](https://github.com/scaleapi/sgp-python/commit/37d798fbec152ea92efa62bd7e153182cf938b69))
* **api:** OpenAPI spec update via Stainless API ([#1256](https://github.com/scaleapi/sgp-python/issues/1256)) ([d4819e9](https://github.com/scaleapi/sgp-python/commit/d4819e92706ff650c59219a05627dec5ec991c5c))
* **api:** OpenAPI spec update via Stainless API ([#1257](https://github.com/scaleapi/sgp-python/issues/1257)) ([7b2128c](https://github.com/scaleapi/sgp-python/commit/7b2128ca29800e17a00a2a8c8d553ac57394ec1a))
* **api:** OpenAPI spec update via Stainless API ([#1258](https://github.com/scaleapi/sgp-python/issues/1258)) ([bb054d0](https://github.com/scaleapi/sgp-python/commit/bb054d035b5d5bf5d18e01e18e500c26129995f9))
* **api:** OpenAPI spec update via Stainless API ([#1259](https://github.com/scaleapi/sgp-python/issues/1259)) ([a728a5d](https://github.com/scaleapi/sgp-python/commit/a728a5dab9795890def5748fb224b5d39e3212d3))
* **api:** OpenAPI spec update via Stainless API ([#1260](https://github.com/scaleapi/sgp-python/issues/1260)) ([f47e3a5](https://github.com/scaleapi/sgp-python/commit/f47e3a5efa2852cad3cacbde314ab90e4bab7934))
* **api:** OpenAPI spec update via Stainless API ([#1261](https://github.com/scaleapi/sgp-python/issues/1261)) ([4389187](https://github.com/scaleapi/sgp-python/commit/43891877f8b9a06d983053e011c878e392fbcb50))
* **api:** OpenAPI spec update via Stainless API ([#1262](https://github.com/scaleapi/sgp-python/issues/1262)) ([52f1d13](https://github.com/scaleapi/sgp-python/commit/52f1d13a5160f700aa0742851c8986b97b846fd9))
* **api:** OpenAPI spec update via Stainless API ([#1263](https://github.com/scaleapi/sgp-python/issues/1263)) ([022e8b5](https://github.com/scaleapi/sgp-python/commit/022e8b574636afaaa1923039e56ac9d08d05d87a))
* **api:** OpenAPI spec update via Stainless API ([#1264](https://github.com/scaleapi/sgp-python/issues/1264)) ([63aef4e](https://github.com/scaleapi/sgp-python/commit/63aef4e36ab687b96060499390cb6016cad80e76))
* **api:** OpenAPI spec update via Stainless API ([#1265](https://github.com/scaleapi/sgp-python/issues/1265)) ([2e6c82f](https://github.com/scaleapi/sgp-python/commit/2e6c82f182de9a74b78f17555965af9f26c7b849))
* **api:** OpenAPI spec update via Stainless API ([#1266](https://github.com/scaleapi/sgp-python/issues/1266)) ([1674f63](https://github.com/scaleapi/sgp-python/commit/1674f63cf2a68806430ff6e51f718db33b7cb067))
* **api:** OpenAPI spec update via Stainless API ([#1267](https://github.com/scaleapi/sgp-python/issues/1267)) ([ab16786](https://github.com/scaleapi/sgp-python/commit/ab167861c18690eba89439fa2b77b30a382cae85))
* **api:** OpenAPI spec update via Stainless API ([#1268](https://github.com/scaleapi/sgp-python/issues/1268)) ([61ac892](https://github.com/scaleapi/sgp-python/commit/61ac8921e31d9e645937fba837456f94711e71ed))
* **api:** OpenAPI spec update via Stainless API ([#1269](https://github.com/scaleapi/sgp-python/issues/1269)) ([f25f063](https://github.com/scaleapi/sgp-python/commit/f25f063e1dfb57735378b8549edb8542f6bee8b7))
* **api:** OpenAPI spec update via Stainless API ([#1270](https://github.com/scaleapi/sgp-python/issues/1270)) ([0da9c75](https://github.com/scaleapi/sgp-python/commit/0da9c75d456677668204fecd10f71053cfdb8ae9))
* **api:** OpenAPI spec update via Stainless API ([#1271](https://github.com/scaleapi/sgp-python/issues/1271)) ([ae4a78c](https://github.com/scaleapi/sgp-python/commit/ae4a78cd6cef99ecfec452d2799a95f684799db5))
* **api:** OpenAPI spec update via Stainless API ([#1272](https://github.com/scaleapi/sgp-python/issues/1272)) ([3c60c7a](https://github.com/scaleapi/sgp-python/commit/3c60c7aa83f9ce49dd68100ed83caf321a0127d1))
* **api:** OpenAPI spec update via Stainless API ([#1273](https://github.com/scaleapi/sgp-python/issues/1273)) ([b749b93](https://github.com/scaleapi/sgp-python/commit/b749b93aebd9d8c811dcc997ed9e146a601ad47e))
* **api:** OpenAPI spec update via Stainless API ([#1274](https://github.com/scaleapi/sgp-python/issues/1274)) ([1c81c59](https://github.com/scaleapi/sgp-python/commit/1c81c599c63b4fcd68ebc0c9fc01821a043c18a8))
* **api:** OpenAPI spec update via Stainless API ([#1275](https://github.com/scaleapi/sgp-python/issues/1275)) ([9808986](https://github.com/scaleapi/sgp-python/commit/9808986b101086935a2b61133882e22e0d5c1eac))
* **api:** OpenAPI spec update via Stainless API ([#1276](https://github.com/scaleapi/sgp-python/issues/1276)) ([5d1d5d4](https://github.com/scaleapi/sgp-python/commit/5d1d5d4e1f9c1c5c2c219e11e88f65aa28b55d3e))
* **api:** OpenAPI spec update via Stainless API ([#1277](https://github.com/scaleapi/sgp-python/issues/1277)) ([b03341b](https://github.com/scaleapi/sgp-python/commit/b03341bacb32be0da5a176b75846431e6b9104e4))
* **api:** OpenAPI spec update via Stainless API ([#1278](https://github.com/scaleapi/sgp-python/issues/1278)) ([ccdbdb4](https://github.com/scaleapi/sgp-python/commit/ccdbdb423eb7edcb20ba44a5782a91ad5e70ffc4))
* **api:** OpenAPI spec update via Stainless API ([#1279](https://github.com/scaleapi/sgp-python/issues/1279)) ([8bab7d5](https://github.com/scaleapi/sgp-python/commit/8bab7d5fe89966c4be4e541145e8b81350c74ec1))
* **api:** OpenAPI spec update via Stainless API ([#1280](https://github.com/scaleapi/sgp-python/issues/1280)) ([9c2c594](https://github.com/scaleapi/sgp-python/commit/9c2c594637a1c55ae979fe56af4047d48b520212))
* **api:** OpenAPI spec update via Stainless API ([#1281](https://github.com/scaleapi/sgp-python/issues/1281)) ([7f16b73](https://github.com/scaleapi/sgp-python/commit/7f16b7305dfc7d966b5814958b92b7ebad013112))
* **api:** OpenAPI spec update via Stainless API ([#1282](https://github.com/scaleapi/sgp-python/issues/1282)) ([17ea0dc](https://github.com/scaleapi/sgp-python/commit/17ea0dc233c015101140a14fe1bf1a7017b2938f))
* **api:** OpenAPI spec update via Stainless API ([#1283](https://github.com/scaleapi/sgp-python/issues/1283)) ([6b0aecb](https://github.com/scaleapi/sgp-python/commit/6b0aecbf097e858d96188853bd3e63e908f50904))
* **api:** OpenAPI spec update via Stainless API ([#1284](https://github.com/scaleapi/sgp-python/issues/1284)) ([f2f14f4](https://github.com/scaleapi/sgp-python/commit/f2f14f4f521db17faac997386e6849da65552051))
* **api:** OpenAPI spec update via Stainless API ([#1285](https://github.com/scaleapi/sgp-python/issues/1285)) ([cc82c29](https://github.com/scaleapi/sgp-python/commit/cc82c2964c5f2249cb45a07188785dc26080dbc7))
* **api:** OpenAPI spec update via Stainless API ([#1286](https://github.com/scaleapi/sgp-python/issues/1286)) ([ac01ee4](https://github.com/scaleapi/sgp-python/commit/ac01ee46b43e125e5d9a7322ac1bcbd89ccc2681))
* **api:** OpenAPI spec update via Stainless API ([#1287](https://github.com/scaleapi/sgp-python/issues/1287)) ([0771871](https://github.com/scaleapi/sgp-python/commit/0771871460d37efbf5ca2fc615db22c82468d251))
* **api:** OpenAPI spec update via Stainless API ([#1288](https://github.com/scaleapi/sgp-python/issues/1288)) ([e36a5fa](https://github.com/scaleapi/sgp-python/commit/e36a5faee3beefbb07bc0a0ff2fa583413654bbf))
* **api:** OpenAPI spec update via Stainless API ([#1290](https://github.com/scaleapi/sgp-python/issues/1290)) ([8267285](https://github.com/scaleapi/sgp-python/commit/826728542f0d8b235e1a8f3a9c6cc846afc5b38f))
* **api:** OpenAPI spec update via Stainless API ([#1291](https://github.com/scaleapi/sgp-python/issues/1291)) ([90b3ba5](https://github.com/scaleapi/sgp-python/commit/90b3ba54514c64d85db5f8f2fab30c8cb949c7da))
* **api:** OpenAPI spec update via Stainless API ([#1292](https://github.com/scaleapi/sgp-python/issues/1292)) ([25906f2](https://github.com/scaleapi/sgp-python/commit/25906f28b28fe212e9356291d4c6ad16cddb83d9))
* **api:** OpenAPI spec update via Stainless API ([#1293](https://github.com/scaleapi/sgp-python/issues/1293)) ([330db5f](https://github.com/scaleapi/sgp-python/commit/330db5fdcd1e140d6bdf0818124a6a4b85b180ed))
* **api:** OpenAPI spec update via Stainless API ([#1294](https://github.com/scaleapi/sgp-python/issues/1294)) ([ce1eb0e](https://github.com/scaleapi/sgp-python/commit/ce1eb0e9c83ba10d3f695bfdb2b357b1e3ea6d2a))
* **api:** OpenAPI spec update via Stainless API ([#1295](https://github.com/scaleapi/sgp-python/issues/1295)) ([f2c7402](https://github.com/scaleapi/sgp-python/commit/f2c7402c62caf0873e57cc2e77f8a9557c8abdfb))
* **api:** OpenAPI spec update via Stainless API ([#1297](https://github.com/scaleapi/sgp-python/issues/1297)) ([fcb946a](https://github.com/scaleapi/sgp-python/commit/fcb946a70cba20bdefd0fedf2c47cd9927f4c940))
* **api:** OpenAPI spec update via Stainless API ([#1298](https://github.com/scaleapi/sgp-python/issues/1298)) ([6d7ac89](https://github.com/scaleapi/sgp-python/commit/6d7ac8987b007e2b3ce0692c1fa6e317af6ba4e5))
* **api:** OpenAPI spec update via Stainless API ([#1299](https://github.com/scaleapi/sgp-python/issues/1299)) ([24a3dc0](https://github.com/scaleapi/sgp-python/commit/24a3dc084763a0318d32704f1f36a2bf1734d35b))
* **api:** OpenAPI spec update via Stainless API ([#1300](https://github.com/scaleapi/sgp-python/issues/1300)) ([ccef36b](https://github.com/scaleapi/sgp-python/commit/ccef36b000c7afb9fa729b4da67a079fe0804f47))
* **api:** OpenAPI spec update via Stainless API ([#1301](https://github.com/scaleapi/sgp-python/issues/1301)) ([38f68ad](https://github.com/scaleapi/sgp-python/commit/38f68ad7ee26d1c2852d3b5a929548064276dcda))
* **api:** OpenAPI spec update via Stainless API ([#1302](https://github.com/scaleapi/sgp-python/issues/1302)) ([0b99a7b](https://github.com/scaleapi/sgp-python/commit/0b99a7be511e61e5ef93deac7cb99a8c2ca8b7b7))
* **api:** OpenAPI spec update via Stainless API ([#1303](https://github.com/scaleapi/sgp-python/issues/1303)) ([d275f04](https://github.com/scaleapi/sgp-python/commit/d275f043993870099b3af4c81c9274193c1d9091))
* **api:** OpenAPI spec update via Stainless API ([#1304](https://github.com/scaleapi/sgp-python/issues/1304)) ([21a4653](https://github.com/scaleapi/sgp-python/commit/21a46531542e3454d224d127bf2b31eb15734862))
* **api:** OpenAPI spec update via Stainless API ([#1305](https://github.com/scaleapi/sgp-python/issues/1305)) ([e2ab780](https://github.com/scaleapi/sgp-python/commit/e2ab7809e9f5ac6aa2c425f644386f36e5575043))
* **api:** OpenAPI spec update via Stainless API ([#1306](https://github.com/scaleapi/sgp-python/issues/1306)) ([a7ffc0e](https://github.com/scaleapi/sgp-python/commit/a7ffc0e18c728c91ed97f69f083a1a6abae76f66))
* **api:** OpenAPI spec update via Stainless API ([#1307](https://github.com/scaleapi/sgp-python/issues/1307)) ([090a3b1](https://github.com/scaleapi/sgp-python/commit/090a3b12bbb397075dc43a7546db7aca28ee89bc))
* **api:** OpenAPI spec update via Stainless API ([#1308](https://github.com/scaleapi/sgp-python/issues/1308)) ([9618257](https://github.com/scaleapi/sgp-python/commit/961825716db6149adc23b67c47422c81b22c1c10))
* **api:** OpenAPI spec update via Stainless API ([#1309](https://github.com/scaleapi/sgp-python/issues/1309)) ([a2cb46e](https://github.com/scaleapi/sgp-python/commit/a2cb46e614af558167fed95b3030d04873665b64))
* **api:** OpenAPI spec update via Stainless API ([#1310](https://github.com/scaleapi/sgp-python/issues/1310)) ([834af4a](https://github.com/scaleapi/sgp-python/commit/834af4a2240c23af040372d2a195be843c572d53))
* **api:** OpenAPI spec update via Stainless API ([#1311](https://github.com/scaleapi/sgp-python/issues/1311)) ([b42b6a2](https://github.com/scaleapi/sgp-python/commit/b42b6a2c457587c727ffa79a4290c2ce3cb16006))
* **api:** OpenAPI spec update via Stainless API ([#1312](https://github.com/scaleapi/sgp-python/issues/1312)) ([ad06572](https://github.com/scaleapi/sgp-python/commit/ad0657212cd7755d81271fed1aec337b3fdad044))
* **api:** OpenAPI spec update via Stainless API ([#1313](https://github.com/scaleapi/sgp-python/issues/1313)) ([1b2b870](https://github.com/scaleapi/sgp-python/commit/1b2b8700e042e0884b4300ed41855001d79e4b65))
* **api:** OpenAPI spec update via Stainless API ([#1314](https://github.com/scaleapi/sgp-python/issues/1314)) ([519e76f](https://github.com/scaleapi/sgp-python/commit/519e76fe7048a89444249529cde38a32ffd3a0c9))
* **api:** OpenAPI spec update via Stainless API ([#1316](https://github.com/scaleapi/sgp-python/issues/1316)) ([2ee2d7b](https://github.com/scaleapi/sgp-python/commit/2ee2d7b4b55872c494c0e20573f55f299c220137))
* **api:** OpenAPI spec update via Stainless API ([#1317](https://github.com/scaleapi/sgp-python/issues/1317)) ([11d282c](https://github.com/scaleapi/sgp-python/commit/11d282ce5854697b668fed6acd029b449b29aa12))
* **api:** OpenAPI spec update via Stainless API ([#1318](https://github.com/scaleapi/sgp-python/issues/1318)) ([678a6ff](https://github.com/scaleapi/sgp-python/commit/678a6ff1db8b94dcfbbe8cc25d010a5f89240002))
* **api:** OpenAPI spec update via Stainless API ([#1319](https://github.com/scaleapi/sgp-python/issues/1319)) ([ab91a62](https://github.com/scaleapi/sgp-python/commit/ab91a62a7c46cb54684f99b16362123216df5111))
* **api:** OpenAPI spec update via Stainless API ([#1320](https://github.com/scaleapi/sgp-python/issues/1320)) ([a4ae9ca](https://github.com/scaleapi/sgp-python/commit/a4ae9caf46d1dfc00562c927f0b1c880bff14e4b))
* **api:** OpenAPI spec update via Stainless API ([#1321](https://github.com/scaleapi/sgp-python/issues/1321)) ([66e3f9b](https://github.com/scaleapi/sgp-python/commit/66e3f9b6e72c1d5b292411ce1846018e56ad9a2f))
* **api:** OpenAPI spec update via Stainless API ([#1322](https://github.com/scaleapi/sgp-python/issues/1322)) ([91c7bba](https://github.com/scaleapi/sgp-python/commit/91c7bba2b64e001f902e77b839e51dabdce7a0ad))
* **api:** OpenAPI spec update via Stainless API ([#1323](https://github.com/scaleapi/sgp-python/issues/1323)) ([ff73b5b](https://github.com/scaleapi/sgp-python/commit/ff73b5b58c4bc434b690a566049b1819aabc994b))
* **api:** OpenAPI spec update via Stainless API ([#1324](https://github.com/scaleapi/sgp-python/issues/1324)) ([dc9eeb2](https://github.com/scaleapi/sgp-python/commit/dc9eeb2a2a34af08d8f31804d5ad44d61608e16b))
* **api:** OpenAPI spec update via Stainless API ([#1325](https://github.com/scaleapi/sgp-python/issues/1325)) ([1c026c6](https://github.com/scaleapi/sgp-python/commit/1c026c6dfcd4115b4001b37824dae11dd987fe6b))
* **api:** OpenAPI spec update via Stainless API ([#1326](https://github.com/scaleapi/sgp-python/issues/1326)) ([fa422b4](https://github.com/scaleapi/sgp-python/commit/fa422b42d19a199ca13879d97b9a45e5d3c30135))
* **api:** OpenAPI spec update via Stainless API ([#1327](https://github.com/scaleapi/sgp-python/issues/1327)) ([f0bfe09](https://github.com/scaleapi/sgp-python/commit/f0bfe09bb9ce95b73fdd2514a702f841b071a541))
* **api:** OpenAPI spec update via Stainless API ([#1328](https://github.com/scaleapi/sgp-python/issues/1328)) ([67aaa88](https://github.com/scaleapi/sgp-python/commit/67aaa8822dff0b5739a0cead4edade69c389cd90))
* **api:** OpenAPI spec update via Stainless API ([#1329](https://github.com/scaleapi/sgp-python/issues/1329)) ([6d70f6c](https://github.com/scaleapi/sgp-python/commit/6d70f6c974ebe2d6f1958ee89276070d3e1f6545))
* **api:** OpenAPI spec update via Stainless API ([#1330](https://github.com/scaleapi/sgp-python/issues/1330)) ([38d2ef6](https://github.com/scaleapi/sgp-python/commit/38d2ef65e528ec8659d0c9e8c7297feab982b9f3))
* **api:** OpenAPI spec update via Stainless API ([#1331](https://github.com/scaleapi/sgp-python/issues/1331)) ([b357e2d](https://github.com/scaleapi/sgp-python/commit/b357e2db12fc1bcdce06d33ae3122b9a4e342565))
* **api:** OpenAPI spec update via Stainless API ([#1332](https://github.com/scaleapi/sgp-python/issues/1332)) ([656941b](https://github.com/scaleapi/sgp-python/commit/656941b0456575fc9ff1e270f5640976fa38285a))
* **api:** OpenAPI spec update via Stainless API ([#1333](https://github.com/scaleapi/sgp-python/issues/1333)) ([e25dba4](https://github.com/scaleapi/sgp-python/commit/e25dba469678410ec191a6e894e868975d345d2c))
* **api:** OpenAPI spec update via Stainless API ([#1334](https://github.com/scaleapi/sgp-python/issues/1334)) ([73bee86](https://github.com/scaleapi/sgp-python/commit/73bee8657c726b17b2d641bfc378715b8dbb21de))
* **api:** OpenAPI spec update via Stainless API ([#1335](https://github.com/scaleapi/sgp-python/issues/1335)) ([479728e](https://github.com/scaleapi/sgp-python/commit/479728e234beb9b10ef0dd2d030c33ac760c8e37))
* **api:** OpenAPI spec update via Stainless API ([#1336](https://github.com/scaleapi/sgp-python/issues/1336)) ([2b9feea](https://github.com/scaleapi/sgp-python/commit/2b9feea4535f50b24316abae9b755e63b6f56e34))
* **api:** OpenAPI spec update via Stainless API ([#1337](https://github.com/scaleapi/sgp-python/issues/1337)) ([2edd209](https://github.com/scaleapi/sgp-python/commit/2edd20964f465892dd7be5210b9537f700e917f0))
* **api:** OpenAPI spec update via Stainless API ([#1338](https://github.com/scaleapi/sgp-python/issues/1338)) ([9a13472](https://github.com/scaleapi/sgp-python/commit/9a134728bd09e5013b4881008504f70388dfea03))
* **api:** OpenAPI spec update via Stainless API ([#1339](https://github.com/scaleapi/sgp-python/issues/1339)) ([5a54a1f](https://github.com/scaleapi/sgp-python/commit/5a54a1f5116cbeb3e10f3ebbf60027e7541c5831))
* **api:** OpenAPI spec update via Stainless API ([#1340](https://github.com/scaleapi/sgp-python/issues/1340)) ([c89717d](https://github.com/scaleapi/sgp-python/commit/c89717d527886efae6694171dae6721653d86314))
* **api:** OpenAPI spec update via Stainless API ([#1341](https://github.com/scaleapi/sgp-python/issues/1341)) ([f1de8fa](https://github.com/scaleapi/sgp-python/commit/f1de8fae3a6ed613b92d94758e52645da7b9d39a))
* **api:** OpenAPI spec update via Stainless API ([#1342](https://github.com/scaleapi/sgp-python/issues/1342)) ([16bbc10](https://github.com/scaleapi/sgp-python/commit/16bbc10f3c62b5d319ba19292d8584efc45454bc))
* **api:** OpenAPI spec update via Stainless API ([#1343](https://github.com/scaleapi/sgp-python/issues/1343)) ([f995180](https://github.com/scaleapi/sgp-python/commit/f995180266a786e5bc32adbc2094d638f7bb61b2))
* **api:** OpenAPI spec update via Stainless API ([#1344](https://github.com/scaleapi/sgp-python/issues/1344)) ([8b37d4b](https://github.com/scaleapi/sgp-python/commit/8b37d4bdeeffb23e9482b4edad5687fbbd65a0a4))
* **api:** OpenAPI spec update via Stainless API ([#1345](https://github.com/scaleapi/sgp-python/issues/1345)) ([6569e3e](https://github.com/scaleapi/sgp-python/commit/6569e3ee95c82a9c79166c3d7ca6fa30c35b825a))
* **api:** OpenAPI spec update via Stainless API ([#1346](https://github.com/scaleapi/sgp-python/issues/1346)) ([e01b656](https://github.com/scaleapi/sgp-python/commit/e01b656eb29b5237a7acefe54d9d9d28fb1b95f2))
* **api:** OpenAPI spec update via Stainless API ([#1347](https://github.com/scaleapi/sgp-python/issues/1347)) ([53b2f03](https://github.com/scaleapi/sgp-python/commit/53b2f0387a0d802c42088ad536f29de91882bdab))
* **api:** OpenAPI spec update via Stainless API ([#1348](https://github.com/scaleapi/sgp-python/issues/1348)) ([7ba5a0c](https://github.com/scaleapi/sgp-python/commit/7ba5a0cc8ddd63bd5afd7ac8211350ac32f98a2c))
* **api:** OpenAPI spec update via Stainless API ([#1349](https://github.com/scaleapi/sgp-python/issues/1349)) ([5c111c3](https://github.com/scaleapi/sgp-python/commit/5c111c3d4036e0559a77df6427fa031b3d3e4c73))
* **api:** OpenAPI spec update via Stainless API ([#1350](https://github.com/scaleapi/sgp-python/issues/1350)) ([3bc5335](https://github.com/scaleapi/sgp-python/commit/3bc5335d7bf88d5633d850ee9b40033a4cdd678d))
* **api:** OpenAPI spec update via Stainless API ([#1351](https://github.com/scaleapi/sgp-python/issues/1351)) ([d5238cc](https://github.com/scaleapi/sgp-python/commit/d5238cc52692445dd5c8d614cd9cba5d5806e6b9))
* **api:** OpenAPI spec update via Stainless API ([#1352](https://github.com/scaleapi/sgp-python/issues/1352)) ([db0a1cb](https://github.com/scaleapi/sgp-python/commit/db0a1cb6048debe165770e28dcd398e8c7d9816f))
* **api:** OpenAPI spec update via Stainless API ([#1353](https://github.com/scaleapi/sgp-python/issues/1353)) ([78db0a6](https://github.com/scaleapi/sgp-python/commit/78db0a6960814f464cdcefd2dca2488f4df0c3a2))
* **api:** OpenAPI spec update via Stainless API ([#1354](https://github.com/scaleapi/sgp-python/issues/1354)) ([ee3b9e4](https://github.com/scaleapi/sgp-python/commit/ee3b9e459ee096295c0fc0def1f82029b7ceb5e9))
* **api:** OpenAPI spec update via Stainless API ([#1355](https://github.com/scaleapi/sgp-python/issues/1355)) ([d2fcd5e](https://github.com/scaleapi/sgp-python/commit/d2fcd5e79ae662f5880d048ecbd05a4f0cc8a821))
* **api:** OpenAPI spec update via Stainless API ([#1356](https://github.com/scaleapi/sgp-python/issues/1356)) ([8b78e8a](https://github.com/scaleapi/sgp-python/commit/8b78e8a3342ee5cd39745fdf6445dc4c0e2fe52c))
* **api:** OpenAPI spec update via Stainless API ([#1357](https://github.com/scaleapi/sgp-python/issues/1357)) ([2f10cdf](https://github.com/scaleapi/sgp-python/commit/2f10cdf7f9f877f9d7e8ab36506d04e322cdedd5))
* **api:** OpenAPI spec update via Stainless API ([#1358](https://github.com/scaleapi/sgp-python/issues/1358)) ([30abf77](https://github.com/scaleapi/sgp-python/commit/30abf77f9fa4bc1c6004d04faa61d3d1a88545c1))
* **api:** OpenAPI spec update via Stainless API ([#1365](https://github.com/scaleapi/sgp-python/issues/1365)) ([e3bd1c4](https://github.com/scaleapi/sgp-python/commit/e3bd1c4b2e9f6eae721073e420b6f94a55dca26e))
* **api:** OpenAPI spec update via Stainless API ([#1367](https://github.com/scaleapi/sgp-python/issues/1367)) ([decd762](https://github.com/scaleapi/sgp-python/commit/decd76240614c45203304f66fe76e99cf23c72cc))


### Bug Fixes

* default values for `trace_spans` and `metrics` ([83dfae9](https://github.com/scaleapi/sgp-python/commit/83dfae967b59efc543904c700c1072669893dae1))
* lint ([b3050a7](https://github.com/scaleapi/sgp-python/commit/b3050a79ee4772fe656df368c63352401ef357f5))


### Chores

* **internal:** codegen related update ([#1370](https://github.com/scaleapi/sgp-python/issues/1370)) ([4b0d16d](https://github.com/scaleapi/sgp-python/commit/4b0d16d5563b8c1b561b74668d64df0c6f296429))
* pyproject.toml formatting changes ([#1369](https://github.com/scaleapi/sgp-python/issues/1369)) ([08a1121](https://github.com/scaleapi/sgp-python/commit/08a11214d19ef2e2690c8f04b7f368fc2b04074f))
* pyproject.toml formatting changes ([#1371](https://github.com/scaleapi/sgp-python/issues/1371)) ([2499595](https://github.com/scaleapi/sgp-python/commit/2499595be3c0f5524a1362df8b23f0ebf4d85d23))

## 0.1.0-alpha.29 (2024-09-04)

Full Changelog: [v0.1.0-alpha.28...v0.1.0-alpha.29](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.28...v0.1.0-alpha.29)

### Features

* **api:** OpenAPI spec update via Stainless API ([#1365](https://github.com/scaleapi/sgp-python/issues/1365)) ([2b10eaf](https://github.com/scaleapi/sgp-python/commit/2b10eafc53d7490564f85d831808198a52d6392d))
* **api:** OpenAPI spec update via Stainless API ([#1367](https://github.com/scaleapi/sgp-python/issues/1367)) ([cf10ab7](https://github.com/scaleapi/sgp-python/commit/cf10ab7da98ff71a98b07c5880e49e6bb820f9aa))

## 0.1.0-alpha.28 (2024-08-30)

Full Changelog: [v0.1.0-alpha.27...v0.1.0-alpha.28](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.27...v0.1.0-alpha.28)

### Features

* **api:** Config update for anishxyz/dev ([#1363](https://github.com/scaleapi/sgp-python/issues/1363)) ([b51171f](https://github.com/scaleapi/sgp-python/commit/b51171f275a0e2cdc3af40b10fdc2fac1039b70d))
* **api:** OpenAPI spec update via Stainless API ([fe8f7ac](https://github.com/scaleapi/sgp-python/commit/fe8f7acfec36aa7e6d2e0b0236029a6d786076e6))
* **api:** OpenAPI spec update via Stainless API ([2e6576c](https://github.com/scaleapi/sgp-python/commit/2e6576ce3494c306b6f3c7d4f2f05714e2563038))
* **api:** OpenAPI spec update via Stainless API ([b452aad](https://github.com/scaleapi/sgp-python/commit/b452aad1ee9f720e64aad5b4f36f1c1f953ac5c6))
* **api:** OpenAPI spec update via Stainless API ([e4db39f](https://github.com/scaleapi/sgp-python/commit/e4db39f1f0b2e3167623b3da0f011a7e883d8728))
* **api:** OpenAPI spec update via Stainless API ([6074993](https://github.com/scaleapi/sgp-python/commit/60749930c26a8823038dd686f126dacab90bca4f))
* **api:** OpenAPI spec update via Stainless API ([744d3a0](https://github.com/scaleapi/sgp-python/commit/744d3a0c960a6fa1e39b73943b085b138fe4eaac))
* **api:** OpenAPI spec update via Stainless API ([3775b3d](https://github.com/scaleapi/sgp-python/commit/3775b3d9f5912bf493d19fafdc3f3a002da53f15))
* **api:** OpenAPI spec update via Stainless API ([25298f1](https://github.com/scaleapi/sgp-python/commit/25298f19dbe1de6448175e2cb7651875229f960f))
* **api:** OpenAPI spec update via Stainless API ([5d6e108](https://github.com/scaleapi/sgp-python/commit/5d6e108698380d424d4d3b25a48720ea57745ee6))
* **api:** OpenAPI spec update via Stainless API ([a87043e](https://github.com/scaleapi/sgp-python/commit/a87043ec0dd34b42295740731ae92c8d984c1dd7))
* **api:** OpenAPI spec update via Stainless API ([7ce5b80](https://github.com/scaleapi/sgp-python/commit/7ce5b80dadff50d1be5c990c77745265830ea94b))
* **api:** OpenAPI spec update via Stainless API ([51ad24c](https://github.com/scaleapi/sgp-python/commit/51ad24c08e23f47a9e746b378ba0be478c2af558))

## 0.1.0-alpha.27 (2024-08-29)

Full Changelog: [v0.1.0-alpha.26...v0.1.0-alpha.27](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.26...v0.1.0-alpha.27)

### Features

* Add optional `metrics` and `trace_spans` to ExternalApplication outputs ([451aaae](https://github.com/scaleapi/sgp-python/commit/451aaae53b4d7e1597fb9af0d5d22b34060b7fc9))
* **api:** manual updates ([#1359](https://github.com/scaleapi/sgp-python/issues/1359)) ([e39f25c](https://github.com/scaleapi/sgp-python/commit/e39f25c81b17fa958f658cfba715dcf87f0d6893))
* **api:** manual updates ([#1360](https://github.com/scaleapi/sgp-python/issues/1360)) ([36b9640](https://github.com/scaleapi/sgp-python/commit/36b964022acc465597a6c729530417be06bce772))
* **api:** OpenAPI spec update via Stainless API ([ff02eb7](https://github.com/scaleapi/sgp-python/commit/ff02eb7a4a27877ccb66f59dc3201028a25cacfa))
* **api:** OpenAPI spec update via Stainless API ([9a4bfb5](https://github.com/scaleapi/sgp-python/commit/9a4bfb5d5fa9cd459013265cffa799d38aab2049))
* **api:** OpenAPI spec update via Stainless API ([0003fb4](https://github.com/scaleapi/sgp-python/commit/0003fb45d01af1294f4207a1b94e28f78fa68595))
* **api:** OpenAPI spec update via Stainless API ([6392f0c](https://github.com/scaleapi/sgp-python/commit/6392f0c693bf042b67ec32b7393336a06d687b51))
* **api:** OpenAPI spec update via Stainless API ([8acd206](https://github.com/scaleapi/sgp-python/commit/8acd206ca781dec7232ac445ca4163a327418560))
* **api:** OpenAPI spec update via Stainless API ([777b194](https://github.com/scaleapi/sgp-python/commit/777b194c8cbd85fbbbbcb932a6c7035900e98126))
* **api:** OpenAPI spec update via Stainless API ([fe165c8](https://github.com/scaleapi/sgp-python/commit/fe165c896086605aa5612339c7901baca4a10aaa))
* **api:** OpenAPI spec update via Stainless API ([b938bcc](https://github.com/scaleapi/sgp-python/commit/b938bcc431ebae37aa5083732c15ade828959808))
* **api:** OpenAPI spec update via Stainless API ([8404621](https://github.com/scaleapi/sgp-python/commit/840462108a68a1ad988dd5e068ab77684a857c2d))
* **api:** OpenAPI spec update via Stainless API ([e4e9b82](https://github.com/scaleapi/sgp-python/commit/e4e9b8222514082662eba431bbf05099a41b18d7))
* **api:** OpenAPI spec update via Stainless API ([#1075](https://github.com/scaleapi/sgp-python/issues/1075)) ([6eb2e58](https://github.com/scaleapi/sgp-python/commit/6eb2e580aa753133f0e07a174c2a7b41bda6e6e4))
* **api:** OpenAPI spec update via Stainless API ([#1077](https://github.com/scaleapi/sgp-python/issues/1077)) ([3f689f8](https://github.com/scaleapi/sgp-python/commit/3f689f82ee624a56955690b10095d9a012fd222c))
* **api:** OpenAPI spec update via Stainless API ([#1078](https://github.com/scaleapi/sgp-python/issues/1078)) ([cde8401](https://github.com/scaleapi/sgp-python/commit/cde84016680edf077184c89b7494068779f3862d))
* **api:** OpenAPI spec update via Stainless API ([#1079](https://github.com/scaleapi/sgp-python/issues/1079)) ([5aeb074](https://github.com/scaleapi/sgp-python/commit/5aeb074ffa6744230e7bef1c2fd7969aa3035e91))
* **api:** OpenAPI spec update via Stainless API ([#1080](https://github.com/scaleapi/sgp-python/issues/1080)) ([e8df2a7](https://github.com/scaleapi/sgp-python/commit/e8df2a70121e962897028a5ce14a0a2bc3d2ed32))
* **api:** OpenAPI spec update via Stainless API ([#1081](https://github.com/scaleapi/sgp-python/issues/1081)) ([6993cb8](https://github.com/scaleapi/sgp-python/commit/6993cb8d7a328cf5b89c6a7aa4e62820a2c7de1e))
* **api:** OpenAPI spec update via Stainless API ([#1082](https://github.com/scaleapi/sgp-python/issues/1082)) ([527d9f5](https://github.com/scaleapi/sgp-python/commit/527d9f5bd5f59d6f334bcea309a4039b8f0dd7f5))
* **api:** OpenAPI spec update via Stainless API ([#1083](https://github.com/scaleapi/sgp-python/issues/1083)) ([8dcb31b](https://github.com/scaleapi/sgp-python/commit/8dcb31b64d9aad83f51a44847a082731dd686c53))
* **api:** OpenAPI spec update via Stainless API ([#1084](https://github.com/scaleapi/sgp-python/issues/1084)) ([b2634f6](https://github.com/scaleapi/sgp-python/commit/b2634f6463b467e53977628dd278a720217f52d7))
* **api:** OpenAPI spec update via Stainless API ([#1085](https://github.com/scaleapi/sgp-python/issues/1085)) ([a1bf86c](https://github.com/scaleapi/sgp-python/commit/a1bf86c0c077837b559b7413f9047656e3cb64ac))
* **api:** OpenAPI spec update via Stainless API ([#1086](https://github.com/scaleapi/sgp-python/issues/1086)) ([061d6a1](https://github.com/scaleapi/sgp-python/commit/061d6a181cd73285c95d6811e99bc84c2502a8ac))
* **api:** OpenAPI spec update via Stainless API ([#1087](https://github.com/scaleapi/sgp-python/issues/1087)) ([88d20b6](https://github.com/scaleapi/sgp-python/commit/88d20b6fa4d3d1274257fb03137d13579050a2f3))
* **api:** OpenAPI spec update via Stainless API ([#1088](https://github.com/scaleapi/sgp-python/issues/1088)) ([f2159af](https://github.com/scaleapi/sgp-python/commit/f2159af08247d09be6a999212ef59410dbdba708))
* **api:** OpenAPI spec update via Stainless API ([#1089](https://github.com/scaleapi/sgp-python/issues/1089)) ([48111f3](https://github.com/scaleapi/sgp-python/commit/48111f3e204a84ccc0f18c7e858c430c666ab9f2))
* **api:** OpenAPI spec update via Stainless API ([#1090](https://github.com/scaleapi/sgp-python/issues/1090)) ([e49983d](https://github.com/scaleapi/sgp-python/commit/e49983df18f174fc863c09e56d79b295c6c73be8))
* **api:** OpenAPI spec update via Stainless API ([#1091](https://github.com/scaleapi/sgp-python/issues/1091)) ([1254ef8](https://github.com/scaleapi/sgp-python/commit/1254ef8659802b4d40b6ea6b01a6e8c90032fb8b))
* **api:** OpenAPI spec update via Stainless API ([#1092](https://github.com/scaleapi/sgp-python/issues/1092)) ([61ffc1c](https://github.com/scaleapi/sgp-python/commit/61ffc1c64b92a09c327ffabd9554bf46bac07aed))
* **api:** OpenAPI spec update via Stainless API ([#1093](https://github.com/scaleapi/sgp-python/issues/1093)) ([3d99394](https://github.com/scaleapi/sgp-python/commit/3d99394c5532b9b758e1147d26aeca12cea4948e))
* **api:** OpenAPI spec update via Stainless API ([#1094](https://github.com/scaleapi/sgp-python/issues/1094)) ([6e5aa87](https://github.com/scaleapi/sgp-python/commit/6e5aa87e83aa62137a674a047e225595f3b9c1b4))
* **api:** OpenAPI spec update via Stainless API ([#1095](https://github.com/scaleapi/sgp-python/issues/1095)) ([03fd885](https://github.com/scaleapi/sgp-python/commit/03fd88564e6fcf382f5f8635a1ff45ea14c9258a))
* **api:** OpenAPI spec update via Stainless API ([#1096](https://github.com/scaleapi/sgp-python/issues/1096)) ([afffbae](https://github.com/scaleapi/sgp-python/commit/afffbaeb93b8d5210afa8b1c809a2f8dd73f6133))
* **api:** OpenAPI spec update via Stainless API ([#1097](https://github.com/scaleapi/sgp-python/issues/1097)) ([a25d091](https://github.com/scaleapi/sgp-python/commit/a25d0918a386cadb7415970a7e3081a8dc495799))
* **api:** OpenAPI spec update via Stainless API ([#1098](https://github.com/scaleapi/sgp-python/issues/1098)) ([d31a333](https://github.com/scaleapi/sgp-python/commit/d31a333a5e2142fa5c2ae62db8e1bc8009652c6c))
* **api:** OpenAPI spec update via Stainless API ([#1099](https://github.com/scaleapi/sgp-python/issues/1099)) ([3e55200](https://github.com/scaleapi/sgp-python/commit/3e55200795463b1b469b014022100d6edd07e0cd))
* **api:** OpenAPI spec update via Stainless API ([#1100](https://github.com/scaleapi/sgp-python/issues/1100)) ([20328ff](https://github.com/scaleapi/sgp-python/commit/20328ff10583e4bb31d2ddd69bfb339f3a00ffc5))
* **api:** OpenAPI spec update via Stainless API ([#1101](https://github.com/scaleapi/sgp-python/issues/1101)) ([8c03040](https://github.com/scaleapi/sgp-python/commit/8c030409024c543f397fc9bfcc401803ddc271c0))
* **api:** OpenAPI spec update via Stainless API ([#1102](https://github.com/scaleapi/sgp-python/issues/1102)) ([5c95ac7](https://github.com/scaleapi/sgp-python/commit/5c95ac7f54a036b2fd137b8f446326f432e4fdfd))
* **api:** OpenAPI spec update via Stainless API ([#1103](https://github.com/scaleapi/sgp-python/issues/1103)) ([3f090df](https://github.com/scaleapi/sgp-python/commit/3f090df3f2ea908aabe93569769cb2573c3dfe69))
* **api:** OpenAPI spec update via Stainless API ([#1104](https://github.com/scaleapi/sgp-python/issues/1104)) ([2d89edf](https://github.com/scaleapi/sgp-python/commit/2d89edfa22c212f6c80acb498aedf850db22cad8))
* **api:** OpenAPI spec update via Stainless API ([#1105](https://github.com/scaleapi/sgp-python/issues/1105)) ([45a77fc](https://github.com/scaleapi/sgp-python/commit/45a77fc6a18864d1b47112a72e0bf738b770009a))
* **api:** OpenAPI spec update via Stainless API ([#1106](https://github.com/scaleapi/sgp-python/issues/1106)) ([1eb4b47](https://github.com/scaleapi/sgp-python/commit/1eb4b479674e7b48895fc96eb1ca5028260dc90a))
* **api:** OpenAPI spec update via Stainless API ([#1107](https://github.com/scaleapi/sgp-python/issues/1107)) ([44d5d87](https://github.com/scaleapi/sgp-python/commit/44d5d87ee8d17ab1be756377860400ced1730748))
* **api:** OpenAPI spec update via Stainless API ([#1108](https://github.com/scaleapi/sgp-python/issues/1108)) ([177f3c5](https://github.com/scaleapi/sgp-python/commit/177f3c5c45fe770ef69c18ca38907acc5723548b))
* **api:** OpenAPI spec update via Stainless API ([#1109](https://github.com/scaleapi/sgp-python/issues/1109)) ([c74b1b8](https://github.com/scaleapi/sgp-python/commit/c74b1b87cc5dbd0201133514f900d107659452c3))
* **api:** OpenAPI spec update via Stainless API ([#1110](https://github.com/scaleapi/sgp-python/issues/1110)) ([b696ecd](https://github.com/scaleapi/sgp-python/commit/b696ecde1309a1f422193a131cc8ee420992250c))
* **api:** OpenAPI spec update via Stainless API ([#1111](https://github.com/scaleapi/sgp-python/issues/1111)) ([2fa4cf8](https://github.com/scaleapi/sgp-python/commit/2fa4cf8de86564ec90d70c28d3a2352dfcc5b515))
* **api:** OpenAPI spec update via Stainless API ([#1112](https://github.com/scaleapi/sgp-python/issues/1112)) ([28024ce](https://github.com/scaleapi/sgp-python/commit/28024ce1e192756bab70e0e0bd99c34db2a24ad3))
* **api:** OpenAPI spec update via Stainless API ([#1113](https://github.com/scaleapi/sgp-python/issues/1113)) ([e00761d](https://github.com/scaleapi/sgp-python/commit/e00761d0f1fdda8733797280828669cfa7f9d2aa))
* **api:** OpenAPI spec update via Stainless API ([#1114](https://github.com/scaleapi/sgp-python/issues/1114)) ([2479506](https://github.com/scaleapi/sgp-python/commit/24795064581f432cee0ba72b62326af8aa4916b0))
* **api:** OpenAPI spec update via Stainless API ([#1115](https://github.com/scaleapi/sgp-python/issues/1115)) ([188d79a](https://github.com/scaleapi/sgp-python/commit/188d79a73524c12056c16a4093b54ed152d9d5aa))
* **api:** OpenAPI spec update via Stainless API ([#1116](https://github.com/scaleapi/sgp-python/issues/1116)) ([f78283e](https://github.com/scaleapi/sgp-python/commit/f78283e0babf809291e1cb4520f847f64475b417))
* **api:** OpenAPI spec update via Stainless API ([#1117](https://github.com/scaleapi/sgp-python/issues/1117)) ([62aae3d](https://github.com/scaleapi/sgp-python/commit/62aae3d35bbe9cb7578a04cc3831d8e144624330))
* **api:** OpenAPI spec update via Stainless API ([#1118](https://github.com/scaleapi/sgp-python/issues/1118)) ([2d1f23a](https://github.com/scaleapi/sgp-python/commit/2d1f23a287f48b2c36085ba76e834259c2beaed1))
* **api:** OpenAPI spec update via Stainless API ([#1119](https://github.com/scaleapi/sgp-python/issues/1119)) ([a833f2c](https://github.com/scaleapi/sgp-python/commit/a833f2cc4caf3e2b4afab0ce5032a71c348086f8))
* **api:** OpenAPI spec update via Stainless API ([#1120](https://github.com/scaleapi/sgp-python/issues/1120)) ([cdbda79](https://github.com/scaleapi/sgp-python/commit/cdbda792874fd9e330d4d003ae3b0a6900db9878))
* **api:** OpenAPI spec update via Stainless API ([#1121](https://github.com/scaleapi/sgp-python/issues/1121)) ([80ee6a5](https://github.com/scaleapi/sgp-python/commit/80ee6a541ece9294398a28615f9e34664cb74756))
* **api:** OpenAPI spec update via Stainless API ([#1122](https://github.com/scaleapi/sgp-python/issues/1122)) ([905a667](https://github.com/scaleapi/sgp-python/commit/905a667b447a3f0625e05717c010835531f93346))
* **api:** OpenAPI spec update via Stainless API ([#1123](https://github.com/scaleapi/sgp-python/issues/1123)) ([8dec360](https://github.com/scaleapi/sgp-python/commit/8dec360f9a428a8d381532ede6197ca1a1593acc))
* **api:** OpenAPI spec update via Stainless API ([#1124](https://github.com/scaleapi/sgp-python/issues/1124)) ([5474d32](https://github.com/scaleapi/sgp-python/commit/5474d32e4cebfd3f4ffb984cfe1fd262a4d7ee0f))
* **api:** OpenAPI spec update via Stainless API ([#1125](https://github.com/scaleapi/sgp-python/issues/1125)) ([ee0d5a1](https://github.com/scaleapi/sgp-python/commit/ee0d5a1e510b220dff6682b4bcaa216f2bf9f74d))
* **api:** OpenAPI spec update via Stainless API ([#1126](https://github.com/scaleapi/sgp-python/issues/1126)) ([e24afbe](https://github.com/scaleapi/sgp-python/commit/e24afbe4fb6fb38da8a675c43fc13ab618f72895))
* **api:** OpenAPI spec update via Stainless API ([#1127](https://github.com/scaleapi/sgp-python/issues/1127)) ([031961f](https://github.com/scaleapi/sgp-python/commit/031961f9df3dd8bb1c7025090f24086df8ab8526))
* **api:** OpenAPI spec update via Stainless API ([#1128](https://github.com/scaleapi/sgp-python/issues/1128)) ([a7b05ae](https://github.com/scaleapi/sgp-python/commit/a7b05aeb46db9e0b30e9c5be80b97946e782e4fa))
* **api:** OpenAPI spec update via Stainless API ([#1129](https://github.com/scaleapi/sgp-python/issues/1129)) ([93c880e](https://github.com/scaleapi/sgp-python/commit/93c880eb55e91bc4dbb29b0eb2c13b4ac6665a59))
* **api:** OpenAPI spec update via Stainless API ([#1130](https://github.com/scaleapi/sgp-python/issues/1130)) ([3085a67](https://github.com/scaleapi/sgp-python/commit/3085a67443f7cc58dc15b88bd9123120a17bad1b))
* **api:** OpenAPI spec update via Stainless API ([#1131](https://github.com/scaleapi/sgp-python/issues/1131)) ([1af4aba](https://github.com/scaleapi/sgp-python/commit/1af4abae810c8489328f8f84875bc44cbce9ce0b))
* **api:** OpenAPI spec update via Stainless API ([#1132](https://github.com/scaleapi/sgp-python/issues/1132)) ([0fa3959](https://github.com/scaleapi/sgp-python/commit/0fa39598d5b61e9892709d5c97239cbb59e2c716))
* **api:** OpenAPI spec update via Stainless API ([#1133](https://github.com/scaleapi/sgp-python/issues/1133)) ([04c1e3c](https://github.com/scaleapi/sgp-python/commit/04c1e3c66cfbdb1b456e11ee4ff1460757d0dfb4))
* **api:** OpenAPI spec update via Stainless API ([#1134](https://github.com/scaleapi/sgp-python/issues/1134)) ([a7bd4a1](https://github.com/scaleapi/sgp-python/commit/a7bd4a19afa323139c015a974758e9ace1020fa0))
* **api:** OpenAPI spec update via Stainless API ([#1135](https://github.com/scaleapi/sgp-python/issues/1135)) ([5976722](https://github.com/scaleapi/sgp-python/commit/59767221ad1afbd75dd8e08ee770d6fc95f4e22c))
* **api:** OpenAPI spec update via Stainless API ([#1137](https://github.com/scaleapi/sgp-python/issues/1137)) ([331cc02](https://github.com/scaleapi/sgp-python/commit/331cc0241db15c78285463f107096ffaadb004c2))
* **api:** OpenAPI spec update via Stainless API ([#1138](https://github.com/scaleapi/sgp-python/issues/1138)) ([0ae2635](https://github.com/scaleapi/sgp-python/commit/0ae2635070b2976a097fbb02d965018391252e40))
* **api:** OpenAPI spec update via Stainless API ([#1140](https://github.com/scaleapi/sgp-python/issues/1140)) ([0dabebc](https://github.com/scaleapi/sgp-python/commit/0dabebc1219140222c259318aba30893a8994afa))
* **api:** OpenAPI spec update via Stainless API ([#1141](https://github.com/scaleapi/sgp-python/issues/1141)) ([46448aa](https://github.com/scaleapi/sgp-python/commit/46448aa2ce1586386f7b2255fb28541ec6d45502))
* **api:** OpenAPI spec update via Stainless API ([#1142](https://github.com/scaleapi/sgp-python/issues/1142)) ([4718f1f](https://github.com/scaleapi/sgp-python/commit/4718f1fcec6e34123497657069f3478719fdb3a4))
* **api:** OpenAPI spec update via Stainless API ([#1143](https://github.com/scaleapi/sgp-python/issues/1143)) ([092e210](https://github.com/scaleapi/sgp-python/commit/092e2102a933ee7fd3f21919ec04d4221774599d))
* **api:** OpenAPI spec update via Stainless API ([#1145](https://github.com/scaleapi/sgp-python/issues/1145)) ([2b281aa](https://github.com/scaleapi/sgp-python/commit/2b281aaeb82fc5e03cd311f464a922f60de921c4))
* **api:** OpenAPI spec update via Stainless API ([#1146](https://github.com/scaleapi/sgp-python/issues/1146)) ([633ea01](https://github.com/scaleapi/sgp-python/commit/633ea01bd3acf5aa2bdd97106fc0c96fef89d2d9))
* **api:** OpenAPI spec update via Stainless API ([#1147](https://github.com/scaleapi/sgp-python/issues/1147)) ([80434bf](https://github.com/scaleapi/sgp-python/commit/80434bfef1f3ed2256453d44cb8a9aa9dbe94c16))
* **api:** OpenAPI spec update via Stainless API ([#1148](https://github.com/scaleapi/sgp-python/issues/1148)) ([fb8f4c8](https://github.com/scaleapi/sgp-python/commit/fb8f4c8585dcad84cdfdf7199c94a93b3d61e047))
* **api:** OpenAPI spec update via Stainless API ([#1149](https://github.com/scaleapi/sgp-python/issues/1149)) ([de220b0](https://github.com/scaleapi/sgp-python/commit/de220b0829cc8bb66ae5c072ce60f96dfc220032))
* **api:** OpenAPI spec update via Stainless API ([#1150](https://github.com/scaleapi/sgp-python/issues/1150)) ([875fc25](https://github.com/scaleapi/sgp-python/commit/875fc25718b250eabbeb45cfadba8c6ee919ed7e))
* **api:** OpenAPI spec update via Stainless API ([#1151](https://github.com/scaleapi/sgp-python/issues/1151)) ([f31aa57](https://github.com/scaleapi/sgp-python/commit/f31aa5741064720a24e0a503f6ecd0f1526893b8))
* **api:** OpenAPI spec update via Stainless API ([#1152](https://github.com/scaleapi/sgp-python/issues/1152)) ([5cb0c8e](https://github.com/scaleapi/sgp-python/commit/5cb0c8ec9255a5ca5652d82642ab35e31499d541))
* **api:** OpenAPI spec update via Stainless API ([#1153](https://github.com/scaleapi/sgp-python/issues/1153)) ([240704e](https://github.com/scaleapi/sgp-python/commit/240704e57b4b20c5cc47d728968afdc0960107d2))
* **api:** OpenAPI spec update via Stainless API ([#1154](https://github.com/scaleapi/sgp-python/issues/1154)) ([e777ada](https://github.com/scaleapi/sgp-python/commit/e777ada1917b70a591a7818373f95e3b12fe0c2f))
* **api:** OpenAPI spec update via Stainless API ([#1155](https://github.com/scaleapi/sgp-python/issues/1155)) ([a718708](https://github.com/scaleapi/sgp-python/commit/a718708d56ed12ef1d2da05735af7225bbf0d18d))
* **api:** OpenAPI spec update via Stainless API ([#1156](https://github.com/scaleapi/sgp-python/issues/1156)) ([eb43005](https://github.com/scaleapi/sgp-python/commit/eb43005922427cea4a5735e3a8271629123fd0cd))
* **api:** OpenAPI spec update via Stainless API ([#1157](https://github.com/scaleapi/sgp-python/issues/1157)) ([61788d1](https://github.com/scaleapi/sgp-python/commit/61788d1ca162557286fbe00c1e0e92d4f38f3893))
* **api:** OpenAPI spec update via Stainless API ([#1158](https://github.com/scaleapi/sgp-python/issues/1158)) ([3a773b1](https://github.com/scaleapi/sgp-python/commit/3a773b1720b29f4e235f5e6103cae43978da0913))
* **api:** OpenAPI spec update via Stainless API ([#1159](https://github.com/scaleapi/sgp-python/issues/1159)) ([6667ab7](https://github.com/scaleapi/sgp-python/commit/6667ab7223839f2ad6c22d04be2608969aef0e4a))
* **api:** OpenAPI spec update via Stainless API ([#1160](https://github.com/scaleapi/sgp-python/issues/1160)) ([c5c8cae](https://github.com/scaleapi/sgp-python/commit/c5c8caea2af7052dcd546912394d187de4fa1255))
* **api:** OpenAPI spec update via Stainless API ([#1161](https://github.com/scaleapi/sgp-python/issues/1161)) ([928b407](https://github.com/scaleapi/sgp-python/commit/928b40750205a9b5bcdab3e77401fed8415bb339))
* **api:** OpenAPI spec update via Stainless API ([#1162](https://github.com/scaleapi/sgp-python/issues/1162)) ([a02d5df](https://github.com/scaleapi/sgp-python/commit/a02d5dfeb571212cf642f65a35416e176496cadb))
* **api:** OpenAPI spec update via Stainless API ([#1163](https://github.com/scaleapi/sgp-python/issues/1163)) ([ce2ef1a](https://github.com/scaleapi/sgp-python/commit/ce2ef1aebbd59c065a0711a6482c21d234078b05))
* **api:** OpenAPI spec update via Stainless API ([#1164](https://github.com/scaleapi/sgp-python/issues/1164)) ([3bef524](https://github.com/scaleapi/sgp-python/commit/3bef5249585a3c81eb01a16ac4e1778b0ec71a38))
* **api:** OpenAPI spec update via Stainless API ([#1165](https://github.com/scaleapi/sgp-python/issues/1165)) ([45a9e55](https://github.com/scaleapi/sgp-python/commit/45a9e55e289e06f8b2d1d2e6d1d22790bbdaa7ed))
* **api:** OpenAPI spec update via Stainless API ([#1166](https://github.com/scaleapi/sgp-python/issues/1166)) ([750f0dd](https://github.com/scaleapi/sgp-python/commit/750f0dd5cb59302a314049021f08ed94e7c0ad53))
* **api:** OpenAPI spec update via Stainless API ([#1167](https://github.com/scaleapi/sgp-python/issues/1167)) ([5312f93](https://github.com/scaleapi/sgp-python/commit/5312f93d3904c8521bf962c10944a39ef3011a8d))
* **api:** OpenAPI spec update via Stainless API ([#1168](https://github.com/scaleapi/sgp-python/issues/1168)) ([e50396b](https://github.com/scaleapi/sgp-python/commit/e50396b9a62d3bdb3f207d8d0c95d2963eb72cfb))
* **api:** OpenAPI spec update via Stainless API ([#1169](https://github.com/scaleapi/sgp-python/issues/1169)) ([1ec079b](https://github.com/scaleapi/sgp-python/commit/1ec079b3b424cd270f31140672c4554798255c45))
* **api:** OpenAPI spec update via Stainless API ([#1170](https://github.com/scaleapi/sgp-python/issues/1170)) ([43263a1](https://github.com/scaleapi/sgp-python/commit/43263a16de2d265d76b70a6e80e6f6bcd677062f))
* **api:** OpenAPI spec update via Stainless API ([#1171](https://github.com/scaleapi/sgp-python/issues/1171)) ([dc089a5](https://github.com/scaleapi/sgp-python/commit/dc089a5f7ec315964c5e330a3dd4108f3c802b9c))
* **api:** OpenAPI spec update via Stainless API ([#1172](https://github.com/scaleapi/sgp-python/issues/1172)) ([bf7e2be](https://github.com/scaleapi/sgp-python/commit/bf7e2be0ddc2c2d05298aa01cac008ef8dbaa1e7))
* **api:** OpenAPI spec update via Stainless API ([#1173](https://github.com/scaleapi/sgp-python/issues/1173)) ([32e5f61](https://github.com/scaleapi/sgp-python/commit/32e5f6191c48fe41772333c171e79f9241edf7ac))
* **api:** OpenAPI spec update via Stainless API ([#1174](https://github.com/scaleapi/sgp-python/issues/1174)) ([66ce677](https://github.com/scaleapi/sgp-python/commit/66ce677969b2cdea58d126ccb41198a4b1c2051d))
* **api:** OpenAPI spec update via Stainless API ([#1175](https://github.com/scaleapi/sgp-python/issues/1175)) ([921c1c6](https://github.com/scaleapi/sgp-python/commit/921c1c6a7300abc6bd712512e0e37cee0ccebbed))
* **api:** OpenAPI spec update via Stainless API ([#1176](https://github.com/scaleapi/sgp-python/issues/1176)) ([0be9bac](https://github.com/scaleapi/sgp-python/commit/0be9bac403b0f6720c48dea5fd5ecc4e9f7b16ea))
* **api:** OpenAPI spec update via Stainless API ([#1177](https://github.com/scaleapi/sgp-python/issues/1177)) ([3518f9a](https://github.com/scaleapi/sgp-python/commit/3518f9ae36a4fa277e74eab106689bd0e28f83e3))
* **api:** OpenAPI spec update via Stainless API ([#1178](https://github.com/scaleapi/sgp-python/issues/1178)) ([a8dfa51](https://github.com/scaleapi/sgp-python/commit/a8dfa5124cd22c731d0133782046d7db98850648))
* **api:** OpenAPI spec update via Stainless API ([#1179](https://github.com/scaleapi/sgp-python/issues/1179)) ([1f85012](https://github.com/scaleapi/sgp-python/commit/1f850120f0a0cacb0603ef291494e3256965ff51))
* **api:** OpenAPI spec update via Stainless API ([#1180](https://github.com/scaleapi/sgp-python/issues/1180)) ([8c7d951](https://github.com/scaleapi/sgp-python/commit/8c7d9518e228b875d9d49332ecc3178cc0cfab4e))
* **api:** OpenAPI spec update via Stainless API ([#1181](https://github.com/scaleapi/sgp-python/issues/1181)) ([4f30a37](https://github.com/scaleapi/sgp-python/commit/4f30a372e671dcef2cd8afb1e14740e49bb5279f))
* **api:** OpenAPI spec update via Stainless API ([#1182](https://github.com/scaleapi/sgp-python/issues/1182)) ([339c3dc](https://github.com/scaleapi/sgp-python/commit/339c3dcc416fadc569100d2f580a692507e9e77c))
* **api:** OpenAPI spec update via Stainless API ([#1183](https://github.com/scaleapi/sgp-python/issues/1183)) ([6ce7011](https://github.com/scaleapi/sgp-python/commit/6ce7011017775b24eefba608247f428dd8e3d4df))
* **api:** OpenAPI spec update via Stainless API ([#1184](https://github.com/scaleapi/sgp-python/issues/1184)) ([329258b](https://github.com/scaleapi/sgp-python/commit/329258bd172aa9570cb4671967e83de3379bc003))
* **api:** OpenAPI spec update via Stainless API ([#1185](https://github.com/scaleapi/sgp-python/issues/1185)) ([d053aa8](https://github.com/scaleapi/sgp-python/commit/d053aa8be2d0ea54cf94fe63e8540d12e1ff0b4a))
* **api:** OpenAPI spec update via Stainless API ([#1186](https://github.com/scaleapi/sgp-python/issues/1186)) ([a9a3318](https://github.com/scaleapi/sgp-python/commit/a9a33182ef0b9eaeda8a3d393a2e564c4cf48d44))
* **api:** OpenAPI spec update via Stainless API ([#1187](https://github.com/scaleapi/sgp-python/issues/1187)) ([023ad93](https://github.com/scaleapi/sgp-python/commit/023ad93ea74237275b52f1bb346cc9b9b6b255ca))
* **api:** OpenAPI spec update via Stainless API ([#1188](https://github.com/scaleapi/sgp-python/issues/1188)) ([4b04a1e](https://github.com/scaleapi/sgp-python/commit/4b04a1ed18fe8be5e80727fa031fdafca2b82a34))
* **api:** OpenAPI spec update via Stainless API ([#1189](https://github.com/scaleapi/sgp-python/issues/1189)) ([9ea2116](https://github.com/scaleapi/sgp-python/commit/9ea21160e3814596009895a3a5745ae8fc7700da))
* **api:** OpenAPI spec update via Stainless API ([#1190](https://github.com/scaleapi/sgp-python/issues/1190)) ([2b4acf1](https://github.com/scaleapi/sgp-python/commit/2b4acf18652417098f2b74a99575389dca7d8478))
* **api:** OpenAPI spec update via Stainless API ([#1191](https://github.com/scaleapi/sgp-python/issues/1191)) ([6a22ec2](https://github.com/scaleapi/sgp-python/commit/6a22ec2f159c0b6009067347dae86b9c967a2958))
* **api:** OpenAPI spec update via Stainless API ([#1192](https://github.com/scaleapi/sgp-python/issues/1192)) ([1750969](https://github.com/scaleapi/sgp-python/commit/175096974c14914d1fd2fd40dd1e4a03a50d8f92))
* **api:** OpenAPI spec update via Stainless API ([#1193](https://github.com/scaleapi/sgp-python/issues/1193)) ([8479146](https://github.com/scaleapi/sgp-python/commit/847914609fff971f59e17bf022c949797464e5e8))
* **api:** OpenAPI spec update via Stainless API ([#1194](https://github.com/scaleapi/sgp-python/issues/1194)) ([e5541ac](https://github.com/scaleapi/sgp-python/commit/e5541aca937ed4aa50f88e9e6c77ea9dbe81b836))
* **api:** OpenAPI spec update via Stainless API ([#1195](https://github.com/scaleapi/sgp-python/issues/1195)) ([8075ffb](https://github.com/scaleapi/sgp-python/commit/8075ffb3b4f2ea2778f8deef6a78da79880d130b))
* **api:** OpenAPI spec update via Stainless API ([#1196](https://github.com/scaleapi/sgp-python/issues/1196)) ([7636a7b](https://github.com/scaleapi/sgp-python/commit/7636a7b557d1c067da20cbad14e41d6c31d2f8a7))
* **api:** OpenAPI spec update via Stainless API ([#1197](https://github.com/scaleapi/sgp-python/issues/1197)) ([18dd32f](https://github.com/scaleapi/sgp-python/commit/18dd32fc515d5170e6f716f0936294f1fead6c69))
* **api:** OpenAPI spec update via Stainless API ([#1198](https://github.com/scaleapi/sgp-python/issues/1198)) ([3b5a9b6](https://github.com/scaleapi/sgp-python/commit/3b5a9b60bcf666dba70183914a3175857ec43a76))
* **api:** OpenAPI spec update via Stainless API ([#1199](https://github.com/scaleapi/sgp-python/issues/1199)) ([833fde4](https://github.com/scaleapi/sgp-python/commit/833fde463f4b7b9e8fcb3b234ec05d5bc1a77476))
* **api:** OpenAPI spec update via Stainless API ([#1200](https://github.com/scaleapi/sgp-python/issues/1200)) ([edc8db9](https://github.com/scaleapi/sgp-python/commit/edc8db93ae7de4ffd85e0ae7bdd3531f10d00c7b))
* **api:** OpenAPI spec update via Stainless API ([#1201](https://github.com/scaleapi/sgp-python/issues/1201)) ([bf8e240](https://github.com/scaleapi/sgp-python/commit/bf8e240fd9357d2a8cad3424f10103db35a3950b))
* **api:** OpenAPI spec update via Stainless API ([#1202](https://github.com/scaleapi/sgp-python/issues/1202)) ([a9818e5](https://github.com/scaleapi/sgp-python/commit/a9818e5595a0850b0aa8914ecd65327973c9f880))
* **api:** OpenAPI spec update via Stainless API ([#1203](https://github.com/scaleapi/sgp-python/issues/1203)) ([bbd2a4b](https://github.com/scaleapi/sgp-python/commit/bbd2a4b9cf68efc013fd9bb3b674791af325a6f0))
* **api:** OpenAPI spec update via Stainless API ([#1204](https://github.com/scaleapi/sgp-python/issues/1204)) ([6a7981f](https://github.com/scaleapi/sgp-python/commit/6a7981fe999630bf81f5757a16cb7c0c36ad069c))
* **api:** OpenAPI spec update via Stainless API ([#1205](https://github.com/scaleapi/sgp-python/issues/1205)) ([cf00cd3](https://github.com/scaleapi/sgp-python/commit/cf00cd3f29bf0ab6e26ae27cd384102511f53c76))
* **api:** OpenAPI spec update via Stainless API ([#1206](https://github.com/scaleapi/sgp-python/issues/1206)) ([5ea1234](https://github.com/scaleapi/sgp-python/commit/5ea1234b6e4936f4da291203a432b1c3264c9b3b))
* **api:** OpenAPI spec update via Stainless API ([#1208](https://github.com/scaleapi/sgp-python/issues/1208)) ([1fffd0e](https://github.com/scaleapi/sgp-python/commit/1fffd0e05119fdd964e495242864b1453b32de69))
* **api:** OpenAPI spec update via Stainless API ([#1209](https://github.com/scaleapi/sgp-python/issues/1209)) ([f9be946](https://github.com/scaleapi/sgp-python/commit/f9be946ec10de39da218e079e4f25a018c47e7aa))
* **api:** OpenAPI spec update via Stainless API ([#1210](https://github.com/scaleapi/sgp-python/issues/1210)) ([96cfc6f](https://github.com/scaleapi/sgp-python/commit/96cfc6f8f7f63b146a874e2cbf5cb8e30b035a68))
* **api:** OpenAPI spec update via Stainless API ([#1211](https://github.com/scaleapi/sgp-python/issues/1211)) ([8fb1626](https://github.com/scaleapi/sgp-python/commit/8fb1626d8db34c255f9a6a79e40c362382d991aa))
* **api:** OpenAPI spec update via Stainless API ([#1212](https://github.com/scaleapi/sgp-python/issues/1212)) ([745d860](https://github.com/scaleapi/sgp-python/commit/745d86088b38603383e34e83873f934cc355589b))
* **api:** OpenAPI spec update via Stainless API ([#1213](https://github.com/scaleapi/sgp-python/issues/1213)) ([21f3309](https://github.com/scaleapi/sgp-python/commit/21f33093195f77a03d91180276498f993525ca77))
* **api:** OpenAPI spec update via Stainless API ([#1214](https://github.com/scaleapi/sgp-python/issues/1214)) ([817a710](https://github.com/scaleapi/sgp-python/commit/817a7102b0aca20c2692c24eb95551bed4f8d8c5))
* **api:** OpenAPI spec update via Stainless API ([#1215](https://github.com/scaleapi/sgp-python/issues/1215)) ([02ec30e](https://github.com/scaleapi/sgp-python/commit/02ec30ee8ffa005ecddd6d7f193e006c1db4313a))
* **api:** OpenAPI spec update via Stainless API ([#1216](https://github.com/scaleapi/sgp-python/issues/1216)) ([596db23](https://github.com/scaleapi/sgp-python/commit/596db239f211a8f5f267936de69dae71bdc2fa77))
* **api:** OpenAPI spec update via Stainless API ([#1217](https://github.com/scaleapi/sgp-python/issues/1217)) ([405417b](https://github.com/scaleapi/sgp-python/commit/405417b69d1afad39aa5ceeefeb91112027fdd86))
* **api:** OpenAPI spec update via Stainless API ([#1218](https://github.com/scaleapi/sgp-python/issues/1218)) ([fb5c80a](https://github.com/scaleapi/sgp-python/commit/fb5c80a58817dc022bb8b90338f60b68243e8a67))
* **api:** OpenAPI spec update via Stainless API ([#1219](https://github.com/scaleapi/sgp-python/issues/1219)) ([0ff0c03](https://github.com/scaleapi/sgp-python/commit/0ff0c03c1a1b211daccc91c665c0d0d604eb3294))
* **api:** OpenAPI spec update via Stainless API ([#1220](https://github.com/scaleapi/sgp-python/issues/1220)) ([f1e90b9](https://github.com/scaleapi/sgp-python/commit/f1e90b9e7005bba5c9e9116f59300b67829ca2b9))
* **api:** OpenAPI spec update via Stainless API ([#1221](https://github.com/scaleapi/sgp-python/issues/1221)) ([e6965f9](https://github.com/scaleapi/sgp-python/commit/e6965f9d7640e88c94661147d1cb1ec8683050f9))
* **api:** OpenAPI spec update via Stainless API ([#1222](https://github.com/scaleapi/sgp-python/issues/1222)) ([c5b9696](https://github.com/scaleapi/sgp-python/commit/c5b96964584fc875c5360c5b1a111892142320ab))
* **api:** OpenAPI spec update via Stainless API ([#1223](https://github.com/scaleapi/sgp-python/issues/1223)) ([d06a219](https://github.com/scaleapi/sgp-python/commit/d06a2196910f836384aa6a51489507a424801a3d))
* **api:** OpenAPI spec update via Stainless API ([#1224](https://github.com/scaleapi/sgp-python/issues/1224)) ([eaeac8b](https://github.com/scaleapi/sgp-python/commit/eaeac8bac3f3f2e131708edc702919d50d71ec7a))
* **api:** OpenAPI spec update via Stainless API ([#1225](https://github.com/scaleapi/sgp-python/issues/1225)) ([b5dbc20](https://github.com/scaleapi/sgp-python/commit/b5dbc20e49c643e658816f74898e69d9fc7cd20b))
* **api:** OpenAPI spec update via Stainless API ([#1226](https://github.com/scaleapi/sgp-python/issues/1226)) ([a96564c](https://github.com/scaleapi/sgp-python/commit/a96564cf552c7c81cf5e9aeef80bd642721f8411))
* **api:** OpenAPI spec update via Stainless API ([#1227](https://github.com/scaleapi/sgp-python/issues/1227)) ([488d393](https://github.com/scaleapi/sgp-python/commit/488d3932d0f9e1315aadf8961d5736e2049b105c))
* **api:** OpenAPI spec update via Stainless API ([#1228](https://github.com/scaleapi/sgp-python/issues/1228)) ([8ba6c68](https://github.com/scaleapi/sgp-python/commit/8ba6c6832b3ee482473a19f71ba33af4ffa02599))
* **api:** OpenAPI spec update via Stainless API ([#1229](https://github.com/scaleapi/sgp-python/issues/1229)) ([ecfea5e](https://github.com/scaleapi/sgp-python/commit/ecfea5e1c49def04a2c97fcaf7092c854c862191))
* **api:** OpenAPI spec update via Stainless API ([#1230](https://github.com/scaleapi/sgp-python/issues/1230)) ([06ebbf9](https://github.com/scaleapi/sgp-python/commit/06ebbf977449802c9b123d8abc77633f417d27c0))
* **api:** OpenAPI spec update via Stainless API ([#1231](https://github.com/scaleapi/sgp-python/issues/1231)) ([0e587cc](https://github.com/scaleapi/sgp-python/commit/0e587cc7a6dee77d755315635c6604bca4dc573c))
* **api:** OpenAPI spec update via Stainless API ([#1232](https://github.com/scaleapi/sgp-python/issues/1232)) ([037287e](https://github.com/scaleapi/sgp-python/commit/037287eec4e2f6e9f14d09da57f3b4f27ffc6550))
* **api:** OpenAPI spec update via Stainless API ([#1233](https://github.com/scaleapi/sgp-python/issues/1233)) ([3b05181](https://github.com/scaleapi/sgp-python/commit/3b051813c75fbe1f40ae163880b30fe5384d808c))
* **api:** OpenAPI spec update via Stainless API ([#1234](https://github.com/scaleapi/sgp-python/issues/1234)) ([9faa72c](https://github.com/scaleapi/sgp-python/commit/9faa72ce0ee9cb25462b93fb7a86cd4504674753))
* **api:** OpenAPI spec update via Stainless API ([#1235](https://github.com/scaleapi/sgp-python/issues/1235)) ([d344ff5](https://github.com/scaleapi/sgp-python/commit/d344ff5d93908ed5715fab8d1d43fb16ecc10059))
* **api:** OpenAPI spec update via Stainless API ([#1236](https://github.com/scaleapi/sgp-python/issues/1236)) ([4a3a5e5](https://github.com/scaleapi/sgp-python/commit/4a3a5e5933f7852711a8037662dabdc6d0969973))
* **api:** OpenAPI spec update via Stainless API ([#1237](https://github.com/scaleapi/sgp-python/issues/1237)) ([299c53d](https://github.com/scaleapi/sgp-python/commit/299c53d73a714a73983073cd6d143cf88010a566))
* **api:** OpenAPI spec update via Stainless API ([#1238](https://github.com/scaleapi/sgp-python/issues/1238)) ([a081aca](https://github.com/scaleapi/sgp-python/commit/a081aca41806d8f09b32a8f9fa712b90d6951721))
* **api:** OpenAPI spec update via Stainless API ([#1239](https://github.com/scaleapi/sgp-python/issues/1239)) ([97af0c1](https://github.com/scaleapi/sgp-python/commit/97af0c166383640a0bac6476f8a0b9c637f25056))
* **api:** OpenAPI spec update via Stainless API ([#1240](https://github.com/scaleapi/sgp-python/issues/1240)) ([9eb014f](https://github.com/scaleapi/sgp-python/commit/9eb014f39115ba702fb9c445923d42f0a8eb46b5))
* **api:** OpenAPI spec update via Stainless API ([#1241](https://github.com/scaleapi/sgp-python/issues/1241)) ([d1ed704](https://github.com/scaleapi/sgp-python/commit/d1ed70471f4e95232471d9390a8eeab8afd626b9))
* **api:** OpenAPI spec update via Stainless API ([#1242](https://github.com/scaleapi/sgp-python/issues/1242)) ([46005f0](https://github.com/scaleapi/sgp-python/commit/46005f0115a43e7129f2c9222392772ded09738d))
* **api:** OpenAPI spec update via Stainless API ([#1243](https://github.com/scaleapi/sgp-python/issues/1243)) ([2f4d2d8](https://github.com/scaleapi/sgp-python/commit/2f4d2d8d3021c217c621447a8e9b14227d8ab30a))
* **api:** OpenAPI spec update via Stainless API ([#1244](https://github.com/scaleapi/sgp-python/issues/1244)) ([2b78381](https://github.com/scaleapi/sgp-python/commit/2b783811c0233e0b526ffab9af13b4c6e9516722))
* **api:** OpenAPI spec update via Stainless API ([#1245](https://github.com/scaleapi/sgp-python/issues/1245)) ([aa0eafa](https://github.com/scaleapi/sgp-python/commit/aa0eafa4f1372ff8389877e09ede535ed4f2b296))
* **api:** OpenAPI spec update via Stainless API ([#1246](https://github.com/scaleapi/sgp-python/issues/1246)) ([ab29042](https://github.com/scaleapi/sgp-python/commit/ab29042eb870ded0ebc507b8b778cd2c864b621a))
* **api:** OpenAPI spec update via Stainless API ([#1247](https://github.com/scaleapi/sgp-python/issues/1247)) ([c44a817](https://github.com/scaleapi/sgp-python/commit/c44a817d89f70c7157aa397bd9c4fe92b3def96c))
* **api:** OpenAPI spec update via Stainless API ([#1248](https://github.com/scaleapi/sgp-python/issues/1248)) ([305199a](https://github.com/scaleapi/sgp-python/commit/305199a139ce303ce5fff0c11b3f63b0bcada9a7))
* **api:** OpenAPI spec update via Stainless API ([#1249](https://github.com/scaleapi/sgp-python/issues/1249)) ([0b1ad1f](https://github.com/scaleapi/sgp-python/commit/0b1ad1fb241a4cbdc1c842b721b57b72b10653bc))
* **api:** OpenAPI spec update via Stainless API ([#1250](https://github.com/scaleapi/sgp-python/issues/1250)) ([b9b673e](https://github.com/scaleapi/sgp-python/commit/b9b673eeff42d7b32bb7ec445aced2cc8fb7defc))
* **api:** OpenAPI spec update via Stainless API ([#1251](https://github.com/scaleapi/sgp-python/issues/1251)) ([d9d26a2](https://github.com/scaleapi/sgp-python/commit/d9d26a2e021db992869118f02de7fe52ced4962a))
* **api:** OpenAPI spec update via Stainless API ([#1252](https://github.com/scaleapi/sgp-python/issues/1252)) ([298baa9](https://github.com/scaleapi/sgp-python/commit/298baa9ed8d03370b0e8a259436fe1215c560ad0))
* **api:** OpenAPI spec update via Stainless API ([#1253](https://github.com/scaleapi/sgp-python/issues/1253)) ([322d4f9](https://github.com/scaleapi/sgp-python/commit/322d4f9828b07b49817bc5585879230c4f6ee8f0))
* **api:** OpenAPI spec update via Stainless API ([#1254](https://github.com/scaleapi/sgp-python/issues/1254)) ([4b20082](https://github.com/scaleapi/sgp-python/commit/4b20082b9cd8f5bec2bf268a43aa47c439d06550))
* **api:** OpenAPI spec update via Stainless API ([#1255](https://github.com/scaleapi/sgp-python/issues/1255)) ([df20d07](https://github.com/scaleapi/sgp-python/commit/df20d07623780791853eb2bacdf40b9c9cdd9873))
* **api:** OpenAPI spec update via Stainless API ([#1256](https://github.com/scaleapi/sgp-python/issues/1256)) ([6710f90](https://github.com/scaleapi/sgp-python/commit/6710f905eaf8df645796aea1d3ed1f6d4e1d19a2))
* **api:** OpenAPI spec update via Stainless API ([#1257](https://github.com/scaleapi/sgp-python/issues/1257)) ([208ca71](https://github.com/scaleapi/sgp-python/commit/208ca714c1d85af451dd4c769b66f604b8bd5336))
* **api:** OpenAPI spec update via Stainless API ([#1258](https://github.com/scaleapi/sgp-python/issues/1258)) ([c884b9c](https://github.com/scaleapi/sgp-python/commit/c884b9caa47f973adfbf08d7e43fa02d479d9dee))
* **api:** OpenAPI spec update via Stainless API ([#1259](https://github.com/scaleapi/sgp-python/issues/1259)) ([0da94cc](https://github.com/scaleapi/sgp-python/commit/0da94ccb75915b20dc2e46d60e27a76eaea838c9))
* **api:** OpenAPI spec update via Stainless API ([#1260](https://github.com/scaleapi/sgp-python/issues/1260)) ([c3411a5](https://github.com/scaleapi/sgp-python/commit/c3411a545c228b073c862b84abd21948b6c30990))
* **api:** OpenAPI spec update via Stainless API ([#1261](https://github.com/scaleapi/sgp-python/issues/1261)) ([c9b6a29](https://github.com/scaleapi/sgp-python/commit/c9b6a295c7377287681d499881615c20ba3ae033))
* **api:** OpenAPI spec update via Stainless API ([#1262](https://github.com/scaleapi/sgp-python/issues/1262)) ([905ba71](https://github.com/scaleapi/sgp-python/commit/905ba714e24f5d6c1c829c229c07a76e5dbc3276))
* **api:** OpenAPI spec update via Stainless API ([#1263](https://github.com/scaleapi/sgp-python/issues/1263)) ([c83ffed](https://github.com/scaleapi/sgp-python/commit/c83ffedeb812dfbc6960355bfc15d0e2cde509fa))
* **api:** OpenAPI spec update via Stainless API ([#1264](https://github.com/scaleapi/sgp-python/issues/1264)) ([b650c2c](https://github.com/scaleapi/sgp-python/commit/b650c2c67f784ab9ca1cfbcf799891073c7427b1))
* **api:** OpenAPI spec update via Stainless API ([#1265](https://github.com/scaleapi/sgp-python/issues/1265)) ([5bb3652](https://github.com/scaleapi/sgp-python/commit/5bb3652c9e14ad31a41b42bee5fc8e6f90bd4a84))
* **api:** OpenAPI spec update via Stainless API ([#1266](https://github.com/scaleapi/sgp-python/issues/1266)) ([cfc132b](https://github.com/scaleapi/sgp-python/commit/cfc132b11305eb985b77df38ddf05aea1249b507))
* **api:** OpenAPI spec update via Stainless API ([#1267](https://github.com/scaleapi/sgp-python/issues/1267)) ([8b19996](https://github.com/scaleapi/sgp-python/commit/8b1999671f91327d9f666fc2ffeb61a2d1e64411))
* **api:** OpenAPI spec update via Stainless API ([#1268](https://github.com/scaleapi/sgp-python/issues/1268)) ([88ba32b](https://github.com/scaleapi/sgp-python/commit/88ba32b59473fd91edb6b297ffef1c32983dda06))
* **api:** OpenAPI spec update via Stainless API ([#1269](https://github.com/scaleapi/sgp-python/issues/1269)) ([e587caf](https://github.com/scaleapi/sgp-python/commit/e587caf0fa6379f52e9da6c88f207ff91d6d5739))
* **api:** OpenAPI spec update via Stainless API ([#1270](https://github.com/scaleapi/sgp-python/issues/1270)) ([9843a60](https://github.com/scaleapi/sgp-python/commit/9843a6007360d771c40daf047dfc0e35ccb6f23c))
* **api:** OpenAPI spec update via Stainless API ([#1271](https://github.com/scaleapi/sgp-python/issues/1271)) ([0676531](https://github.com/scaleapi/sgp-python/commit/06765315a2114faa78d8bc741a4f63e8f640941e))
* **api:** OpenAPI spec update via Stainless API ([#1272](https://github.com/scaleapi/sgp-python/issues/1272)) ([1f88d0a](https://github.com/scaleapi/sgp-python/commit/1f88d0af919e54b3f2e3e55e30f19e94bd9ce871))
* **api:** OpenAPI spec update via Stainless API ([#1273](https://github.com/scaleapi/sgp-python/issues/1273)) ([d43475b](https://github.com/scaleapi/sgp-python/commit/d43475b6bd9e757b34407fc37505df13eb5134f7))
* **api:** OpenAPI spec update via Stainless API ([#1274](https://github.com/scaleapi/sgp-python/issues/1274)) ([3529422](https://github.com/scaleapi/sgp-python/commit/35294221f97430f237d2530be599aee0358c7097))
* **api:** OpenAPI spec update via Stainless API ([#1275](https://github.com/scaleapi/sgp-python/issues/1275)) ([dbeda36](https://github.com/scaleapi/sgp-python/commit/dbeda364f6004eec08109cf3c03e758ac15f4879))
* **api:** OpenAPI spec update via Stainless API ([#1276](https://github.com/scaleapi/sgp-python/issues/1276)) ([7a95118](https://github.com/scaleapi/sgp-python/commit/7a95118210f23d07e4d5445bd472eab851791672))
* **api:** OpenAPI spec update via Stainless API ([#1277](https://github.com/scaleapi/sgp-python/issues/1277)) ([3e1cf4b](https://github.com/scaleapi/sgp-python/commit/3e1cf4b455d9aa8fda45d737cbb7f9faac0b2ea4))
* **api:** OpenAPI spec update via Stainless API ([#1278](https://github.com/scaleapi/sgp-python/issues/1278)) ([e3ed73d](https://github.com/scaleapi/sgp-python/commit/e3ed73d3b285875d9100b5dec13dc6ad1b47b9cc))
* **api:** OpenAPI spec update via Stainless API ([#1279](https://github.com/scaleapi/sgp-python/issues/1279)) ([1e29b63](https://github.com/scaleapi/sgp-python/commit/1e29b63b3923701a2062973c917f4dd6d35b93c6))
* **api:** OpenAPI spec update via Stainless API ([#1280](https://github.com/scaleapi/sgp-python/issues/1280)) ([1c0d437](https://github.com/scaleapi/sgp-python/commit/1c0d4371394ea2ee176c68e1011623a15c5e6204))
* **api:** OpenAPI spec update via Stainless API ([#1281](https://github.com/scaleapi/sgp-python/issues/1281)) ([d00b150](https://github.com/scaleapi/sgp-python/commit/d00b150d705c5e5c7cb02e28e6637263f7757892))
* **api:** OpenAPI spec update via Stainless API ([#1282](https://github.com/scaleapi/sgp-python/issues/1282)) ([469864f](https://github.com/scaleapi/sgp-python/commit/469864f82685258d2868c5af24ceb7c9dfe25360))
* **api:** OpenAPI spec update via Stainless API ([#1283](https://github.com/scaleapi/sgp-python/issues/1283)) ([b257c0f](https://github.com/scaleapi/sgp-python/commit/b257c0f1fd853c912ddbf12320d6c20430a09e63))
* **api:** OpenAPI spec update via Stainless API ([#1284](https://github.com/scaleapi/sgp-python/issues/1284)) ([43dfe1f](https://github.com/scaleapi/sgp-python/commit/43dfe1fbfdf966a952048e50f7183473b4c5ae87))
* **api:** OpenAPI spec update via Stainless API ([#1285](https://github.com/scaleapi/sgp-python/issues/1285)) ([878d815](https://github.com/scaleapi/sgp-python/commit/878d8157ffc28306e62a580729bc6a3ac4fd67c9))
* **api:** OpenAPI spec update via Stainless API ([#1286](https://github.com/scaleapi/sgp-python/issues/1286)) ([e5c5608](https://github.com/scaleapi/sgp-python/commit/e5c560805afb9ae735137eb30517563d289a3738))
* **api:** OpenAPI spec update via Stainless API ([#1287](https://github.com/scaleapi/sgp-python/issues/1287)) ([934e18a](https://github.com/scaleapi/sgp-python/commit/934e18a4ab82cb507cf069124ca1c8f291b9c4fe))
* **api:** OpenAPI spec update via Stainless API ([#1288](https://github.com/scaleapi/sgp-python/issues/1288)) ([6920030](https://github.com/scaleapi/sgp-python/commit/6920030c9d2f3f2048d13f99c71f697740a58d7a))
* **api:** OpenAPI spec update via Stainless API ([#1290](https://github.com/scaleapi/sgp-python/issues/1290)) ([670f1f2](https://github.com/scaleapi/sgp-python/commit/670f1f2ae225c4213d14e728343a3f7bf7ad98fc))
* **api:** OpenAPI spec update via Stainless API ([#1291](https://github.com/scaleapi/sgp-python/issues/1291)) ([1d8c956](https://github.com/scaleapi/sgp-python/commit/1d8c95689af5253fe8f174d9c1bf77534eb183db))
* **api:** OpenAPI spec update via Stainless API ([#1292](https://github.com/scaleapi/sgp-python/issues/1292)) ([730fce2](https://github.com/scaleapi/sgp-python/commit/730fce21f6f98662707a6de6d1d903e5887d8534))
* **api:** OpenAPI spec update via Stainless API ([#1293](https://github.com/scaleapi/sgp-python/issues/1293)) ([b6a268b](https://github.com/scaleapi/sgp-python/commit/b6a268b546dcc1f6ab21209f59c22c4ad8e7093c))
* **api:** OpenAPI spec update via Stainless API ([#1294](https://github.com/scaleapi/sgp-python/issues/1294)) ([cbfcadb](https://github.com/scaleapi/sgp-python/commit/cbfcadba362b9ecb9177bb586fd6d505c069df56))
* **api:** OpenAPI spec update via Stainless API ([#1295](https://github.com/scaleapi/sgp-python/issues/1295)) ([2b1a5e2](https://github.com/scaleapi/sgp-python/commit/2b1a5e28e0c0472c46a078a2c37e601d5a4b991d))
* **api:** OpenAPI spec update via Stainless API ([#1297](https://github.com/scaleapi/sgp-python/issues/1297)) ([57b7b4a](https://github.com/scaleapi/sgp-python/commit/57b7b4a07b61b5fcc60503799df5d09991c4d140))
* **api:** OpenAPI spec update via Stainless API ([#1298](https://github.com/scaleapi/sgp-python/issues/1298)) ([c1435f0](https://github.com/scaleapi/sgp-python/commit/c1435f0babca6db434dbca7b0d1811670496e6b2))
* **api:** OpenAPI spec update via Stainless API ([#1299](https://github.com/scaleapi/sgp-python/issues/1299)) ([7f34259](https://github.com/scaleapi/sgp-python/commit/7f34259df2a01e494093163974895d7833041472))
* **api:** OpenAPI spec update via Stainless API ([#1300](https://github.com/scaleapi/sgp-python/issues/1300)) ([01fee9b](https://github.com/scaleapi/sgp-python/commit/01fee9b87120ae4e20d5c137103d64e4fb98cd38))
* **api:** OpenAPI spec update via Stainless API ([#1301](https://github.com/scaleapi/sgp-python/issues/1301)) ([4db6dd9](https://github.com/scaleapi/sgp-python/commit/4db6dd9e7b6a558f9657186b89fac28dbeeb8eeb))
* **api:** OpenAPI spec update via Stainless API ([#1302](https://github.com/scaleapi/sgp-python/issues/1302)) ([72e8a10](https://github.com/scaleapi/sgp-python/commit/72e8a10d487df36e0d7cd5c117459c5f3b48eb88))
* **api:** OpenAPI spec update via Stainless API ([#1303](https://github.com/scaleapi/sgp-python/issues/1303)) ([ab295e1](https://github.com/scaleapi/sgp-python/commit/ab295e19f29bc1f312146e30a86ebad3cf4e0e30))
* **api:** OpenAPI spec update via Stainless API ([#1304](https://github.com/scaleapi/sgp-python/issues/1304)) ([ff4c4e7](https://github.com/scaleapi/sgp-python/commit/ff4c4e74388b09d16ec145a86dd724c5590ade70))
* **api:** OpenAPI spec update via Stainless API ([#1305](https://github.com/scaleapi/sgp-python/issues/1305)) ([8db4dbe](https://github.com/scaleapi/sgp-python/commit/8db4dbe58f24feabcc6b84414ec6f620b2450ca9))
* **api:** OpenAPI spec update via Stainless API ([#1306](https://github.com/scaleapi/sgp-python/issues/1306)) ([a7424ba](https://github.com/scaleapi/sgp-python/commit/a7424ba7f53bb068c5f8af19dcd1199829c56e0d))
* **api:** OpenAPI spec update via Stainless API ([#1307](https://github.com/scaleapi/sgp-python/issues/1307)) ([c34f70e](https://github.com/scaleapi/sgp-python/commit/c34f70e53b69e8f63a66643864aa03d6973b727f))
* **api:** OpenAPI spec update via Stainless API ([#1308](https://github.com/scaleapi/sgp-python/issues/1308)) ([b001e78](https://github.com/scaleapi/sgp-python/commit/b001e782acb19d3a7a452eb15cd847ab50ac5737))
* **api:** OpenAPI spec update via Stainless API ([#1309](https://github.com/scaleapi/sgp-python/issues/1309)) ([3425220](https://github.com/scaleapi/sgp-python/commit/3425220af87e69b83b05a9b2ff346247349f43a6))
* **api:** OpenAPI spec update via Stainless API ([#1310](https://github.com/scaleapi/sgp-python/issues/1310)) ([91b46a6](https://github.com/scaleapi/sgp-python/commit/91b46a635ae624b1aec667b90b5ca9cb225bd00e))
* **api:** OpenAPI spec update via Stainless API ([#1311](https://github.com/scaleapi/sgp-python/issues/1311)) ([718b6cd](https://github.com/scaleapi/sgp-python/commit/718b6cd974648ba574a4d8534cb8f0e45cfb9190))
* **api:** OpenAPI spec update via Stainless API ([#1312](https://github.com/scaleapi/sgp-python/issues/1312)) ([cf54c3a](https://github.com/scaleapi/sgp-python/commit/cf54c3ae5496bbc497ae4f4c859574e481f2341f))
* **api:** OpenAPI spec update via Stainless API ([#1313](https://github.com/scaleapi/sgp-python/issues/1313)) ([423ae71](https://github.com/scaleapi/sgp-python/commit/423ae71cb3cd953c260ccef09b1bac6ca8fd20c8))
* **api:** OpenAPI spec update via Stainless API ([#1314](https://github.com/scaleapi/sgp-python/issues/1314)) ([ecadbbd](https://github.com/scaleapi/sgp-python/commit/ecadbbde39de0120b43f62451efe6c794975b6d9))
* **api:** OpenAPI spec update via Stainless API ([#1316](https://github.com/scaleapi/sgp-python/issues/1316)) ([4c331c8](https://github.com/scaleapi/sgp-python/commit/4c331c890bc9e34d2dd8838f9b1bbb94ab38fec2))
* **api:** OpenAPI spec update via Stainless API ([#1317](https://github.com/scaleapi/sgp-python/issues/1317)) ([24b103f](https://github.com/scaleapi/sgp-python/commit/24b103f5d39424110bcab1ccf674def1c0a7968b))
* **api:** OpenAPI spec update via Stainless API ([#1318](https://github.com/scaleapi/sgp-python/issues/1318)) ([cb6ad85](https://github.com/scaleapi/sgp-python/commit/cb6ad854022ec8225c02aa55f2ad083d474444f5))
* **api:** OpenAPI spec update via Stainless API ([#1319](https://github.com/scaleapi/sgp-python/issues/1319)) ([f9ca645](https://github.com/scaleapi/sgp-python/commit/f9ca64569b6c71d5720da62e73e4b8320c5c9088))
* **api:** OpenAPI spec update via Stainless API ([#1320](https://github.com/scaleapi/sgp-python/issues/1320)) ([60e51b6](https://github.com/scaleapi/sgp-python/commit/60e51b6fdadfa638d3c8f5975a3ebdbffd346a9c))
* **api:** OpenAPI spec update via Stainless API ([#1321](https://github.com/scaleapi/sgp-python/issues/1321)) ([e53bf3d](https://github.com/scaleapi/sgp-python/commit/e53bf3dee0ffbd6b65bcf076371f246a698c1589))
* **api:** OpenAPI spec update via Stainless API ([#1322](https://github.com/scaleapi/sgp-python/issues/1322)) ([0eb2bf5](https://github.com/scaleapi/sgp-python/commit/0eb2bf59a9e123d0fd71e28fdca5fc3c15e7804f))
* **api:** OpenAPI spec update via Stainless API ([#1323](https://github.com/scaleapi/sgp-python/issues/1323)) ([fdd586e](https://github.com/scaleapi/sgp-python/commit/fdd586e7a6d4ea76be84dba949909523c586f1b0))
* **api:** OpenAPI spec update via Stainless API ([#1324](https://github.com/scaleapi/sgp-python/issues/1324)) ([653daf8](https://github.com/scaleapi/sgp-python/commit/653daf89e3b9efc249e477687b5849948843ca1b))
* **api:** OpenAPI spec update via Stainless API ([#1325](https://github.com/scaleapi/sgp-python/issues/1325)) ([84a44ed](https://github.com/scaleapi/sgp-python/commit/84a44ed86f0306027ff160e8962fcfea3270fce4))
* **api:** OpenAPI spec update via Stainless API ([#1326](https://github.com/scaleapi/sgp-python/issues/1326)) ([c87b8e6](https://github.com/scaleapi/sgp-python/commit/c87b8e60731f9a2caa9a9d8867fd4255f77ba5bf))
* **api:** OpenAPI spec update via Stainless API ([#1327](https://github.com/scaleapi/sgp-python/issues/1327)) ([2347a57](https://github.com/scaleapi/sgp-python/commit/2347a578e06fcf573e5727f3586419247346854b))
* **api:** OpenAPI spec update via Stainless API ([#1328](https://github.com/scaleapi/sgp-python/issues/1328)) ([8bd2a25](https://github.com/scaleapi/sgp-python/commit/8bd2a25e4c0c2df668e4e6e03422a62f13071a34))
* **api:** OpenAPI spec update via Stainless API ([#1329](https://github.com/scaleapi/sgp-python/issues/1329)) ([2492536](https://github.com/scaleapi/sgp-python/commit/2492536204800129785df98c9e7655d8c5474a2e))
* **api:** OpenAPI spec update via Stainless API ([#1330](https://github.com/scaleapi/sgp-python/issues/1330)) ([7e4afbb](https://github.com/scaleapi/sgp-python/commit/7e4afbbfbaa71ab1e6538c48532dc9bbdd3c34e9))
* **api:** OpenAPI spec update via Stainless API ([#1331](https://github.com/scaleapi/sgp-python/issues/1331)) ([e2d8079](https://github.com/scaleapi/sgp-python/commit/e2d80798a8dd1dd870bce1094c5cf66d2c3d12c0))
* **api:** OpenAPI spec update via Stainless API ([#1332](https://github.com/scaleapi/sgp-python/issues/1332)) ([a4bf321](https://github.com/scaleapi/sgp-python/commit/a4bf32100b3c20f13e9aeb96b7ee2a1bf1b93a63))
* **api:** OpenAPI spec update via Stainless API ([#1333](https://github.com/scaleapi/sgp-python/issues/1333)) ([8fcb020](https://github.com/scaleapi/sgp-python/commit/8fcb020b2ada52f21a0443e011076995b48b9647))
* **api:** OpenAPI spec update via Stainless API ([#1334](https://github.com/scaleapi/sgp-python/issues/1334)) ([fed701c](https://github.com/scaleapi/sgp-python/commit/fed701cb323236b5676b448e90a994943ef8221b))
* **api:** OpenAPI spec update via Stainless API ([#1335](https://github.com/scaleapi/sgp-python/issues/1335)) ([d8009ea](https://github.com/scaleapi/sgp-python/commit/d8009ea8a8b8536390ce1d4669c96a8dac85bc60))
* **api:** OpenAPI spec update via Stainless API ([#1336](https://github.com/scaleapi/sgp-python/issues/1336)) ([cec3682](https://github.com/scaleapi/sgp-python/commit/cec3682a58716f14550c73bfbf317a42f7181868))
* **api:** OpenAPI spec update via Stainless API ([#1337](https://github.com/scaleapi/sgp-python/issues/1337)) ([1f05d1f](https://github.com/scaleapi/sgp-python/commit/1f05d1f4161369184e1abb5caa64cfada508ec6f))
* **api:** OpenAPI spec update via Stainless API ([#1338](https://github.com/scaleapi/sgp-python/issues/1338)) ([40e5729](https://github.com/scaleapi/sgp-python/commit/40e572949937b5e31d9c45a2e25518a4479f622a))
* **api:** OpenAPI spec update via Stainless API ([#1339](https://github.com/scaleapi/sgp-python/issues/1339)) ([75b8e01](https://github.com/scaleapi/sgp-python/commit/75b8e010766233e3e3c3f2eb1202b9f1cc9568e3))
* **api:** OpenAPI spec update via Stainless API ([#1340](https://github.com/scaleapi/sgp-python/issues/1340)) ([385c2c4](https://github.com/scaleapi/sgp-python/commit/385c2c4a2b9fb7ea973f962727f247ca53a44911))
* **api:** OpenAPI spec update via Stainless API ([#1341](https://github.com/scaleapi/sgp-python/issues/1341)) ([96140c8](https://github.com/scaleapi/sgp-python/commit/96140c80811aa681f6e394c6633358f5a8835967))
* **api:** OpenAPI spec update via Stainless API ([#1342](https://github.com/scaleapi/sgp-python/issues/1342)) ([797fdca](https://github.com/scaleapi/sgp-python/commit/797fdca4c53906f29e2b7a02691c26dfa0a11509))
* **api:** OpenAPI spec update via Stainless API ([#1343](https://github.com/scaleapi/sgp-python/issues/1343)) ([c189cc0](https://github.com/scaleapi/sgp-python/commit/c189cc07fa37538f0aa454e42007f268aa3df74e))
* **api:** OpenAPI spec update via Stainless API ([#1344](https://github.com/scaleapi/sgp-python/issues/1344)) ([2d8606b](https://github.com/scaleapi/sgp-python/commit/2d8606ba351b8a2a0bb3119fc6ed6f2bcc78e46b))
* **api:** OpenAPI spec update via Stainless API ([#1345](https://github.com/scaleapi/sgp-python/issues/1345)) ([4371836](https://github.com/scaleapi/sgp-python/commit/4371836bfb40cfdc221acf2116d9b519c11d3a09))
* **api:** OpenAPI spec update via Stainless API ([#1346](https://github.com/scaleapi/sgp-python/issues/1346)) ([f1cbca6](https://github.com/scaleapi/sgp-python/commit/f1cbca6150b73b0fdecdaf196119e69f08fe2322))
* **api:** OpenAPI spec update via Stainless API ([#1347](https://github.com/scaleapi/sgp-python/issues/1347)) ([2cb4542](https://github.com/scaleapi/sgp-python/commit/2cb454217449cfa8a96fbe336f3c0d1dbbd5dc33))
* **api:** OpenAPI spec update via Stainless API ([#1348](https://github.com/scaleapi/sgp-python/issues/1348)) ([28f81a8](https://github.com/scaleapi/sgp-python/commit/28f81a81c8e0a8ecc3cc012b71609cf3c2bf6e78))
* **api:** OpenAPI spec update via Stainless API ([#1349](https://github.com/scaleapi/sgp-python/issues/1349)) ([7c6a32b](https://github.com/scaleapi/sgp-python/commit/7c6a32b6ec35b29e4a9d5898c7386ac32d4e1ddf))
* **api:** OpenAPI spec update via Stainless API ([#1350](https://github.com/scaleapi/sgp-python/issues/1350)) ([1e4ec23](https://github.com/scaleapi/sgp-python/commit/1e4ec238332234751dbbf2b4d006ec63d4b347a7))
* **api:** OpenAPI spec update via Stainless API ([#1351](https://github.com/scaleapi/sgp-python/issues/1351)) ([9b55226](https://github.com/scaleapi/sgp-python/commit/9b55226e6091564673e0b750d321c2853fc80b31))
* **api:** OpenAPI spec update via Stainless API ([#1352](https://github.com/scaleapi/sgp-python/issues/1352)) ([35243ce](https://github.com/scaleapi/sgp-python/commit/35243cea7e22306c8b37f2b1221e4b01d022a5e7))
* **api:** OpenAPI spec update via Stainless API ([#1353](https://github.com/scaleapi/sgp-python/issues/1353)) ([19dd406](https://github.com/scaleapi/sgp-python/commit/19dd4064029f0f14a24a2d496ee69f9fc0bf708a))
* **api:** OpenAPI spec update via Stainless API ([#1354](https://github.com/scaleapi/sgp-python/issues/1354)) ([308403a](https://github.com/scaleapi/sgp-python/commit/308403a136bdb8d57140152044a0120ffab12c6f))
* **api:** OpenAPI spec update via Stainless API ([#1355](https://github.com/scaleapi/sgp-python/issues/1355)) ([202098b](https://github.com/scaleapi/sgp-python/commit/202098b8e2d5b98ace89b6021cdbd86f4e30739f))
* **api:** OpenAPI spec update via Stainless API ([#1356](https://github.com/scaleapi/sgp-python/issues/1356)) ([20fae23](https://github.com/scaleapi/sgp-python/commit/20fae23645c85ce7028d46837f52124af2fed01e))
* **api:** OpenAPI spec update via Stainless API ([#1357](https://github.com/scaleapi/sgp-python/issues/1357)) ([02ff8e1](https://github.com/scaleapi/sgp-python/commit/02ff8e143b93f95063075f4003b207331a0e82fa))
* **api:** OpenAPI spec update via Stainless API ([#1358](https://github.com/scaleapi/sgp-python/issues/1358)) ([6358ad3](https://github.com/scaleapi/sgp-python/commit/6358ad328bd9271faf48402f3051e5270823a9e3))


### Bug Fixes

* default values for `trace_spans` and `metrics` ([a56cdcb](https://github.com/scaleapi/sgp-python/commit/a56cdcb967079bef42745dedff7567345a23777d))
* lint ([7b6c08a](https://github.com/scaleapi/sgp-python/commit/7b6c08a4a1610ac235e64fe2a5bcc56cb51b5b35))


### Chores

* **ci:** also run pydantic v1 tests ([#1144](https://github.com/scaleapi/sgp-python/issues/1144)) ([65be626](https://github.com/scaleapi/sgp-python/commit/65be626e28c0aef5732d3238d7c53093b1fbb056))
* **client:** fix parsing union responses when non-json is returned ([#1139](https://github.com/scaleapi/sgp-python/issues/1139)) ([5d97d7c](https://github.com/scaleapi/sgp-python/commit/5d97d7cb515c1de08d56ff7f6c7be5e75266fd51))

## 0.1.0-alpha.26 (2024-08-17)

Full Changelog: [v0.1.0-alpha.25...v0.1.0-alpha.26](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.25...v0.1.0-alpha.26)

### Features

* **api:** OpenAPI spec update via Stainless API ([#1047](https://github.com/scaleapi/sgp-python/issues/1047)) ([56f41b5](https://github.com/scaleapi/sgp-python/commit/56f41b583a6bef3032bc286170a9434200d3e613))
* **api:** OpenAPI spec update via Stainless API ([#1050](https://github.com/scaleapi/sgp-python/issues/1050)) ([ebccfa2](https://github.com/scaleapi/sgp-python/commit/ebccfa27e097aa4f7da5b5b690bb09f451d18f30))
* **api:** OpenAPI spec update via Stainless API ([#1052](https://github.com/scaleapi/sgp-python/issues/1052)) ([7441a41](https://github.com/scaleapi/sgp-python/commit/7441a417cbeee53e70bfe5d2286f28bd3ea7f606))
* **api:** OpenAPI spec update via Stainless API ([#1053](https://github.com/scaleapi/sgp-python/issues/1053)) ([48d062b](https://github.com/scaleapi/sgp-python/commit/48d062be40466d62b26013c72e63890af008126c))
* **api:** OpenAPI spec update via Stainless API ([#1054](https://github.com/scaleapi/sgp-python/issues/1054)) ([25c9d01](https://github.com/scaleapi/sgp-python/commit/25c9d01ab04ebe079182404b93634b5816d4f438))
* **api:** OpenAPI spec update via Stainless API ([#1055](https://github.com/scaleapi/sgp-python/issues/1055)) ([d020abc](https://github.com/scaleapi/sgp-python/commit/d020abc5024a3201c10da8b329afcf4f0f0487ff))
* **api:** OpenAPI spec update via Stainless API ([#1056](https://github.com/scaleapi/sgp-python/issues/1056)) ([2a30ddf](https://github.com/scaleapi/sgp-python/commit/2a30ddfbadc87c4420ce44b66d5dd532538058e6))
* **api:** OpenAPI spec update via Stainless API ([#1057](https://github.com/scaleapi/sgp-python/issues/1057)) ([250b853](https://github.com/scaleapi/sgp-python/commit/250b8534e4f770ad4edc79da06e7e883861362fc))
* **api:** OpenAPI spec update via Stainless API ([#1058](https://github.com/scaleapi/sgp-python/issues/1058)) ([9293c1f](https://github.com/scaleapi/sgp-python/commit/9293c1fa6693bf1868854787da237bbab277e01a))
* **api:** OpenAPI spec update via Stainless API ([#1059](https://github.com/scaleapi/sgp-python/issues/1059)) ([8a715b1](https://github.com/scaleapi/sgp-python/commit/8a715b1fb66a0026f854a58237f12a4f7ce003f5))
* **api:** OpenAPI spec update via Stainless API ([#1060](https://github.com/scaleapi/sgp-python/issues/1060)) ([8553330](https://github.com/scaleapi/sgp-python/commit/8553330cd0eed88dafed68cd8b4f76d4ba3a561f))
* **api:** OpenAPI spec update via Stainless API ([#1061](https://github.com/scaleapi/sgp-python/issues/1061)) ([1eb1e96](https://github.com/scaleapi/sgp-python/commit/1eb1e96ae378fc3ab0412efaaa21bd11f6c75190))
* **api:** OpenAPI spec update via Stainless API ([#1062](https://github.com/scaleapi/sgp-python/issues/1062)) ([2e298ad](https://github.com/scaleapi/sgp-python/commit/2e298ad229b2cc45a8770ca7994d28d9c1a24c37))
* **api:** OpenAPI spec update via Stainless API ([#1063](https://github.com/scaleapi/sgp-python/issues/1063)) ([47d2405](https://github.com/scaleapi/sgp-python/commit/47d2405c502b65faf3eb794dd2d21a3e624806f4))
* **api:** OpenAPI spec update via Stainless API ([#1064](https://github.com/scaleapi/sgp-python/issues/1064)) ([6d196cd](https://github.com/scaleapi/sgp-python/commit/6d196cd19a7b31b8b20a5e840e4c3a5035180b4c))
* **api:** OpenAPI spec update via Stainless API ([#1065](https://github.com/scaleapi/sgp-python/issues/1065)) ([9b4a8a3](https://github.com/scaleapi/sgp-python/commit/9b4a8a34f876f9d387c762a8d8c412fe90b83ba6))
* **api:** OpenAPI spec update via Stainless API ([#1066](https://github.com/scaleapi/sgp-python/issues/1066)) ([2b91a4b](https://github.com/scaleapi/sgp-python/commit/2b91a4b245284c62ae3d922024bb0e15bc902fbb))
* **api:** OpenAPI spec update via Stainless API ([#1067](https://github.com/scaleapi/sgp-python/issues/1067)) ([31a53b8](https://github.com/scaleapi/sgp-python/commit/31a53b8957ab89fe97691041eb68ef35956f446b))
* **api:** OpenAPI spec update via Stainless API ([#1068](https://github.com/scaleapi/sgp-python/issues/1068)) ([e74c112](https://github.com/scaleapi/sgp-python/commit/e74c11242f3c428f946aebacddf1ea91bbf5d628))
* **api:** OpenAPI spec update via Stainless API ([#1069](https://github.com/scaleapi/sgp-python/issues/1069)) ([9ad5375](https://github.com/scaleapi/sgp-python/commit/9ad53754e57375a2bc6fc6ebad160832d539609f))
* **api:** OpenAPI spec update via Stainless API ([#1070](https://github.com/scaleapi/sgp-python/issues/1070)) ([43400d1](https://github.com/scaleapi/sgp-python/commit/43400d10052694ac7272aa30b7e93960cdeecd0c))
* **api:** OpenAPI spec update via Stainless API ([#1071](https://github.com/scaleapi/sgp-python/issues/1071)) ([93f77bc](https://github.com/scaleapi/sgp-python/commit/93f77bc9a1caf42173738e73a893f864c5d32673))
* **api:** OpenAPI spec update via Stainless API ([#1072](https://github.com/scaleapi/sgp-python/issues/1072)) ([19920ea](https://github.com/scaleapi/sgp-python/commit/19920ea8bece17e6e2ef0dd6ef62ece7576d4a17))
* **api:** OpenAPI spec update via Stainless API ([#1073](https://github.com/scaleapi/sgp-python/issues/1073)) ([a18d8e7](https://github.com/scaleapi/sgp-python/commit/a18d8e762f9253eb10aaa88fb18e31acaf4dfc1c))
* **api:** update via SDK Studio ([#1051](https://github.com/scaleapi/sgp-python/issues/1051)) ([212295c](https://github.com/scaleapi/sgp-python/commit/212295c4bec113755f06fdfca8d7d0841dbf247b))


### Bug Fixes

* **lib:** fix ExternalApplication implementation ([033a4f7](https://github.com/scaleapi/sgp-python/commit/033a4f7703f933a4acfba2b9effe574bfae0b605))


### Chores

* **format:** run formatter ([ec04dbe](https://github.com/scaleapi/sgp-python/commit/ec04dbe52077994cb7a255896ea7ba1791308ef8))
* **internal:** use different 32bit detection method ([#1044](https://github.com/scaleapi/sgp-python/issues/1044)) ([f810ba9](https://github.com/scaleapi/sgp-python/commit/f810ba97c79a70ec29474483418fd423a6021fa4))

## 0.1.0-alpha.25 (2024-08-15)

Full Changelog: [v0.1.0-alpha.24...v0.1.0-alpha.25](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.24...v0.1.0-alpha.25)

### Features

* **api:** OpenAPI spec update via Stainless API ([#1018](https://github.com/scaleapi/sgp-python/issues/1018)) ([0c50750](https://github.com/scaleapi/sgp-python/commit/0c50750125ed0500c62655641c40aee20bb216fe))
* **api:** OpenAPI spec update via Stainless API ([#1019](https://github.com/scaleapi/sgp-python/issues/1019)) ([427a997](https://github.com/scaleapi/sgp-python/commit/427a99743dc7784e67c32bd901992265a8e0cb74))
* **api:** OpenAPI spec update via Stainless API ([#1020](https://github.com/scaleapi/sgp-python/issues/1020)) ([8269257](https://github.com/scaleapi/sgp-python/commit/8269257f7481c16e21510b67c5352430fea03a07))
* **api:** OpenAPI spec update via Stainless API ([#1021](https://github.com/scaleapi/sgp-python/issues/1021)) ([d24643c](https://github.com/scaleapi/sgp-python/commit/d24643cbcaea2874cb7af01b63f5cf7e2b3e3b87))
* **api:** OpenAPI spec update via Stainless API ([#1022](https://github.com/scaleapi/sgp-python/issues/1022)) ([8d41431](https://github.com/scaleapi/sgp-python/commit/8d41431f7519c11a91d355b9a5ed09d4d54ca31b))
* **api:** OpenAPI spec update via Stainless API ([#1023](https://github.com/scaleapi/sgp-python/issues/1023)) ([87bd44b](https://github.com/scaleapi/sgp-python/commit/87bd44bf77a4d684b819763ebfe125e92b46b817))
* **api:** OpenAPI spec update via Stainless API ([#1024](https://github.com/scaleapi/sgp-python/issues/1024)) ([2ca1505](https://github.com/scaleapi/sgp-python/commit/2ca1505865348eed8a409e847c1744f574d34038))
* **api:** OpenAPI spec update via Stainless API ([#1025](https://github.com/scaleapi/sgp-python/issues/1025)) ([61a3864](https://github.com/scaleapi/sgp-python/commit/61a3864d7ca74a93c276bae769f5e4c8ecd16266))
* **api:** OpenAPI spec update via Stainless API ([#1026](https://github.com/scaleapi/sgp-python/issues/1026)) ([b8dfcca](https://github.com/scaleapi/sgp-python/commit/b8dfcca44ab244de3f56e3e43a3a39b4c38c7d40))
* **api:** OpenAPI spec update via Stainless API ([#1027](https://github.com/scaleapi/sgp-python/issues/1027)) ([bcbf535](https://github.com/scaleapi/sgp-python/commit/bcbf5354738612356ed2e6a13cbb819195047193))
* **api:** OpenAPI spec update via Stainless API ([#1028](https://github.com/scaleapi/sgp-python/issues/1028)) ([9a784e1](https://github.com/scaleapi/sgp-python/commit/9a784e116f531191036a4ea11094471a66257137))
* **api:** OpenAPI spec update via Stainless API ([#1029](https://github.com/scaleapi/sgp-python/issues/1029)) ([5f61c9f](https://github.com/scaleapi/sgp-python/commit/5f61c9f6ce19f5792ed21a76d409cf8a50930b88))
* **api:** OpenAPI spec update via Stainless API ([#1030](https://github.com/scaleapi/sgp-python/issues/1030)) ([64731da](https://github.com/scaleapi/sgp-python/commit/64731da68a2a0e3bb4caf390f9b1ea79c3707086))
* **api:** OpenAPI spec update via Stainless API ([#1031](https://github.com/scaleapi/sgp-python/issues/1031)) ([642b51e](https://github.com/scaleapi/sgp-python/commit/642b51eb288fc2804d6e1954f2e9237559e2c60d))
* **api:** OpenAPI spec update via Stainless API ([#1032](https://github.com/scaleapi/sgp-python/issues/1032)) ([60059d1](https://github.com/scaleapi/sgp-python/commit/60059d16562c78d87e140ae4a1404341db1ce64d))
* **api:** OpenAPI spec update via Stainless API ([#1033](https://github.com/scaleapi/sgp-python/issues/1033)) ([5bb38a5](https://github.com/scaleapi/sgp-python/commit/5bb38a544f4502d6ea0a2b18e0d31d3620be3179))
* **api:** OpenAPI spec update via Stainless API ([#1034](https://github.com/scaleapi/sgp-python/issues/1034)) ([1a74663](https://github.com/scaleapi/sgp-python/commit/1a74663eeff9f5f0dd3c87839e55c4ef0eb79e88))
* **api:** OpenAPI spec update via Stainless API ([#1035](https://github.com/scaleapi/sgp-python/issues/1035)) ([f563ffe](https://github.com/scaleapi/sgp-python/commit/f563ffe6470eb397f850057f9877c7618e92c86c))
* **api:** OpenAPI spec update via Stainless API ([#1036](https://github.com/scaleapi/sgp-python/issues/1036)) ([f1d88a4](https://github.com/scaleapi/sgp-python/commit/f1d88a469dc122634c2505d3eb1203e5504d2f13))
* **api:** OpenAPI spec update via Stainless API ([#1037](https://github.com/scaleapi/sgp-python/issues/1037)) ([f22256e](https://github.com/scaleapi/sgp-python/commit/f22256e7ef9af16bc04a2c8e8b023d9e512c067d))
* **api:** OpenAPI spec update via Stainless API ([#1038](https://github.com/scaleapi/sgp-python/issues/1038)) ([1a5a98d](https://github.com/scaleapi/sgp-python/commit/1a5a98d058792f598ed8813f68cd3ac20c5e12eb))
* **api:** OpenAPI spec update via Stainless API ([#1040](https://github.com/scaleapi/sgp-python/issues/1040)) ([229339d](https://github.com/scaleapi/sgp-python/commit/229339da36411744da2b37d53b0f579cd5b64779))
* **api:** OpenAPI spec update via Stainless API ([#1041](https://github.com/scaleapi/sgp-python/issues/1041)) ([c8de49e](https://github.com/scaleapi/sgp-python/commit/c8de49ee3a2dba9114e82e173a1ec2d586c14baa))
* **api:** update via SDK Studio ([#1016](https://github.com/scaleapi/sgp-python/issues/1016)) ([a796121](https://github.com/scaleapi/sgp-python/commit/a796121916187369134856a6bd098ad6d9a1505b))
* **api:** update via SDK Studio ([#1039](https://github.com/scaleapi/sgp-python/issues/1039)) ([80d081f](https://github.com/scaleapi/sgp-python/commit/80d081fc7f7cd6e1ab32928afee4a854f6daff34))
* **api:** update via SDK Studio ([#1042](https://github.com/scaleapi/sgp-python/issues/1042)) ([144e6e8](https://github.com/scaleapi/sgp-python/commit/144e6e8878a580c3ece671e9bc284f3f3d96d459))

## 0.1.0-alpha.24 (2024-08-14)

Full Changelog: [v0.1.0-alpha.23...v0.1.0-alpha.24](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.23...v0.1.0-alpha.24)

### Features

* **api:** OpenAPI spec update via Stainless API ([#1000](https://github.com/scaleapi/sgp-python/issues/1000)) ([64dbe42](https://github.com/scaleapi/sgp-python/commit/64dbe420d6fe6794207261cc0964242d256a83f3))
* **api:** OpenAPI spec update via Stainless API ([#1001](https://github.com/scaleapi/sgp-python/issues/1001)) ([519b608](https://github.com/scaleapi/sgp-python/commit/519b6081d6234dd64f541b5292507d83fe5f8686))
* **api:** OpenAPI spec update via Stainless API ([#1002](https://github.com/scaleapi/sgp-python/issues/1002)) ([910b285](https://github.com/scaleapi/sgp-python/commit/910b285335ce3519629d5493eae47b2913ba3d0d))
* **api:** OpenAPI spec update via Stainless API ([#1003](https://github.com/scaleapi/sgp-python/issues/1003)) ([2dc0045](https://github.com/scaleapi/sgp-python/commit/2dc004587169a6f202b778f5b19ae3e3e2a534e8))
* **api:** OpenAPI spec update via Stainless API ([#1004](https://github.com/scaleapi/sgp-python/issues/1004)) ([48b39fa](https://github.com/scaleapi/sgp-python/commit/48b39fade4b513fe966a5d39fb9c3d34a600c5c1))
* **api:** OpenAPI spec update via Stainless API ([#1005](https://github.com/scaleapi/sgp-python/issues/1005)) ([0c00a98](https://github.com/scaleapi/sgp-python/commit/0c00a98a87048d04778445307fc1a7215f67723d))
* **api:** OpenAPI spec update via Stainless API ([#1006](https://github.com/scaleapi/sgp-python/issues/1006)) ([eb53cf7](https://github.com/scaleapi/sgp-python/commit/eb53cf7d222bc6ecb6aa5b5689054daa974d44ab))
* **api:** OpenAPI spec update via Stainless API ([#1007](https://github.com/scaleapi/sgp-python/issues/1007)) ([6de4328](https://github.com/scaleapi/sgp-python/commit/6de43281c2e95e4f5b6041ceef61eebeb88abcd6))
* **api:** OpenAPI spec update via Stainless API ([#1008](https://github.com/scaleapi/sgp-python/issues/1008)) ([804d404](https://github.com/scaleapi/sgp-python/commit/804d404dc521ddccbeb2ce09bd3dcf025fa3f0da))
* **api:** OpenAPI spec update via Stainless API ([#1009](https://github.com/scaleapi/sgp-python/issues/1009)) ([003c469](https://github.com/scaleapi/sgp-python/commit/003c469c3a76219c53b0971227511edc60991569))
* **api:** OpenAPI spec update via Stainless API ([#1010](https://github.com/scaleapi/sgp-python/issues/1010)) ([eb29ab6](https://github.com/scaleapi/sgp-python/commit/eb29ab6a020e8ddce6c3127f0636e426e968c07c))
* **api:** OpenAPI spec update via Stainless API ([#1011](https://github.com/scaleapi/sgp-python/issues/1011)) ([e36bd8c](https://github.com/scaleapi/sgp-python/commit/e36bd8cedc9cdb3a07a82855e13583fc9e196057))
* **api:** OpenAPI spec update via Stainless API ([#1012](https://github.com/scaleapi/sgp-python/issues/1012)) ([dbde75d](https://github.com/scaleapi/sgp-python/commit/dbde75df6938f88cda5613264bad87a002a36192))
* **api:** OpenAPI spec update via Stainless API ([#1013](https://github.com/scaleapi/sgp-python/issues/1013)) ([4b7eadd](https://github.com/scaleapi/sgp-python/commit/4b7eadd061e7cd97784250ae214adce3fcd7334e))
* **api:** OpenAPI spec update via Stainless API ([#993](https://github.com/scaleapi/sgp-python/issues/993)) ([b2375d3](https://github.com/scaleapi/sgp-python/commit/b2375d3554a9da3cca14af148867ad273a120941))
* **api:** OpenAPI spec update via Stainless API ([#994](https://github.com/scaleapi/sgp-python/issues/994)) ([f94ede9](https://github.com/scaleapi/sgp-python/commit/f94ede98f40d94481f6844e4d07bbdddb444e010))
* **api:** OpenAPI spec update via Stainless API ([#995](https://github.com/scaleapi/sgp-python/issues/995)) ([9aed993](https://github.com/scaleapi/sgp-python/commit/9aed99363916446fd2b22a52478becec2a18bf82))
* **api:** OpenAPI spec update via Stainless API ([#996](https://github.com/scaleapi/sgp-python/issues/996)) ([ccf011a](https://github.com/scaleapi/sgp-python/commit/ccf011a27bb6f73ba7e47cdde1d06c4fa2fb910e))
* **api:** OpenAPI spec update via Stainless API ([#997](https://github.com/scaleapi/sgp-python/issues/997)) ([70e92fc](https://github.com/scaleapi/sgp-python/commit/70e92fc9662bd26dfe077e9a7e048718e39e75d8))
* **api:** OpenAPI spec update via Stainless API ([#998](https://github.com/scaleapi/sgp-python/issues/998)) ([71fab16](https://github.com/scaleapi/sgp-python/commit/71fab166d630717bdf3d9475a9fe037e590021be))
* **api:** OpenAPI spec update via Stainless API ([#999](https://github.com/scaleapi/sgp-python/issues/999)) ([e37b78b](https://github.com/scaleapi/sgp-python/commit/e37b78bebc5d04027140dcaf614ddb3c010854e7))
* **api:** update via SDK Studio ([#1014](https://github.com/scaleapi/sgp-python/issues/1014)) ([9b306c1](https://github.com/scaleapi/sgp-python/commit/9b306c196880ab332eaadcd02202f86db6e9fd5b))
* **api:** update via SDK Studio ([#991](https://github.com/scaleapi/sgp-python/issues/991)) ([c5d818a](https://github.com/scaleapi/sgp-python/commit/c5d818a38090ae70a16a56bf9438b2fd2e6b1821))

## 0.1.0-alpha.23 (2024-08-13)

Full Changelog: [v0.1.0-alpha.22...v0.1.0-alpha.23](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.22...v0.1.0-alpha.23)

### Features

* **api:** OpenAPI spec update via Stainless API ([#970](https://github.com/scaleapi/sgp-python/issues/970)) ([b0b5eff](https://github.com/scaleapi/sgp-python/commit/b0b5effce8cd781159858cd2fafe7790843689f8))
* **api:** OpenAPI spec update via Stainless API ([#971](https://github.com/scaleapi/sgp-python/issues/971)) ([a3363cc](https://github.com/scaleapi/sgp-python/commit/a3363ccf86789f681a067756b0fd05687052d478))
* **api:** OpenAPI spec update via Stainless API ([#972](https://github.com/scaleapi/sgp-python/issues/972)) ([6dedbc5](https://github.com/scaleapi/sgp-python/commit/6dedbc59ae12383d7da1ce7419efbe19f1270774))
* **api:** OpenAPI spec update via Stainless API ([#973](https://github.com/scaleapi/sgp-python/issues/973)) ([410007b](https://github.com/scaleapi/sgp-python/commit/410007bf2e15274f276b08f16ecd7291a0ae3d11))
* **api:** OpenAPI spec update via Stainless API ([#974](https://github.com/scaleapi/sgp-python/issues/974)) ([61d2fcb](https://github.com/scaleapi/sgp-python/commit/61d2fcb5996e404301940b2c592aaf16ec24fccd))
* **api:** OpenAPI spec update via Stainless API ([#975](https://github.com/scaleapi/sgp-python/issues/975)) ([9fa9ed1](https://github.com/scaleapi/sgp-python/commit/9fa9ed17fa071171d444b369a0bd66739718493b))
* **api:** OpenAPI spec update via Stainless API ([#976](https://github.com/scaleapi/sgp-python/issues/976)) ([bf93fb7](https://github.com/scaleapi/sgp-python/commit/bf93fb7a70fe75d1f897b044b57b492fee42774a))
* **api:** OpenAPI spec update via Stainless API ([#977](https://github.com/scaleapi/sgp-python/issues/977)) ([cc4ac35](https://github.com/scaleapi/sgp-python/commit/cc4ac35c2c65f301c18bb50ce97a100f7c3284b7))
* **api:** OpenAPI spec update via Stainless API ([#978](https://github.com/scaleapi/sgp-python/issues/978)) ([632c7cf](https://github.com/scaleapi/sgp-python/commit/632c7cfefa2c528fe7730aaed458c10cc9d42759))
* **api:** OpenAPI spec update via Stainless API ([#979](https://github.com/scaleapi/sgp-python/issues/979)) ([c86630d](https://github.com/scaleapi/sgp-python/commit/c86630decba14255bb9ca86888c4d747e7f85440))
* **api:** OpenAPI spec update via Stainless API ([#980](https://github.com/scaleapi/sgp-python/issues/980)) ([4bed52f](https://github.com/scaleapi/sgp-python/commit/4bed52f7269fd3d85672e653ccd8778eafc17f8a))
* **api:** OpenAPI spec update via Stainless API ([#981](https://github.com/scaleapi/sgp-python/issues/981)) ([9fc1afe](https://github.com/scaleapi/sgp-python/commit/9fc1afee6dc18f8dc6bd5dc0161e6ee89aa02e63))
* **api:** OpenAPI spec update via Stainless API ([#982](https://github.com/scaleapi/sgp-python/issues/982)) ([ccdf42f](https://github.com/scaleapi/sgp-python/commit/ccdf42f7be1f6801169a46735c2781c0e58c216e))
* **api:** OpenAPI spec update via Stainless API ([#983](https://github.com/scaleapi/sgp-python/issues/983)) ([9bf4aa0](https://github.com/scaleapi/sgp-python/commit/9bf4aa0ec2fd3798714bc782e89fb113011a5cf5))
* **api:** OpenAPI spec update via Stainless API ([#984](https://github.com/scaleapi/sgp-python/issues/984)) ([19c4acc](https://github.com/scaleapi/sgp-python/commit/19c4acc673cd516d0db1dbea57fd3762426cacc2))
* **api:** OpenAPI spec update via Stainless API ([#985](https://github.com/scaleapi/sgp-python/issues/985)) ([560de2c](https://github.com/scaleapi/sgp-python/commit/560de2ccaf3ec4f661795bc26a03ae68b9c661dd))
* **api:** OpenAPI spec update via Stainless API ([#987](https://github.com/scaleapi/sgp-python/issues/987)) ([ed3ade0](https://github.com/scaleapi/sgp-python/commit/ed3ade0208ddfe8b0c5eb86ea45676d3dd0b598d))
* **api:** OpenAPI spec update via Stainless API ([#988](https://github.com/scaleapi/sgp-python/issues/988)) ([0c6fcdd](https://github.com/scaleapi/sgp-python/commit/0c6fcdd1799de9711c29005d9b1c981599269919))
* **api:** update via SDK Studio ([#986](https://github.com/scaleapi/sgp-python/issues/986)) ([19a08da](https://github.com/scaleapi/sgp-python/commit/19a08daa4f2c46943360fa3d7da6ee5c9e3e8def))
* **api:** update via SDK Studio ([#989](https://github.com/scaleapi/sgp-python/issues/989)) ([319aaaa](https://github.com/scaleapi/sgp-python/commit/319aaaae2737a17ac5df532b424472f68e8fd1c6))


### Chores

* **examples:** minor formatting changes ([#968](https://github.com/scaleapi/sgp-python/issues/968)) ([e42234c](https://github.com/scaleapi/sgp-python/commit/e42234c3c4eea775b3a7fab7f728a3146ad3b32f))

## 0.1.0-alpha.22 (2024-08-12)

Full Changelog: [v0.1.0-alpha.21...v0.1.0-alpha.22](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.21...v0.1.0-alpha.22)

### Features

* **api:** OpenAPI spec update via Stainless API ([#962](https://github.com/scaleapi/sgp-python/issues/962)) ([87c3a1e](https://github.com/scaleapi/sgp-python/commit/87c3a1e276cba4e9fb081ed9f5739aa62e454ee1))
* **api:** OpenAPI spec update via Stainless API ([#966](https://github.com/scaleapi/sgp-python/issues/966)) ([925f6cc](https://github.com/scaleapi/sgp-python/commit/925f6cc4b4e8d4789dc9f273270b7b1637535ddb))


### Chores

* **internal:** update some imports ([#965](https://github.com/scaleapi/sgp-python/issues/965)) ([296335e](https://github.com/scaleapi/sgp-python/commit/296335e430fd25eb672cec12b8267d45ff309040))

## 0.1.0-alpha.21 (2024-08-12)

Full Changelog: [v0.1.0-alpha.20...v0.1.0-alpha.21](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.20...v0.1.0-alpha.21)

### Features

* **api:** OpenAPI spec update via Stainless API ([#851](https://github.com/scaleapi/sgp-python/issues/851)) ([7fdbc3e](https://github.com/scaleapi/sgp-python/commit/7fdbc3e973bd33374042367c444c1b604435366e))
* **api:** OpenAPI spec update via Stainless API ([#852](https://github.com/scaleapi/sgp-python/issues/852)) ([c0d3ff8](https://github.com/scaleapi/sgp-python/commit/c0d3ff8d20e7b64c89b5dcae59241edc346f37bf))
* **api:** OpenAPI spec update via Stainless API ([#853](https://github.com/scaleapi/sgp-python/issues/853)) ([edcb36c](https://github.com/scaleapi/sgp-python/commit/edcb36c5d244f5c43c7e0a7d4c0ecc9a66369c65))
* **api:** OpenAPI spec update via Stainless API ([#854](https://github.com/scaleapi/sgp-python/issues/854)) ([1437274](https://github.com/scaleapi/sgp-python/commit/1437274e6c2efe769c50e5c379c29d34813a01c5))
* **api:** OpenAPI spec update via Stainless API ([#855](https://github.com/scaleapi/sgp-python/issues/855)) ([dfa034b](https://github.com/scaleapi/sgp-python/commit/dfa034bd6be9b50d6de4ecd5a91b2d4024a90121))
* **api:** OpenAPI spec update via Stainless API ([#856](https://github.com/scaleapi/sgp-python/issues/856)) ([8052c19](https://github.com/scaleapi/sgp-python/commit/8052c197f43d2a125c409bef65a400b97ddd5354))
* **api:** OpenAPI spec update via Stainless API ([#858](https://github.com/scaleapi/sgp-python/issues/858)) ([bc80fd7](https://github.com/scaleapi/sgp-python/commit/bc80fd700697c80ce26593e4bdc35a2afebc0a83))
* **api:** OpenAPI spec update via Stainless API ([#859](https://github.com/scaleapi/sgp-python/issues/859)) ([5365b5d](https://github.com/scaleapi/sgp-python/commit/5365b5d9293694f2e4de4d74515f9cbdba39f32b))
* **api:** OpenAPI spec update via Stainless API ([#860](https://github.com/scaleapi/sgp-python/issues/860)) ([54dc8bd](https://github.com/scaleapi/sgp-python/commit/54dc8bd3a2b7439a1c8f8ea7263bbab1443d82c4))
* **api:** OpenAPI spec update via Stainless API ([#861](https://github.com/scaleapi/sgp-python/issues/861)) ([748a671](https://github.com/scaleapi/sgp-python/commit/748a671563930d587b64b7ee514cef3b426153b9))
* **api:** OpenAPI spec update via Stainless API ([#862](https://github.com/scaleapi/sgp-python/issues/862)) ([ee3ad2c](https://github.com/scaleapi/sgp-python/commit/ee3ad2cd5e64020ec01d761d084344e357c49cc4))
* **api:** OpenAPI spec update via Stainless API ([#863](https://github.com/scaleapi/sgp-python/issues/863)) ([b6d7821](https://github.com/scaleapi/sgp-python/commit/b6d7821735e33e452881bab1afd2db0b83eb0eea))
* **api:** OpenAPI spec update via Stainless API ([#864](https://github.com/scaleapi/sgp-python/issues/864)) ([fad75b2](https://github.com/scaleapi/sgp-python/commit/fad75b2f0da9c75c6aa63211c6a0c247be5c4430))
* **api:** OpenAPI spec update via Stainless API ([#865](https://github.com/scaleapi/sgp-python/issues/865)) ([7dc19f3](https://github.com/scaleapi/sgp-python/commit/7dc19f3e13feb52b37ddc84d400d54649e284dc2))
* **api:** OpenAPI spec update via Stainless API ([#866](https://github.com/scaleapi/sgp-python/issues/866)) ([fd72e37](https://github.com/scaleapi/sgp-python/commit/fd72e371b1e40aab1d4f8eecfb73d9dac5d07a6f))
* **api:** OpenAPI spec update via Stainless API ([#867](https://github.com/scaleapi/sgp-python/issues/867)) ([95b6d6d](https://github.com/scaleapi/sgp-python/commit/95b6d6d655b2e7563449f8d905195ffa31537a53))
* **api:** OpenAPI spec update via Stainless API ([#868](https://github.com/scaleapi/sgp-python/issues/868)) ([3fc93bc](https://github.com/scaleapi/sgp-python/commit/3fc93bc4ad0e48ea5c79c183c2683d2047a84f65))
* **api:** OpenAPI spec update via Stainless API ([#869](https://github.com/scaleapi/sgp-python/issues/869)) ([7a09465](https://github.com/scaleapi/sgp-python/commit/7a09465cc5de3754b97341d65690707d8727c5e3))
* **api:** OpenAPI spec update via Stainless API ([#871](https://github.com/scaleapi/sgp-python/issues/871)) ([530d0ad](https://github.com/scaleapi/sgp-python/commit/530d0adfa18d311b39376dd4df3b8cc2bf8f074c))
* **api:** OpenAPI spec update via Stainless API ([#872](https://github.com/scaleapi/sgp-python/issues/872)) ([9bd6569](https://github.com/scaleapi/sgp-python/commit/9bd65698d72221eab640bfc623cf7cd46ed56ebe))
* **api:** OpenAPI spec update via Stainless API ([#873](https://github.com/scaleapi/sgp-python/issues/873)) ([e1368db](https://github.com/scaleapi/sgp-python/commit/e1368dbc4f220a2333b3b8c9e7c5978ff971be07))
* **api:** OpenAPI spec update via Stainless API ([#874](https://github.com/scaleapi/sgp-python/issues/874)) ([6e12998](https://github.com/scaleapi/sgp-python/commit/6e12998898029e9c506f68ad4cbc82030d44db24))
* **api:** OpenAPI spec update via Stainless API ([#875](https://github.com/scaleapi/sgp-python/issues/875)) ([4b003a8](https://github.com/scaleapi/sgp-python/commit/4b003a8e773c22714beb7c1d3cd4311b7e01c4c0))
* **api:** OpenAPI spec update via Stainless API ([#876](https://github.com/scaleapi/sgp-python/issues/876)) ([98efa7d](https://github.com/scaleapi/sgp-python/commit/98efa7db18d3ab5c4e1b094a43f9047195c3e7a8))
* **api:** OpenAPI spec update via Stainless API ([#877](https://github.com/scaleapi/sgp-python/issues/877)) ([cbf3cd9](https://github.com/scaleapi/sgp-python/commit/cbf3cd95d266b4b049a055421299a6061f873476))
* **api:** OpenAPI spec update via Stainless API ([#878](https://github.com/scaleapi/sgp-python/issues/878)) ([2235536](https://github.com/scaleapi/sgp-python/commit/22355363dc9afea7c13fb50e396b1add08c25139))
* **api:** OpenAPI spec update via Stainless API ([#879](https://github.com/scaleapi/sgp-python/issues/879)) ([e4efbf0](https://github.com/scaleapi/sgp-python/commit/e4efbf0b8ead2d2665c0ac2934a73179dc2bc6eb))
* **api:** OpenAPI spec update via Stainless API ([#880](https://github.com/scaleapi/sgp-python/issues/880)) ([6a41536](https://github.com/scaleapi/sgp-python/commit/6a415361133e4aa4851a8e5ec36cfe81a7adf4cf))
* **api:** OpenAPI spec update via Stainless API ([#881](https://github.com/scaleapi/sgp-python/issues/881)) ([57e51d9](https://github.com/scaleapi/sgp-python/commit/57e51d9abc66be5d4b89652ac3f88e6c748d3e3a))
* **api:** OpenAPI spec update via Stainless API ([#882](https://github.com/scaleapi/sgp-python/issues/882)) ([544af8e](https://github.com/scaleapi/sgp-python/commit/544af8efdcd95b0136c53eb49839a27739cd0db0))
* **api:** OpenAPI spec update via Stainless API ([#883](https://github.com/scaleapi/sgp-python/issues/883)) ([2f1f3c7](https://github.com/scaleapi/sgp-python/commit/2f1f3c79b19599925af0266dd7635c88f4779ede))
* **api:** OpenAPI spec update via Stainless API ([#884](https://github.com/scaleapi/sgp-python/issues/884)) ([b1cc607](https://github.com/scaleapi/sgp-python/commit/b1cc607870b6e4501b0cfdf77c231dcb6e3633bd))
* **api:** OpenAPI spec update via Stainless API ([#885](https://github.com/scaleapi/sgp-python/issues/885)) ([0dd4bd3](https://github.com/scaleapi/sgp-python/commit/0dd4bd374042c2646ffe00f8cd3831c2568073eb))
* **api:** OpenAPI spec update via Stainless API ([#886](https://github.com/scaleapi/sgp-python/issues/886)) ([f9cbea8](https://github.com/scaleapi/sgp-python/commit/f9cbea8b71edd4ffd39fe14869d284353eabebd5))
* **api:** OpenAPI spec update via Stainless API ([#887](https://github.com/scaleapi/sgp-python/issues/887)) ([a1c5834](https://github.com/scaleapi/sgp-python/commit/a1c58346e7d8f6a90a41ad945272838c5a2adf89))
* **api:** OpenAPI spec update via Stainless API ([#888](https://github.com/scaleapi/sgp-python/issues/888)) ([69bad9b](https://github.com/scaleapi/sgp-python/commit/69bad9bce1f68939b6a67f42afa233114d59551e))
* **api:** OpenAPI spec update via Stainless API ([#889](https://github.com/scaleapi/sgp-python/issues/889)) ([eee0eb0](https://github.com/scaleapi/sgp-python/commit/eee0eb02e1e5ed7d1330d6548004fd0f882c5045))
* **api:** OpenAPI spec update via Stainless API ([#890](https://github.com/scaleapi/sgp-python/issues/890)) ([738cb50](https://github.com/scaleapi/sgp-python/commit/738cb50f1def76be00e5d3d31711716e872f9751))
* **api:** OpenAPI spec update via Stainless API ([#891](https://github.com/scaleapi/sgp-python/issues/891)) ([fc602e1](https://github.com/scaleapi/sgp-python/commit/fc602e1c402c47b5a3f92fed18cf5a1a637ea489))
* **api:** OpenAPI spec update via Stainless API ([#892](https://github.com/scaleapi/sgp-python/issues/892)) ([cf61d18](https://github.com/scaleapi/sgp-python/commit/cf61d18d13bbf20914f5865e400cc04d0510f248))
* **api:** OpenAPI spec update via Stainless API ([#893](https://github.com/scaleapi/sgp-python/issues/893)) ([1ae8d58](https://github.com/scaleapi/sgp-python/commit/1ae8d58bac213124ec1a7e2bc08b12cdecf532f9))
* **api:** OpenAPI spec update via Stainless API ([#894](https://github.com/scaleapi/sgp-python/issues/894)) ([ea9c680](https://github.com/scaleapi/sgp-python/commit/ea9c6801cf0f75c0d6ace3e786b0a59353c44805))
* **api:** OpenAPI spec update via Stainless API ([#895](https://github.com/scaleapi/sgp-python/issues/895)) ([e9cce02](https://github.com/scaleapi/sgp-python/commit/e9cce02e2275b290cce72a830210f1732e220704))
* **api:** OpenAPI spec update via Stainless API ([#896](https://github.com/scaleapi/sgp-python/issues/896)) ([847b64f](https://github.com/scaleapi/sgp-python/commit/847b64fe11e29229ec02cd00800b6c1d9a9959f9))
* **api:** OpenAPI spec update via Stainless API ([#897](https://github.com/scaleapi/sgp-python/issues/897)) ([175477a](https://github.com/scaleapi/sgp-python/commit/175477a5e9cb535d8189df30b206dd1e367419a7))
* **api:** OpenAPI spec update via Stainless API ([#902](https://github.com/scaleapi/sgp-python/issues/902)) ([26e121e](https://github.com/scaleapi/sgp-python/commit/26e121e1899f7e851e0a88addacd84f8d94b1fb4))
* **api:** OpenAPI spec update via Stainless API ([#905](https://github.com/scaleapi/sgp-python/issues/905)) ([d527218](https://github.com/scaleapi/sgp-python/commit/d527218f5eac0e7e622f86b0bbfcf04e9ed7ed52))
* **api:** OpenAPI spec update via Stainless API ([#906](https://github.com/scaleapi/sgp-python/issues/906)) ([5db9ab5](https://github.com/scaleapi/sgp-python/commit/5db9ab5ba45bdd83607b981ef6b54cd025b72790))
* **api:** OpenAPI spec update via Stainless API ([#908](https://github.com/scaleapi/sgp-python/issues/908)) ([001dea6](https://github.com/scaleapi/sgp-python/commit/001dea695d0a74440013c4b25c04538b63162674))
* **api:** OpenAPI spec update via Stainless API ([#909](https://github.com/scaleapi/sgp-python/issues/909)) ([9fd0880](https://github.com/scaleapi/sgp-python/commit/9fd088020266d11e8cf48546678036a8002b4d67))
* **api:** OpenAPI spec update via Stainless API ([#910](https://github.com/scaleapi/sgp-python/issues/910)) ([3474491](https://github.com/scaleapi/sgp-python/commit/347449163431792ad2fa4e1379cc34fdfdebfa8e))
* **api:** OpenAPI spec update via Stainless API ([#911](https://github.com/scaleapi/sgp-python/issues/911)) ([b5d5903](https://github.com/scaleapi/sgp-python/commit/b5d590352333b19977da77e6a56f5730e0715281))
* **api:** OpenAPI spec update via Stainless API ([#912](https://github.com/scaleapi/sgp-python/issues/912)) ([525a73f](https://github.com/scaleapi/sgp-python/commit/525a73f92eabc3a7ba602f053347e84786eaa5ef))
* **api:** OpenAPI spec update via Stainless API ([#913](https://github.com/scaleapi/sgp-python/issues/913)) ([dfaddcb](https://github.com/scaleapi/sgp-python/commit/dfaddcb9ddc6546bd7319a728159caaf1a974d6c))
* **api:** OpenAPI spec update via Stainless API ([#914](https://github.com/scaleapi/sgp-python/issues/914)) ([97984bf](https://github.com/scaleapi/sgp-python/commit/97984bf53af6ee9e67e6232320bb74dd8b3cad69))
* **api:** OpenAPI spec update via Stainless API ([#915](https://github.com/scaleapi/sgp-python/issues/915)) ([27256cf](https://github.com/scaleapi/sgp-python/commit/27256cfada22026cb2fcd024bdc472b4f6b8c1f1))
* **api:** OpenAPI spec update via Stainless API ([#916](https://github.com/scaleapi/sgp-python/issues/916)) ([f0c6a4b](https://github.com/scaleapi/sgp-python/commit/f0c6a4bb9d2342f800219bee95c81702ab3d407c))
* **api:** OpenAPI spec update via Stainless API ([#917](https://github.com/scaleapi/sgp-python/issues/917)) ([0d5693e](https://github.com/scaleapi/sgp-python/commit/0d5693ebd9b0b058511b55f146f00d8e58ac1c5c))
* **api:** OpenAPI spec update via Stainless API ([#918](https://github.com/scaleapi/sgp-python/issues/918)) ([df07104](https://github.com/scaleapi/sgp-python/commit/df071043991589796648d5679af9f2f5ade79c48))
* **api:** OpenAPI spec update via Stainless API ([#919](https://github.com/scaleapi/sgp-python/issues/919)) ([465d618](https://github.com/scaleapi/sgp-python/commit/465d618053e63647bcf75c5cfc29c1b508f48454))
* **api:** OpenAPI spec update via Stainless API ([#920](https://github.com/scaleapi/sgp-python/issues/920)) ([919f702](https://github.com/scaleapi/sgp-python/commit/919f702e1ba2ec39b8d90bdf633d8d1da2bfb06b))
* **api:** OpenAPI spec update via Stainless API ([#921](https://github.com/scaleapi/sgp-python/issues/921)) ([b04f1d8](https://github.com/scaleapi/sgp-python/commit/b04f1d8085d42f5ff251767fb392f916f2eaea63))
* **api:** OpenAPI spec update via Stainless API ([#922](https://github.com/scaleapi/sgp-python/issues/922)) ([fa1a34c](https://github.com/scaleapi/sgp-python/commit/fa1a34c65544159e15d9bb83248a4fee6c430933))
* **api:** OpenAPI spec update via Stainless API ([#923](https://github.com/scaleapi/sgp-python/issues/923)) ([3e8b2f9](https://github.com/scaleapi/sgp-python/commit/3e8b2f95dde319e9115d46ebb5e07e2243ac3d0d))
* **api:** OpenAPI spec update via Stainless API ([#924](https://github.com/scaleapi/sgp-python/issues/924)) ([a5fa3f2](https://github.com/scaleapi/sgp-python/commit/a5fa3f2eca6138b803e4bc64d96a4a6bee918f05))
* **api:** OpenAPI spec update via Stainless API ([#925](https://github.com/scaleapi/sgp-python/issues/925)) ([ccf4254](https://github.com/scaleapi/sgp-python/commit/ccf4254bb82b3f161a6747d235c535b96ddf47b1))
* **api:** OpenAPI spec update via Stainless API ([#926](https://github.com/scaleapi/sgp-python/issues/926)) ([b9737f4](https://github.com/scaleapi/sgp-python/commit/b9737f4efdb7c3a21d1cac1aa056efb53a5abeca))
* **api:** OpenAPI spec update via Stainless API ([#927](https://github.com/scaleapi/sgp-python/issues/927)) ([81ebf76](https://github.com/scaleapi/sgp-python/commit/81ebf76dacc4932e8a6a20524e6e1747dc92c66e))
* **api:** OpenAPI spec update via Stainless API ([#928](https://github.com/scaleapi/sgp-python/issues/928)) ([61b2d06](https://github.com/scaleapi/sgp-python/commit/61b2d06621e6c0cdd3032c808c8c387ce1e97d58))
* **api:** OpenAPI spec update via Stainless API ([#929](https://github.com/scaleapi/sgp-python/issues/929)) ([bce50bc](https://github.com/scaleapi/sgp-python/commit/bce50bc0f7b31c9bc5f154fa6dc506754abb08f3))
* **api:** OpenAPI spec update via Stainless API ([#930](https://github.com/scaleapi/sgp-python/issues/930)) ([753fac0](https://github.com/scaleapi/sgp-python/commit/753fac08d37311786319fd99e2e4158fc9ac91f0))
* **api:** OpenAPI spec update via Stainless API ([#931](https://github.com/scaleapi/sgp-python/issues/931)) ([770a84f](https://github.com/scaleapi/sgp-python/commit/770a84fb9af4b4a8e6fa8f7dfb0f87341ddde683))
* **api:** OpenAPI spec update via Stainless API ([#932](https://github.com/scaleapi/sgp-python/issues/932)) ([61494b9](https://github.com/scaleapi/sgp-python/commit/61494b9b28830ad06c954f834537de473cacb00d))
* **api:** OpenAPI spec update via Stainless API ([#933](https://github.com/scaleapi/sgp-python/issues/933)) ([b235eee](https://github.com/scaleapi/sgp-python/commit/b235eeeafe1ed1e8d1f38e159d33287c8db605ec))
* **api:** OpenAPI spec update via Stainless API ([#934](https://github.com/scaleapi/sgp-python/issues/934)) ([ffaabb8](https://github.com/scaleapi/sgp-python/commit/ffaabb8632514e5219667e32b35537454e443e45))
* **api:** OpenAPI spec update via Stainless API ([#935](https://github.com/scaleapi/sgp-python/issues/935)) ([01644ad](https://github.com/scaleapi/sgp-python/commit/01644adcc676bb25989abb4892429cbc49f07cb1))
* **api:** OpenAPI spec update via Stainless API ([#936](https://github.com/scaleapi/sgp-python/issues/936)) ([adb4600](https://github.com/scaleapi/sgp-python/commit/adb460018077f580178d6ece7b4ff94b4eaf33db))
* **api:** OpenAPI spec update via Stainless API ([#937](https://github.com/scaleapi/sgp-python/issues/937)) ([b6c6351](https://github.com/scaleapi/sgp-python/commit/b6c63511c4188f7e1a7c3348a0c44c3c422c9e7f))
* **api:** OpenAPI spec update via Stainless API ([#938](https://github.com/scaleapi/sgp-python/issues/938)) ([e3dc1b0](https://github.com/scaleapi/sgp-python/commit/e3dc1b0ddde9f71bc23718685b205aaf8ecbe75d))
* **api:** OpenAPI spec update via Stainless API ([#939](https://github.com/scaleapi/sgp-python/issues/939)) ([ab9f5c5](https://github.com/scaleapi/sgp-python/commit/ab9f5c530f914b9eb7f392b8bf6274c7d0eb8549))
* **api:** OpenAPI spec update via Stainless API ([#940](https://github.com/scaleapi/sgp-python/issues/940)) ([63c9d7c](https://github.com/scaleapi/sgp-python/commit/63c9d7c5cb3679088f6b51a9bc692ac8e5123200))
* **api:** OpenAPI spec update via Stainless API ([#941](https://github.com/scaleapi/sgp-python/issues/941)) ([3a1d5e4](https://github.com/scaleapi/sgp-python/commit/3a1d5e43b8c647da1744c2d082bea33da182657b))
* **api:** OpenAPI spec update via Stainless API ([#942](https://github.com/scaleapi/sgp-python/issues/942)) ([a460b3a](https://github.com/scaleapi/sgp-python/commit/a460b3a7f0a59543a2f4b94cb480448c8c8c27f8))
* **api:** OpenAPI spec update via Stainless API ([#943](https://github.com/scaleapi/sgp-python/issues/943)) ([f1a174f](https://github.com/scaleapi/sgp-python/commit/f1a174fb28047228cce4b1587c5bbe69c9b63a66))
* **api:** OpenAPI spec update via Stainless API ([#944](https://github.com/scaleapi/sgp-python/issues/944)) ([e1d271c](https://github.com/scaleapi/sgp-python/commit/e1d271c0d0f1cddd9780ccd61c6afab4e699af9d))
* **api:** OpenAPI spec update via Stainless API ([#945](https://github.com/scaleapi/sgp-python/issues/945)) ([9c0019c](https://github.com/scaleapi/sgp-python/commit/9c0019c851ea4181a710ed8171e8266ec2113ba0))
* **api:** OpenAPI spec update via Stainless API ([#946](https://github.com/scaleapi/sgp-python/issues/946)) ([5a87b5f](https://github.com/scaleapi/sgp-python/commit/5a87b5fdda2497e0fefd95fb0417b988f833384d))
* **api:** OpenAPI spec update via Stainless API ([#947](https://github.com/scaleapi/sgp-python/issues/947)) ([7ba738f](https://github.com/scaleapi/sgp-python/commit/7ba738f61205afb6d96d16c4b9664803eecf76fb))
* **api:** OpenAPI spec update via Stainless API ([#948](https://github.com/scaleapi/sgp-python/issues/948)) ([7ed3f46](https://github.com/scaleapi/sgp-python/commit/7ed3f46006be1639d28e1020c01d2bc2c5cdea24))
* **api:** OpenAPI spec update via Stainless API ([#949](https://github.com/scaleapi/sgp-python/issues/949)) ([c4dd11a](https://github.com/scaleapi/sgp-python/commit/c4dd11a1f7b525488b0d91a735d221143119cf17))
* **api:** OpenAPI spec update via Stainless API ([#950](https://github.com/scaleapi/sgp-python/issues/950)) ([9eec264](https://github.com/scaleapi/sgp-python/commit/9eec264ffa7f41b979d185cf4a5dfe7bfdc35569))
* **api:** OpenAPI spec update via Stainless API ([#951](https://github.com/scaleapi/sgp-python/issues/951)) ([eef7457](https://github.com/scaleapi/sgp-python/commit/eef7457a76e293f50b89329ef85a00c1b1207047))
* **api:** OpenAPI spec update via Stainless API ([#952](https://github.com/scaleapi/sgp-python/issues/952)) ([81ec12b](https://github.com/scaleapi/sgp-python/commit/81ec12be59f59d52d3f294c671381fa61ee5253d))
* **api:** OpenAPI spec update via Stainless API ([#953](https://github.com/scaleapi/sgp-python/issues/953)) ([caf8360](https://github.com/scaleapi/sgp-python/commit/caf83608fa7e32094d9be34d456e090ab26d6bc2))
* **api:** OpenAPI spec update via Stainless API ([#954](https://github.com/scaleapi/sgp-python/issues/954)) ([30c83b3](https://github.com/scaleapi/sgp-python/commit/30c83b3a0aedf492293b072b62899477c936fa38))
* **api:** OpenAPI spec update via Stainless API ([#955](https://github.com/scaleapi/sgp-python/issues/955)) ([c59a010](https://github.com/scaleapi/sgp-python/commit/c59a010f83d44f5e11df929fc083436389699c7b))
* **api:** OpenAPI spec update via Stainless API ([#956](https://github.com/scaleapi/sgp-python/issues/956)) ([734774a](https://github.com/scaleapi/sgp-python/commit/734774abe7a1c9df358492e50b1a1bd4e775176c))
* **api:** OpenAPI spec update via Stainless API ([#957](https://github.com/scaleapi/sgp-python/issues/957)) ([2a14fbe](https://github.com/scaleapi/sgp-python/commit/2a14fbefac40ea92a036ea2202b7003a5ae5f0f4))
* **api:** OpenAPI spec update via Stainless API ([#958](https://github.com/scaleapi/sgp-python/issues/958)) ([7379119](https://github.com/scaleapi/sgp-python/commit/73791192027967122a5cbed222a066a01a7ca1eb))
* **api:** OpenAPI spec update via Stainless API ([#959](https://github.com/scaleapi/sgp-python/issues/959)) ([ac7ffa4](https://github.com/scaleapi/sgp-python/commit/ac7ffa4b1058b804e11a38c966e6784bf61eb805))
* **api:** OpenAPI spec update via Stainless API ([#960](https://github.com/scaleapi/sgp-python/issues/960)) ([cf8ff13](https://github.com/scaleapi/sgp-python/commit/cf8ff134c3fcc6d9f35ed6ffe87736ba5e0d683b))
* **api:** update via SDK Studio ([#847](https://github.com/scaleapi/sgp-python/issues/847)) ([04519b6](https://github.com/scaleapi/sgp-python/commit/04519b66719679bf36867682a91a1ff45e093414))
* **api:** update via SDK Studio ([#899](https://github.com/scaleapi/sgp-python/issues/899)) ([c597bd8](https://github.com/scaleapi/sgp-python/commit/c597bd87d52eb2509152b0727067cb13fe480020))
* **api:** update via SDK Studio ([#901](https://github.com/scaleapi/sgp-python/issues/901)) ([b8bf627](https://github.com/scaleapi/sgp-python/commit/b8bf6271e159c8bf5c5cffac1c3600062d6aa8c5))
* **api:** update via SDK Studio ([#903](https://github.com/scaleapi/sgp-python/issues/903)) ([7fc9e6c](https://github.com/scaleapi/sgp-python/commit/7fc9e6c8cc65b18a9c5ec941cf7bef524e796266))
* **api:** update via SDK Studio ([#904](https://github.com/scaleapi/sgp-python/issues/904)) ([9317c3f](https://github.com/scaleapi/sgp-python/commit/9317c3f1314b1e9d0ca32f7778b70790a950029c))
* **api:** update via SDK Studio ([#907](https://github.com/scaleapi/sgp-python/issues/907)) ([b22f5f2](https://github.com/scaleapi/sgp-python/commit/b22f5f2e5c52663c6bd0b3dd3f2bc86c5562353c))


### Bug Fixes

* **client:** correctly serialise array body params ([#849](https://github.com/scaleapi/sgp-python/issues/849)) ([e6e2c64](https://github.com/scaleapi/sgp-python/commit/e6e2c640a75c476383d1984f23e29f50be37aab4))


### Chores

* **ci:** bump prism mock server version ([#898](https://github.com/scaleapi/sgp-python/issues/898)) ([3a056a0](https://github.com/scaleapi/sgp-python/commit/3a056a0518a9bb079c44d6cb7c40f9d7270435fe))
* **internal:** codegen related update ([#961](https://github.com/scaleapi/sgp-python/issues/961)) ([d314654](https://github.com/scaleapi/sgp-python/commit/d31465458b3204832b22265f2a63c3dafd479601))
* **internal:** ensure package is importable in lint cmd ([#900](https://github.com/scaleapi/sgp-python/issues/900)) ([b22df1c](https://github.com/scaleapi/sgp-python/commit/b22df1c829bd8d8fd887c14412255d168b602f90))
* **internal:** remove deprecated ruff config ([#870](https://github.com/scaleapi/sgp-python/issues/870)) ([ae0a230](https://github.com/scaleapi/sgp-python/commit/ae0a2301fcffa915d65d76c62a8d01a3b3196c54))

## 0.1.0-alpha.20 (2024-08-07)

Full Changelog: [v0.1.0-alpha.19...v0.1.0-alpha.20](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.19...v0.1.0-alpha.20)

### Features

* **api:** OpenAPI spec update via Stainless API ([#665](https://github.com/scaleapi/sgp-python/issues/665)) ([1cc5547](https://github.com/scaleapi/sgp-python/commit/1cc5547dfaff4b5566217cbb2c4080d491334dce))
* **api:** OpenAPI spec update via Stainless API ([#669](https://github.com/scaleapi/sgp-python/issues/669)) ([944fccf](https://github.com/scaleapi/sgp-python/commit/944fccfe9625cd32e2c696e566e7d8206066c3b0))
* **api:** OpenAPI spec update via Stainless API ([#670](https://github.com/scaleapi/sgp-python/issues/670)) ([837e611](https://github.com/scaleapi/sgp-python/commit/837e611f67f8fc3d5b7ef23e27e84fc653d373a0))
* **api:** OpenAPI spec update via Stainless API ([#671](https://github.com/scaleapi/sgp-python/issues/671)) ([ba1fc34](https://github.com/scaleapi/sgp-python/commit/ba1fc34691b1190efd3fa40b40757df067e147a6))
* **api:** OpenAPI spec update via Stainless API ([#672](https://github.com/scaleapi/sgp-python/issues/672)) ([14c02dd](https://github.com/scaleapi/sgp-python/commit/14c02dd06708dae42c371b4d5f69408c9ffe77fa))
* **api:** OpenAPI spec update via Stainless API ([#673](https://github.com/scaleapi/sgp-python/issues/673)) ([0342b65](https://github.com/scaleapi/sgp-python/commit/0342b656bf4a6001649263a3673fdf1a7b849f31))
* **api:** OpenAPI spec update via Stainless API ([#674](https://github.com/scaleapi/sgp-python/issues/674)) ([00b4bb2](https://github.com/scaleapi/sgp-python/commit/00b4bb2153f16cbd761acdadd69f1fa2de950638))
* **api:** OpenAPI spec update via Stainless API ([#675](https://github.com/scaleapi/sgp-python/issues/675)) ([a253dc4](https://github.com/scaleapi/sgp-python/commit/a253dc40646c43579e73085709f4ef8f99714a37))
* **api:** OpenAPI spec update via Stainless API ([#676](https://github.com/scaleapi/sgp-python/issues/676)) ([a9d1431](https://github.com/scaleapi/sgp-python/commit/a9d1431d23cdf84bb2a0831d66a9b987efdb7f7a))
* **api:** OpenAPI spec update via Stainless API ([#677](https://github.com/scaleapi/sgp-python/issues/677)) ([3582708](https://github.com/scaleapi/sgp-python/commit/3582708cf78ca148fbbba080cb8d2955c8b86796))
* **api:** OpenAPI spec update via Stainless API ([#678](https://github.com/scaleapi/sgp-python/issues/678)) ([fdefe0b](https://github.com/scaleapi/sgp-python/commit/fdefe0b63b380a3e75ee267a79dae82dc647f77e))
* **api:** OpenAPI spec update via Stainless API ([#679](https://github.com/scaleapi/sgp-python/issues/679)) ([5e5e2e6](https://github.com/scaleapi/sgp-python/commit/5e5e2e69f50e11e6dda0f1b0845ff3a9fd2e5bcf))
* **api:** OpenAPI spec update via Stainless API ([#680](https://github.com/scaleapi/sgp-python/issues/680)) ([04e76f9](https://github.com/scaleapi/sgp-python/commit/04e76f95b440f5ea1365b834163a692877aeda67))
* **api:** OpenAPI spec update via Stainless API ([#681](https://github.com/scaleapi/sgp-python/issues/681)) ([c46375b](https://github.com/scaleapi/sgp-python/commit/c46375b63e734e9bf2d99f54e138d3b56c2fb13c))
* **api:** OpenAPI spec update via Stainless API ([#682](https://github.com/scaleapi/sgp-python/issues/682)) ([c939759](https://github.com/scaleapi/sgp-python/commit/c939759d73aef7bc06901223aef56a7954bd1f0b))
* **api:** OpenAPI spec update via Stainless API ([#683](https://github.com/scaleapi/sgp-python/issues/683)) ([8aafcf2](https://github.com/scaleapi/sgp-python/commit/8aafcf2e710231d1da071d7395c2fbb66dab7bac))
* **api:** OpenAPI spec update via Stainless API ([#684](https://github.com/scaleapi/sgp-python/issues/684)) ([532e85c](https://github.com/scaleapi/sgp-python/commit/532e85c731aa451211d0e1ab518a5a10ea2a58b8))
* **api:** OpenAPI spec update via Stainless API ([#685](https://github.com/scaleapi/sgp-python/issues/685)) ([53350f4](https://github.com/scaleapi/sgp-python/commit/53350f4cbb2823a6b8e821b08055f3683b1fb4fd))
* **api:** OpenAPI spec update via Stainless API ([#686](https://github.com/scaleapi/sgp-python/issues/686)) ([2d012a2](https://github.com/scaleapi/sgp-python/commit/2d012a2d3569cbf08da628e8e6082f7aff152a99))
* **api:** OpenAPI spec update via Stainless API ([#687](https://github.com/scaleapi/sgp-python/issues/687)) ([d4fc335](https://github.com/scaleapi/sgp-python/commit/d4fc33514a3d60ac7cf3fe8426bb6ee987ffc80c))
* **api:** OpenAPI spec update via Stainless API ([#688](https://github.com/scaleapi/sgp-python/issues/688)) ([3f50cea](https://github.com/scaleapi/sgp-python/commit/3f50cea6871eec58d9fe67ccbdaf426da8993eb9))
* **api:** OpenAPI spec update via Stainless API ([#689](https://github.com/scaleapi/sgp-python/issues/689)) ([cba13a5](https://github.com/scaleapi/sgp-python/commit/cba13a51d86cc13e384e8172030b1ae43bea6d9f))
* **api:** OpenAPI spec update via Stainless API ([#690](https://github.com/scaleapi/sgp-python/issues/690)) ([0c0e4c6](https://github.com/scaleapi/sgp-python/commit/0c0e4c6e791160a5113586a3fb6d1dbd0d814899))
* **api:** OpenAPI spec update via Stainless API ([#694](https://github.com/scaleapi/sgp-python/issues/694)) ([879cd62](https://github.com/scaleapi/sgp-python/commit/879cd62dda9e53735bf2f7648f37dc1406795cf4))
* **api:** OpenAPI spec update via Stainless API ([#695](https://github.com/scaleapi/sgp-python/issues/695)) ([64a3c18](https://github.com/scaleapi/sgp-python/commit/64a3c1816789c3768a6428387c87a01a85ac0b47))
* **api:** OpenAPI spec update via Stainless API ([#696](https://github.com/scaleapi/sgp-python/issues/696)) ([4220547](https://github.com/scaleapi/sgp-python/commit/42205470c2c65bca7d9e01c4122cedaa04515fd4))
* **api:** OpenAPI spec update via Stainless API ([#697](https://github.com/scaleapi/sgp-python/issues/697)) ([da9dfac](https://github.com/scaleapi/sgp-python/commit/da9dfac2dfbf27a2b894ee116cfad07b723e5601))
* **api:** OpenAPI spec update via Stainless API ([#698](https://github.com/scaleapi/sgp-python/issues/698)) ([0acdd0d](https://github.com/scaleapi/sgp-python/commit/0acdd0d09a4c51fcef9d7e818b13aa998b92a140))
* **api:** OpenAPI spec update via Stainless API ([#699](https://github.com/scaleapi/sgp-python/issues/699)) ([29744f9](https://github.com/scaleapi/sgp-python/commit/29744f97c37c19b46cf131375273d71c43926ed4))
* **api:** OpenAPI spec update via Stainless API ([#700](https://github.com/scaleapi/sgp-python/issues/700)) ([d4f5ba2](https://github.com/scaleapi/sgp-python/commit/d4f5ba2c67ee906c8d96657c89d51fd60c259f6c))
* **api:** OpenAPI spec update via Stainless API ([#701](https://github.com/scaleapi/sgp-python/issues/701)) ([f9903b2](https://github.com/scaleapi/sgp-python/commit/f9903b28ff370c3053bfdcbef0fd63ec0098d372))
* **api:** OpenAPI spec update via Stainless API ([#702](https://github.com/scaleapi/sgp-python/issues/702)) ([00ceb42](https://github.com/scaleapi/sgp-python/commit/00ceb42b42bc1e977f2166893008086b5a0a8cec))
* **api:** OpenAPI spec update via Stainless API ([#703](https://github.com/scaleapi/sgp-python/issues/703)) ([99972ac](https://github.com/scaleapi/sgp-python/commit/99972ace1a8b8fb3952732d17c94eeaee4bc1dbd))
* **api:** OpenAPI spec update via Stainless API ([#704](https://github.com/scaleapi/sgp-python/issues/704)) ([707322b](https://github.com/scaleapi/sgp-python/commit/707322bb12438550da5590ddd783d55919c2900e))
* **api:** OpenAPI spec update via Stainless API ([#708](https://github.com/scaleapi/sgp-python/issues/708)) ([5c1490a](https://github.com/scaleapi/sgp-python/commit/5c1490ad3bedfe4439c42ee91bb0b98d573fd676))
* **api:** OpenAPI spec update via Stainless API ([#709](https://github.com/scaleapi/sgp-python/issues/709)) ([8f3fd03](https://github.com/scaleapi/sgp-python/commit/8f3fd03416db242858661f2f3ac694dd5947fea9))
* **api:** OpenAPI spec update via Stainless API ([#710](https://github.com/scaleapi/sgp-python/issues/710)) ([c2add35](https://github.com/scaleapi/sgp-python/commit/c2add3576b01892c73339560d0465aaa2e0e888e))
* **api:** OpenAPI spec update via Stainless API ([#711](https://github.com/scaleapi/sgp-python/issues/711)) ([91c46cb](https://github.com/scaleapi/sgp-python/commit/91c46cb43956228b88f394f96863a1120ff38ce9))
* **api:** OpenAPI spec update via Stainless API ([#712](https://github.com/scaleapi/sgp-python/issues/712)) ([0fe3d67](https://github.com/scaleapi/sgp-python/commit/0fe3d67ba26eb2c2955bef3fa2c6b2b0260a3724))
* **api:** OpenAPI spec update via Stainless API ([#713](https://github.com/scaleapi/sgp-python/issues/713)) ([a575f6a](https://github.com/scaleapi/sgp-python/commit/a575f6a50ce712a6f1e63d80c2cad0b542ceb261))
* **api:** OpenAPI spec update via Stainless API ([#714](https://github.com/scaleapi/sgp-python/issues/714)) ([5aa8352](https://github.com/scaleapi/sgp-python/commit/5aa8352d046fe2e8a4b68ae1c27961cdce2de6e2))
* **api:** OpenAPI spec update via Stainless API ([#715](https://github.com/scaleapi/sgp-python/issues/715)) ([f2eb710](https://github.com/scaleapi/sgp-python/commit/f2eb71021cfb67b501df32deb4658029048d93d6))
* **api:** OpenAPI spec update via Stainless API ([#717](https://github.com/scaleapi/sgp-python/issues/717)) ([53833f6](https://github.com/scaleapi/sgp-python/commit/53833f6ef3aa2834b0adbb40dd019b7d69f82c25))
* **api:** OpenAPI spec update via Stainless API ([#721](https://github.com/scaleapi/sgp-python/issues/721)) ([99f3074](https://github.com/scaleapi/sgp-python/commit/99f30745e6398631cdb59dc402550a29bb72c65e))
* **api:** OpenAPI spec update via Stainless API ([#723](https://github.com/scaleapi/sgp-python/issues/723)) ([5fd2bc5](https://github.com/scaleapi/sgp-python/commit/5fd2bc58bbd84f0fa3bea566c809eeccdf273218))
* **api:** OpenAPI spec update via Stainless API ([#724](https://github.com/scaleapi/sgp-python/issues/724)) ([b89d29e](https://github.com/scaleapi/sgp-python/commit/b89d29ea5bec7bc2ea1a000edfd4be59f753902b))
* **api:** OpenAPI spec update via Stainless API ([#725](https://github.com/scaleapi/sgp-python/issues/725)) ([67adf9c](https://github.com/scaleapi/sgp-python/commit/67adf9cc2f981d1a87674fd934ce900938cbc51c))
* **api:** OpenAPI spec update via Stainless API ([#726](https://github.com/scaleapi/sgp-python/issues/726)) ([d28410b](https://github.com/scaleapi/sgp-python/commit/d28410bf9f6666dcd56c52f3c4a7c15e5f9d3a7f))
* **api:** OpenAPI spec update via Stainless API ([#727](https://github.com/scaleapi/sgp-python/issues/727)) ([d739379](https://github.com/scaleapi/sgp-python/commit/d739379826a5931a4c621f3bf566ee300529ac0f))
* **api:** OpenAPI spec update via Stainless API ([#728](https://github.com/scaleapi/sgp-python/issues/728)) ([1fc4993](https://github.com/scaleapi/sgp-python/commit/1fc4993608fcdaaf1ec55a0691fcfc87a5c8278a))
* **api:** OpenAPI spec update via Stainless API ([#729](https://github.com/scaleapi/sgp-python/issues/729)) ([f7c05b8](https://github.com/scaleapi/sgp-python/commit/f7c05b89b8b9d6454a08de37145be8f139d0b9c5))
* **api:** OpenAPI spec update via Stainless API ([#730](https://github.com/scaleapi/sgp-python/issues/730)) ([81393ce](https://github.com/scaleapi/sgp-python/commit/81393cefde0f077a87361f8eb7b94d377a4fb55e))
* **api:** OpenAPI spec update via Stainless API ([#731](https://github.com/scaleapi/sgp-python/issues/731)) ([237b64b](https://github.com/scaleapi/sgp-python/commit/237b64bac562681bb9e30dd17008803eeed36086))
* **api:** OpenAPI spec update via Stainless API ([#732](https://github.com/scaleapi/sgp-python/issues/732)) ([c7d1597](https://github.com/scaleapi/sgp-python/commit/c7d1597b7d01a99fb9215a225330ee552f3ff63c))
* **api:** OpenAPI spec update via Stainless API ([#733](https://github.com/scaleapi/sgp-python/issues/733)) ([5fb0d38](https://github.com/scaleapi/sgp-python/commit/5fb0d38b2161c2979e9c9495de4222eb1cfc49f8))
* **api:** OpenAPI spec update via Stainless API ([#734](https://github.com/scaleapi/sgp-python/issues/734)) ([a7153f5](https://github.com/scaleapi/sgp-python/commit/a7153f55a63d392df9a6752110dd83bf3801fdf1))
* **api:** OpenAPI spec update via Stainless API ([#735](https://github.com/scaleapi/sgp-python/issues/735)) ([1937d4d](https://github.com/scaleapi/sgp-python/commit/1937d4d39d729e66796a9ca151784434e2f547e7))
* **api:** OpenAPI spec update via Stainless API ([#736](https://github.com/scaleapi/sgp-python/issues/736)) ([797c805](https://github.com/scaleapi/sgp-python/commit/797c80594fa862f67d42062878ff5cacfc999809))
* **api:** OpenAPI spec update via Stainless API ([#737](https://github.com/scaleapi/sgp-python/issues/737)) ([7dafc07](https://github.com/scaleapi/sgp-python/commit/7dafc078d9e36b98cd5ba0a2d96f6dc11fdb9895))
* **api:** OpenAPI spec update via Stainless API ([#738](https://github.com/scaleapi/sgp-python/issues/738)) ([7e7f5e2](https://github.com/scaleapi/sgp-python/commit/7e7f5e2e4808a66445b92d772435b8e4e25d7913))
* **api:** OpenAPI spec update via Stainless API ([#739](https://github.com/scaleapi/sgp-python/issues/739)) ([5cff5f3](https://github.com/scaleapi/sgp-python/commit/5cff5f38d4c3a4bd24ec8fa5051ee4ee36237719))
* **api:** OpenAPI spec update via Stainless API ([#740](https://github.com/scaleapi/sgp-python/issues/740)) ([69445ac](https://github.com/scaleapi/sgp-python/commit/69445ac61f0e218af08daf19a86971f793f5ae66))
* **api:** OpenAPI spec update via Stainless API ([#741](https://github.com/scaleapi/sgp-python/issues/741)) ([337e9fd](https://github.com/scaleapi/sgp-python/commit/337e9fd0fbc133093c14ff655e0d06427a4898b2))
* **api:** OpenAPI spec update via Stainless API ([#742](https://github.com/scaleapi/sgp-python/issues/742)) ([95d7a4c](https://github.com/scaleapi/sgp-python/commit/95d7a4cd74377d75c902fc2596bff939b22e2995))
* **api:** OpenAPI spec update via Stainless API ([#743](https://github.com/scaleapi/sgp-python/issues/743)) ([e9207cf](https://github.com/scaleapi/sgp-python/commit/e9207cf8272b8b82998c6ccc53513a6f982777bc))
* **api:** OpenAPI spec update via Stainless API ([#744](https://github.com/scaleapi/sgp-python/issues/744)) ([c2cab47](https://github.com/scaleapi/sgp-python/commit/c2cab4714a09840bb39a4bf8ab3d1bed4af53ad4))
* **api:** OpenAPI spec update via Stainless API ([#745](https://github.com/scaleapi/sgp-python/issues/745)) ([14b5d8e](https://github.com/scaleapi/sgp-python/commit/14b5d8e4b5dc683f6abbad9a11802836ccabf604))
* **api:** OpenAPI spec update via Stainless API ([#746](https://github.com/scaleapi/sgp-python/issues/746)) ([6b818e0](https://github.com/scaleapi/sgp-python/commit/6b818e0998fa0f3e484e039b4396fa5b23730bb3))
* **api:** OpenAPI spec update via Stainless API ([#747](https://github.com/scaleapi/sgp-python/issues/747)) ([e062844](https://github.com/scaleapi/sgp-python/commit/e0628445523c9870868b31f0d38e70fc4d222b60))
* **api:** OpenAPI spec update via Stainless API ([#748](https://github.com/scaleapi/sgp-python/issues/748)) ([942e3cd](https://github.com/scaleapi/sgp-python/commit/942e3cd17badf1aa323b498e446209937026538e))
* **api:** OpenAPI spec update via Stainless API ([#749](https://github.com/scaleapi/sgp-python/issues/749)) ([48e2fed](https://github.com/scaleapi/sgp-python/commit/48e2feda1fe6b084cf0a79982ab703bb8977a1eb))
* **api:** OpenAPI spec update via Stainless API ([#750](https://github.com/scaleapi/sgp-python/issues/750)) ([798d70b](https://github.com/scaleapi/sgp-python/commit/798d70bc2d3301486245ae49d2e613b76c9aa3f9))
* **api:** OpenAPI spec update via Stainless API ([#751](https://github.com/scaleapi/sgp-python/issues/751)) ([02708ef](https://github.com/scaleapi/sgp-python/commit/02708efb6ae21f20bb38ec6f7c173f623a43bfbf))
* **api:** OpenAPI spec update via Stainless API ([#752](https://github.com/scaleapi/sgp-python/issues/752)) ([0978207](https://github.com/scaleapi/sgp-python/commit/09782073e4a65a6cfcf928d55ad33363a45e0aa6))
* **api:** OpenAPI spec update via Stainless API ([#753](https://github.com/scaleapi/sgp-python/issues/753)) ([9129686](https://github.com/scaleapi/sgp-python/commit/91296863aa2e46863a950e2f92e228bca8d79b46))
* **api:** OpenAPI spec update via Stainless API ([#754](https://github.com/scaleapi/sgp-python/issues/754)) ([6b3bf77](https://github.com/scaleapi/sgp-python/commit/6b3bf77c62d49afa70eac06f9e496b725ae126e0))
* **api:** OpenAPI spec update via Stainless API ([#755](https://github.com/scaleapi/sgp-python/issues/755)) ([f2a5f6b](https://github.com/scaleapi/sgp-python/commit/f2a5f6b3f4c94594349b789b93be8ea407612617))
* **api:** OpenAPI spec update via Stainless API ([#756](https://github.com/scaleapi/sgp-python/issues/756)) ([72f6766](https://github.com/scaleapi/sgp-python/commit/72f676675916408b66151174c81f37018deba8a6))
* **api:** OpenAPI spec update via Stainless API ([#757](https://github.com/scaleapi/sgp-python/issues/757)) ([cd9b788](https://github.com/scaleapi/sgp-python/commit/cd9b788cabe98d562c7fa1657aee1b11f3579595))
* **api:** OpenAPI spec update via Stainless API ([#758](https://github.com/scaleapi/sgp-python/issues/758)) ([51e29e0](https://github.com/scaleapi/sgp-python/commit/51e29e0ba687e33d908a6aae319357e31b69f5b5))
* **api:** OpenAPI spec update via Stainless API ([#759](https://github.com/scaleapi/sgp-python/issues/759)) ([e0c5f2d](https://github.com/scaleapi/sgp-python/commit/e0c5f2d0a2f482993ae88529e3866e69fbf1ffbc))
* **api:** OpenAPI spec update via Stainless API ([#760](https://github.com/scaleapi/sgp-python/issues/760)) ([0c84695](https://github.com/scaleapi/sgp-python/commit/0c846957a00b8130bda6fc59a46dec9c1b8ebb94))
* **api:** OpenAPI spec update via Stainless API ([#761](https://github.com/scaleapi/sgp-python/issues/761)) ([44d423e](https://github.com/scaleapi/sgp-python/commit/44d423eb76009546c63d9d17e42f2bb28b11aae0))
* **api:** OpenAPI spec update via Stainless API ([#762](https://github.com/scaleapi/sgp-python/issues/762)) ([5e1370a](https://github.com/scaleapi/sgp-python/commit/5e1370ae55a6230ebc0a5216945d660694d97a98))
* **api:** OpenAPI spec update via Stainless API ([#763](https://github.com/scaleapi/sgp-python/issues/763)) ([6abf5f7](https://github.com/scaleapi/sgp-python/commit/6abf5f7dbe685118a5e6634b510c19ed485bdf29))
* **api:** OpenAPI spec update via Stainless API ([#764](https://github.com/scaleapi/sgp-python/issues/764)) ([4233bcb](https://github.com/scaleapi/sgp-python/commit/4233bcb7c6df76f77fa0f01a6e64b4607002e5c1))
* **api:** OpenAPI spec update via Stainless API ([#765](https://github.com/scaleapi/sgp-python/issues/765)) ([e6ab256](https://github.com/scaleapi/sgp-python/commit/e6ab256e3f542fe8886a0df39b5099587efade1d))
* **api:** OpenAPI spec update via Stainless API ([#766](https://github.com/scaleapi/sgp-python/issues/766)) ([76875e6](https://github.com/scaleapi/sgp-python/commit/76875e65d4015fdbc44a17387b19939f17c0ea86))
* **api:** OpenAPI spec update via Stainless API ([#767](https://github.com/scaleapi/sgp-python/issues/767)) ([37791c2](https://github.com/scaleapi/sgp-python/commit/37791c20dd84053104abb9a2ef8edfcbac79f6b9))
* **api:** OpenAPI spec update via Stainless API ([#768](https://github.com/scaleapi/sgp-python/issues/768)) ([8ffded1](https://github.com/scaleapi/sgp-python/commit/8ffded1ab667c2c0466bc14a62934e142c98abce))
* **api:** OpenAPI spec update via Stainless API ([#769](https://github.com/scaleapi/sgp-python/issues/769)) ([3ee6e70](https://github.com/scaleapi/sgp-python/commit/3ee6e7015fb4c89efab8d02ac7027fa57f85c4c5))
* **api:** OpenAPI spec update via Stainless API ([#770](https://github.com/scaleapi/sgp-python/issues/770)) ([7d4d8e7](https://github.com/scaleapi/sgp-python/commit/7d4d8e77d89956edc404f256048ed110b7cf4511))
* **api:** OpenAPI spec update via Stainless API ([#771](https://github.com/scaleapi/sgp-python/issues/771)) ([de43d70](https://github.com/scaleapi/sgp-python/commit/de43d70b7ef425cc46bca5fbe6da858fec14ff3e))
* **api:** OpenAPI spec update via Stainless API ([#772](https://github.com/scaleapi/sgp-python/issues/772)) ([b724324](https://github.com/scaleapi/sgp-python/commit/b724324dff552e69f197e9484e08915e5520306d))
* **api:** OpenAPI spec update via Stainless API ([#773](https://github.com/scaleapi/sgp-python/issues/773)) ([e9c34cb](https://github.com/scaleapi/sgp-python/commit/e9c34cb19fae33f0c7cbe9f6b28a1c3db5571949))
* **api:** OpenAPI spec update via Stainless API ([#774](https://github.com/scaleapi/sgp-python/issues/774)) ([7bbe1ee](https://github.com/scaleapi/sgp-python/commit/7bbe1ee0e56fef7ec54fc76fcc24d696b5f11e07))
* **api:** OpenAPI spec update via Stainless API ([#775](https://github.com/scaleapi/sgp-python/issues/775)) ([c28dda4](https://github.com/scaleapi/sgp-python/commit/c28dda4551a5f6d55b19a74c6a299a433cd45e70))
* **api:** OpenAPI spec update via Stainless API ([#776](https://github.com/scaleapi/sgp-python/issues/776)) ([cc340f8](https://github.com/scaleapi/sgp-python/commit/cc340f8161e5c6964ead5bba1b4ba1899dabbd29))
* **api:** OpenAPI spec update via Stainless API ([#777](https://github.com/scaleapi/sgp-python/issues/777)) ([f0ae5be](https://github.com/scaleapi/sgp-python/commit/f0ae5bed98b69c4cf8056fb58d5bc2bb5377cfe6))
* **api:** OpenAPI spec update via Stainless API ([#778](https://github.com/scaleapi/sgp-python/issues/778)) ([a14ee8d](https://github.com/scaleapi/sgp-python/commit/a14ee8ddd9352e1f1c4fec37818f91d73e006978))
* **api:** OpenAPI spec update via Stainless API ([#779](https://github.com/scaleapi/sgp-python/issues/779)) ([b65aad3](https://github.com/scaleapi/sgp-python/commit/b65aad34d69c2d339d6b91dc15c621e6c68f753a))
* **api:** OpenAPI spec update via Stainless API ([#780](https://github.com/scaleapi/sgp-python/issues/780)) ([0314944](https://github.com/scaleapi/sgp-python/commit/031494431d3b482fc8863284381ec8ddcd7f4cb7))
* **api:** OpenAPI spec update via Stainless API ([#781](https://github.com/scaleapi/sgp-python/issues/781)) ([233239a](https://github.com/scaleapi/sgp-python/commit/233239aea06dcdb5f70e6522951cd49814c6965a))
* **api:** OpenAPI spec update via Stainless API ([#782](https://github.com/scaleapi/sgp-python/issues/782)) ([8f3e0f0](https://github.com/scaleapi/sgp-python/commit/8f3e0f067350fe7b5f8cd052cf9db329c678aab5))
* **api:** OpenAPI spec update via Stainless API ([#783](https://github.com/scaleapi/sgp-python/issues/783)) ([a8e7172](https://github.com/scaleapi/sgp-python/commit/a8e7172fabc5001378040b0e5f7cba11e83a84bb))
* **api:** OpenAPI spec update via Stainless API ([#784](https://github.com/scaleapi/sgp-python/issues/784)) ([7991824](https://github.com/scaleapi/sgp-python/commit/7991824b298d7bd3548613d3e06cf09255c7ec6c))
* **api:** OpenAPI spec update via Stainless API ([#785](https://github.com/scaleapi/sgp-python/issues/785)) ([6cb0e9f](https://github.com/scaleapi/sgp-python/commit/6cb0e9f7131bb80f6531c11e71e457d1655f556d))
* **api:** OpenAPI spec update via Stainless API ([#786](https://github.com/scaleapi/sgp-python/issues/786)) ([96c3628](https://github.com/scaleapi/sgp-python/commit/96c36283cd73f80d69a93572e7132342483a538e))
* **api:** OpenAPI spec update via Stainless API ([#787](https://github.com/scaleapi/sgp-python/issues/787)) ([ada383e](https://github.com/scaleapi/sgp-python/commit/ada383e1a1f5be51f447cc06d43e2b5e8a971271))
* **api:** OpenAPI spec update via Stainless API ([#788](https://github.com/scaleapi/sgp-python/issues/788)) ([418b2d7](https://github.com/scaleapi/sgp-python/commit/418b2d7a5c2450bac804e62c26fc02946bc118c5))
* **api:** OpenAPI spec update via Stainless API ([#789](https://github.com/scaleapi/sgp-python/issues/789)) ([60aedbf](https://github.com/scaleapi/sgp-python/commit/60aedbfcdc19be56e2f7be94529909ee84a39849))
* **api:** OpenAPI spec update via Stainless API ([#791](https://github.com/scaleapi/sgp-python/issues/791)) ([1bf1a6f](https://github.com/scaleapi/sgp-python/commit/1bf1a6ff6bbb08cf66e88789133849093131b6fa))
* **api:** OpenAPI spec update via Stainless API ([#793](https://github.com/scaleapi/sgp-python/issues/793)) ([2044f0e](https://github.com/scaleapi/sgp-python/commit/2044f0ef7a274c84989f95d5c5b1885a7a26f3eb))
* **api:** OpenAPI spec update via Stainless API ([#794](https://github.com/scaleapi/sgp-python/issues/794)) ([ea843ac](https://github.com/scaleapi/sgp-python/commit/ea843ac51ab4a13128b10b9f8b3cf1799dcce260))
* **api:** OpenAPI spec update via Stainless API ([#796](https://github.com/scaleapi/sgp-python/issues/796)) ([2544cb2](https://github.com/scaleapi/sgp-python/commit/2544cb2a9ae804cbf7dbfd5c0353ca2764c950d7))
* **api:** OpenAPI spec update via Stainless API ([#798](https://github.com/scaleapi/sgp-python/issues/798)) ([9d8b3d4](https://github.com/scaleapi/sgp-python/commit/9d8b3d49945cf8f1c66de9597c8ee92622933c5a))
* **api:** OpenAPI spec update via Stainless API ([#799](https://github.com/scaleapi/sgp-python/issues/799)) ([4bb9204](https://github.com/scaleapi/sgp-python/commit/4bb9204ffa6808ebe78f0a404275dc701fbd66c0))
* **api:** OpenAPI spec update via Stainless API ([#800](https://github.com/scaleapi/sgp-python/issues/800)) ([830bb81](https://github.com/scaleapi/sgp-python/commit/830bb81c4a4326deb2209e406c110da2447a8201))
* **api:** OpenAPI spec update via Stainless API ([#801](https://github.com/scaleapi/sgp-python/issues/801)) ([fb69930](https://github.com/scaleapi/sgp-python/commit/fb69930990ae55b404f046a08ea7be01ee0b939a))
* **api:** OpenAPI spec update via Stainless API ([#802](https://github.com/scaleapi/sgp-python/issues/802)) ([a81d6b5](https://github.com/scaleapi/sgp-python/commit/a81d6b5ffe38a653aaf047013f438e97d0d19452))
* **api:** OpenAPI spec update via Stainless API ([#803](https://github.com/scaleapi/sgp-python/issues/803)) ([48f5cd1](https://github.com/scaleapi/sgp-python/commit/48f5cd1a3018e0350dc8f119141bb3cf7e11ab6a))
* **api:** OpenAPI spec update via Stainless API ([#804](https://github.com/scaleapi/sgp-python/issues/804)) ([841edd1](https://github.com/scaleapi/sgp-python/commit/841edd1f6334e194419a8a80351aebd22483e5b8))
* **api:** OpenAPI spec update via Stainless API ([#805](https://github.com/scaleapi/sgp-python/issues/805)) ([98aad6f](https://github.com/scaleapi/sgp-python/commit/98aad6f91f6fae57043aed3dcd19a822e8ff7987))
* **api:** OpenAPI spec update via Stainless API ([#806](https://github.com/scaleapi/sgp-python/issues/806)) ([cfcb90b](https://github.com/scaleapi/sgp-python/commit/cfcb90b7a3190d35c89349163289d12a85bdcc2b))
* **api:** OpenAPI spec update via Stainless API ([#807](https://github.com/scaleapi/sgp-python/issues/807)) ([7a961b0](https://github.com/scaleapi/sgp-python/commit/7a961b005f6e1873fdadf1b9db226c85d329d057))
* **api:** OpenAPI spec update via Stainless API ([#808](https://github.com/scaleapi/sgp-python/issues/808)) ([c2048c8](https://github.com/scaleapi/sgp-python/commit/c2048c8d1db83f7a490d0d44f072548e2cb6b8df))
* **api:** OpenAPI spec update via Stainless API ([#810](https://github.com/scaleapi/sgp-python/issues/810)) ([ce68f96](https://github.com/scaleapi/sgp-python/commit/ce68f96e4537e656df45d7fb7e39ffa06c390935))
* **api:** OpenAPI spec update via Stainless API ([#811](https://github.com/scaleapi/sgp-python/issues/811)) ([75ffced](https://github.com/scaleapi/sgp-python/commit/75ffced5a7e9fa5887949274429ad5a1af5ce767))
* **api:** OpenAPI spec update via Stainless API ([#812](https://github.com/scaleapi/sgp-python/issues/812)) ([35373dc](https://github.com/scaleapi/sgp-python/commit/35373dcae3aead32c0218919707ef3fd05b60e6d))
* **api:** OpenAPI spec update via Stainless API ([#813](https://github.com/scaleapi/sgp-python/issues/813)) ([d4de246](https://github.com/scaleapi/sgp-python/commit/d4de24665cf8fe5d94457cdfe30015ba625b310a))
* **api:** OpenAPI spec update via Stainless API ([#814](https://github.com/scaleapi/sgp-python/issues/814)) ([4fd2584](https://github.com/scaleapi/sgp-python/commit/4fd2584e3bd954bfe4be0e4787bcaeceddfb0b66))
* **api:** OpenAPI spec update via Stainless API ([#815](https://github.com/scaleapi/sgp-python/issues/815)) ([6d0636d](https://github.com/scaleapi/sgp-python/commit/6d0636dd193e6c1860af2902728dcec3ba319a5d))
* **api:** OpenAPI spec update via Stainless API ([#816](https://github.com/scaleapi/sgp-python/issues/816)) ([15df3e8](https://github.com/scaleapi/sgp-python/commit/15df3e8626ac0613fef55011d957ac1282567b6e))
* **api:** OpenAPI spec update via Stainless API ([#818](https://github.com/scaleapi/sgp-python/issues/818)) ([62f43fc](https://github.com/scaleapi/sgp-python/commit/62f43fccd265fce36a8e87a0924079819133b4ec))
* **api:** OpenAPI spec update via Stainless API ([#819](https://github.com/scaleapi/sgp-python/issues/819)) ([ef34ae6](https://github.com/scaleapi/sgp-python/commit/ef34ae699cc11a2adc135d9286afdc813c63f161))
* **api:** OpenAPI spec update via Stainless API ([#820](https://github.com/scaleapi/sgp-python/issues/820)) ([a85be60](https://github.com/scaleapi/sgp-python/commit/a85be60635e51a9dce0aa8235d63719fc79ec35d))
* **api:** OpenAPI spec update via Stainless API ([#821](https://github.com/scaleapi/sgp-python/issues/821)) ([4482146](https://github.com/scaleapi/sgp-python/commit/44821467d2289d487901b998eebee90b0a8b3534))
* **api:** OpenAPI spec update via Stainless API ([#823](https://github.com/scaleapi/sgp-python/issues/823)) ([ebbf745](https://github.com/scaleapi/sgp-python/commit/ebbf745d66beb4148411ba3cd1850e26ebc98fff))
* **api:** OpenAPI spec update via Stainless API ([#824](https://github.com/scaleapi/sgp-python/issues/824)) ([b5706a9](https://github.com/scaleapi/sgp-python/commit/b5706a9cdc39bf4c173b376ad6ed33a8bef96a48))
* **api:** OpenAPI spec update via Stainless API ([#825](https://github.com/scaleapi/sgp-python/issues/825)) ([b8ec4e9](https://github.com/scaleapi/sgp-python/commit/b8ec4e98f0316e852fc30672eb28c1dbb9e45844))
* **api:** OpenAPI spec update via Stainless API ([#826](https://github.com/scaleapi/sgp-python/issues/826)) ([97d32ec](https://github.com/scaleapi/sgp-python/commit/97d32ec3862c248f51b45843e6e643207523c6ac))
* **api:** OpenAPI spec update via Stainless API ([#827](https://github.com/scaleapi/sgp-python/issues/827)) ([bc6dd42](https://github.com/scaleapi/sgp-python/commit/bc6dd4222fe198ae00b07296b018d0bec36dfbb3))
* **api:** OpenAPI spec update via Stainless API ([#828](https://github.com/scaleapi/sgp-python/issues/828)) ([4d52f10](https://github.com/scaleapi/sgp-python/commit/4d52f107a32b047d2c43d6ed8ce54cc1faf44040))
* **api:** OpenAPI spec update via Stainless API ([#829](https://github.com/scaleapi/sgp-python/issues/829)) ([b4abd3b](https://github.com/scaleapi/sgp-python/commit/b4abd3b691ce149a72c46efcc277f2f264538835))
* **api:** OpenAPI spec update via Stainless API ([#830](https://github.com/scaleapi/sgp-python/issues/830)) ([e8333a8](https://github.com/scaleapi/sgp-python/commit/e8333a8939a89ac9e974cde381ce11d3487a794c))
* **api:** OpenAPI spec update via Stainless API ([#831](https://github.com/scaleapi/sgp-python/issues/831)) ([2a72c2c](https://github.com/scaleapi/sgp-python/commit/2a72c2c2137c35535905c0dbff8b2f6dd7d90abb))
* **api:** OpenAPI spec update via Stainless API ([#832](https://github.com/scaleapi/sgp-python/issues/832)) ([e3f6e04](https://github.com/scaleapi/sgp-python/commit/e3f6e042d7c4be0294b1812db4facdbc26c6da28))
* **api:** OpenAPI spec update via Stainless API ([#833](https://github.com/scaleapi/sgp-python/issues/833)) ([2cc2e8f](https://github.com/scaleapi/sgp-python/commit/2cc2e8f79e09082f1fcbdccde1d21c4a2cc384ac))
* **api:** OpenAPI spec update via Stainless API ([#834](https://github.com/scaleapi/sgp-python/issues/834)) ([9866885](https://github.com/scaleapi/sgp-python/commit/9866885cb7b98f102f7d73a2e2cc561fb9d5a175))
* **api:** OpenAPI spec update via Stainless API ([#835](https://github.com/scaleapi/sgp-python/issues/835)) ([cea781c](https://github.com/scaleapi/sgp-python/commit/cea781ccbd94e0394ec0dcec51e65c8fe5aa7567))
* **api:** OpenAPI spec update via Stainless API ([#836](https://github.com/scaleapi/sgp-python/issues/836)) ([10bd642](https://github.com/scaleapi/sgp-python/commit/10bd642dce9525f9b9729886a73ede0aeeef5202))
* **api:** OpenAPI spec update via Stainless API ([#837](https://github.com/scaleapi/sgp-python/issues/837)) ([e798f8d](https://github.com/scaleapi/sgp-python/commit/e798f8dec6addfb034e0d2829e6ccca39349118e))
* **api:** OpenAPI spec update via Stainless API ([#838](https://github.com/scaleapi/sgp-python/issues/838)) ([c560833](https://github.com/scaleapi/sgp-python/commit/c560833f7db854efbbf4006ec46c9f090d4631f5))
* **api:** OpenAPI spec update via Stainless API ([#839](https://github.com/scaleapi/sgp-python/issues/839)) ([bd42a64](https://github.com/scaleapi/sgp-python/commit/bd42a648f526157fa1b86e1f678520c33b94ad42))
* **api:** OpenAPI spec update via Stainless API ([#840](https://github.com/scaleapi/sgp-python/issues/840)) ([345db54](https://github.com/scaleapi/sgp-python/commit/345db5464b09b6cb07262bda233ecfeba6d86617))
* **api:** OpenAPI spec update via Stainless API ([#841](https://github.com/scaleapi/sgp-python/issues/841)) ([6ef6314](https://github.com/scaleapi/sgp-python/commit/6ef631456ed3c3cf4fd6723db54822b810e818f8))
* **api:** OpenAPI spec update via Stainless API ([#842](https://github.com/scaleapi/sgp-python/issues/842)) ([2a6ac14](https://github.com/scaleapi/sgp-python/commit/2a6ac143e4bfddde45bf4901184786ae9ea05f0e))
* **api:** OpenAPI spec update via Stainless API ([#843](https://github.com/scaleapi/sgp-python/issues/843)) ([2473c43](https://github.com/scaleapi/sgp-python/commit/2473c431571e641a8de3f2b68dbd25dae5f3b755))
* **api:** OpenAPI spec update via Stainless API ([#844](https://github.com/scaleapi/sgp-python/issues/844)) ([c9db280](https://github.com/scaleapi/sgp-python/commit/c9db28022121df57b8a2d038b388f54a01891d26))
* **api:** OpenAPI spec update via Stainless API ([#845](https://github.com/scaleapi/sgp-python/issues/845)) ([5cef90e](https://github.com/scaleapi/sgp-python/commit/5cef90ea21f5a4b98515df561cc30ddd0e283231))
* **api:** OpenAPI spec update via Stainless API ([#846](https://github.com/scaleapi/sgp-python/issues/846)) ([8614602](https://github.com/scaleapi/sgp-python/commit/86146027859b23ba4ee982c2c4bf87c0618fda2b))
* **api:** update via SDK Studio ([#667](https://github.com/scaleapi/sgp-python/issues/667)) ([1d591a6](https://github.com/scaleapi/sgp-python/commit/1d591a6be4e5bc33da3116956bb8fa428707c3da))
* **api:** update via SDK Studio ([#691](https://github.com/scaleapi/sgp-python/issues/691)) ([14a09cb](https://github.com/scaleapi/sgp-python/commit/14a09cb7a8a12e5c3a34388ca4686ae6fc27c3ae))
* **api:** update via SDK Studio ([#693](https://github.com/scaleapi/sgp-python/issues/693)) ([159a6d1](https://github.com/scaleapi/sgp-python/commit/159a6d1b319ed8282e023b8575674a5c7f17d63b))
* **api:** update via SDK Studio ([#705](https://github.com/scaleapi/sgp-python/issues/705)) ([9f6b9a6](https://github.com/scaleapi/sgp-python/commit/9f6b9a670a65f8680ef73c8472732727a72363f1))
* **api:** update via SDK Studio ([#706](https://github.com/scaleapi/sgp-python/issues/706)) ([4fc6256](https://github.com/scaleapi/sgp-python/commit/4fc625673e688b3e0c2ad9553da66d5e3b8caa53))
* **api:** update via SDK Studio ([#707](https://github.com/scaleapi/sgp-python/issues/707)) ([717b4fd](https://github.com/scaleapi/sgp-python/commit/717b4fd7113db71b3c990899d4061374b300cdc4))
* **api:** update via SDK Studio ([#716](https://github.com/scaleapi/sgp-python/issues/716)) ([c18b1b0](https://github.com/scaleapi/sgp-python/commit/c18b1b08f16ca7f1773d9e7403a5eb59faf19dc3))
* **api:** update via SDK Studio ([#718](https://github.com/scaleapi/sgp-python/issues/718)) ([00629fb](https://github.com/scaleapi/sgp-python/commit/00629fba17d930edabfee4515dd0e089eef062d5))
* **api:** update via SDK Studio ([#719](https://github.com/scaleapi/sgp-python/issues/719)) ([6cd7ef2](https://github.com/scaleapi/sgp-python/commit/6cd7ef288c6dde21894eb5b80245c4c09a708b80))
* **api:** update via SDK Studio ([#720](https://github.com/scaleapi/sgp-python/issues/720)) ([3f039f7](https://github.com/scaleapi/sgp-python/commit/3f039f7da0b5242487def998745ed7446ffdebc6))
* **api:** update via SDK Studio ([#722](https://github.com/scaleapi/sgp-python/issues/722)) ([f24d339](https://github.com/scaleapi/sgp-python/commit/f24d339ba8c7bb34cd1e8620838fe2ecd0fc32a2))
* **client:** add `retry_count` to raw response class ([#795](https://github.com/scaleapi/sgp-python/issues/795)) ([3a6fa26](https://github.com/scaleapi/sgp-python/commit/3a6fa268d2446d798c74b95d76d2f12e800b6a1d))


### Chores

* **internal:** bump pyright ([#792](https://github.com/scaleapi/sgp-python/issues/792)) ([b6dab7a](https://github.com/scaleapi/sgp-python/commit/b6dab7a61ab3c836a4ebf10fa0390a11a14b134a))
* **internal:** bump ruff version ([#817](https://github.com/scaleapi/sgp-python/issues/817)) ([848736c](https://github.com/scaleapi/sgp-python/commit/848736cf4bf5a4d11bff420ff6c7d3b6f90e1215))
* **internal:** codegen related update ([#692](https://github.com/scaleapi/sgp-python/issues/692)) ([c71dad5](https://github.com/scaleapi/sgp-python/commit/c71dad51f75c32cb4b56cc395f12b2f1178f0f1b))
* **internal:** test updates ([#797](https://github.com/scaleapi/sgp-python/issues/797)) ([888dee9](https://github.com/scaleapi/sgp-python/commit/888dee975051151b76908ead72fcf68a53505897))
* **internal:** update example values ([#668](https://github.com/scaleapi/sgp-python/issues/668)) ([69bebf9](https://github.com/scaleapi/sgp-python/commit/69bebf93f08bcefbf10fba85a39843e624f9fec1))
* **internal:** update pydantic compat helper function ([#822](https://github.com/scaleapi/sgp-python/issues/822)) ([73a76a1](https://github.com/scaleapi/sgp-python/commit/73a76a1746b25b6205b1f70011edc9e6cd733068))
* **internal:** use `TypeAlias` marker for type assignments ([#790](https://github.com/scaleapi/sgp-python/issues/790)) ([bef2ff9](https://github.com/scaleapi/sgp-python/commit/bef2ff9595b481db2c4f8c7e13c8a0838e5c39e2))

## 0.1.0-alpha.19 (2024-07-30)

Full Changelog: [v0.1.0-alpha.18...v0.1.0-alpha.19](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.18...v0.1.0-alpha.19)

### Features

* **api:** OpenAPI spec update via Stainless API ([#568](https://github.com/scaleapi/sgp-python/issues/568)) ([5e2bfd6](https://github.com/scaleapi/sgp-python/commit/5e2bfd67f671d78f3b713168c3cc2c272aa522d5))
* **api:** OpenAPI spec update via Stainless API ([#570](https://github.com/scaleapi/sgp-python/issues/570)) ([1dc12b5](https://github.com/scaleapi/sgp-python/commit/1dc12b539983d118c74fd614df86c2b1d2aea5ca))
* **api:** OpenAPI spec update via Stainless API ([#571](https://github.com/scaleapi/sgp-python/issues/571)) ([114b6cf](https://github.com/scaleapi/sgp-python/commit/114b6cfeb2c5fa3ca95bc250efa26e38420bc24c))
* **api:** OpenAPI spec update via Stainless API ([#572](https://github.com/scaleapi/sgp-python/issues/572)) ([962fe69](https://github.com/scaleapi/sgp-python/commit/962fe69fda1a47d954eba7399085796561c57461))
* **api:** OpenAPI spec update via Stainless API ([#573](https://github.com/scaleapi/sgp-python/issues/573)) ([79f7221](https://github.com/scaleapi/sgp-python/commit/79f72210e20661618b1675b51175de880b961019))
* **api:** OpenAPI spec update via Stainless API ([#574](https://github.com/scaleapi/sgp-python/issues/574)) ([cf1edf6](https://github.com/scaleapi/sgp-python/commit/cf1edf6e42aa319984665658e301c302806c5b51))
* **api:** OpenAPI spec update via Stainless API ([#575](https://github.com/scaleapi/sgp-python/issues/575)) ([637c919](https://github.com/scaleapi/sgp-python/commit/637c919a417288bb43d8fa602a1b83cb17cc2e58))
* **api:** OpenAPI spec update via Stainless API ([#576](https://github.com/scaleapi/sgp-python/issues/576)) ([1ff264e](https://github.com/scaleapi/sgp-python/commit/1ff264e5ccc6d019115d431924b7d4c56bdc0805))
* **api:** OpenAPI spec update via Stainless API ([#577](https://github.com/scaleapi/sgp-python/issues/577)) ([1f5b8bc](https://github.com/scaleapi/sgp-python/commit/1f5b8bc71d749d42b04035941597e9dfa4867e91))
* **api:** OpenAPI spec update via Stainless API ([#578](https://github.com/scaleapi/sgp-python/issues/578)) ([a6f392d](https://github.com/scaleapi/sgp-python/commit/a6f392da38dccaa0b11a903233f8bfc9d3312447))
* **api:** OpenAPI spec update via Stainless API ([#579](https://github.com/scaleapi/sgp-python/issues/579)) ([f01bba5](https://github.com/scaleapi/sgp-python/commit/f01bba5f87114b52da0e7f218240a90657375242))
* **api:** OpenAPI spec update via Stainless API ([#580](https://github.com/scaleapi/sgp-python/issues/580)) ([aaa3e0b](https://github.com/scaleapi/sgp-python/commit/aaa3e0b683cb9860140b3db537377624a0a96136))
* **api:** OpenAPI spec update via Stainless API ([#581](https://github.com/scaleapi/sgp-python/issues/581)) ([0f0655d](https://github.com/scaleapi/sgp-python/commit/0f0655d6ae51752b3d4904a7e131cbe1b9b2e765))
* **api:** OpenAPI spec update via Stainless API ([#582](https://github.com/scaleapi/sgp-python/issues/582)) ([7a71e92](https://github.com/scaleapi/sgp-python/commit/7a71e92fa37e17e46f7297e30e56d56473051786))
* **api:** OpenAPI spec update via Stainless API ([#583](https://github.com/scaleapi/sgp-python/issues/583)) ([2916754](https://github.com/scaleapi/sgp-python/commit/29167549e81c9164f9d5eeda2c5c2bfa44112cef))
* **api:** OpenAPI spec update via Stainless API ([#584](https://github.com/scaleapi/sgp-python/issues/584)) ([804f2fd](https://github.com/scaleapi/sgp-python/commit/804f2fd0583ccb97f731fc33421156f4d82332b8))
* **api:** OpenAPI spec update via Stainless API ([#585](https://github.com/scaleapi/sgp-python/issues/585)) ([99e3cf3](https://github.com/scaleapi/sgp-python/commit/99e3cf39f060d636918667af7d2408388ceb714c))
* **api:** OpenAPI spec update via Stainless API ([#586](https://github.com/scaleapi/sgp-python/issues/586)) ([0f6dbbe](https://github.com/scaleapi/sgp-python/commit/0f6dbbedda7090378f89849227a821ef8c5f1b84))
* **api:** OpenAPI spec update via Stainless API ([#587](https://github.com/scaleapi/sgp-python/issues/587)) ([5499ac1](https://github.com/scaleapi/sgp-python/commit/5499ac1702b2ebf5321b2ffaa85d94f5f39ae427))
* **api:** OpenAPI spec update via Stainless API ([#588](https://github.com/scaleapi/sgp-python/issues/588)) ([4b751a4](https://github.com/scaleapi/sgp-python/commit/4b751a4f4613b3eeac2712b35556b13493cd33e3))
* **api:** OpenAPI spec update via Stainless API ([#589](https://github.com/scaleapi/sgp-python/issues/589)) ([a9135f9](https://github.com/scaleapi/sgp-python/commit/a9135f94c69be0054030ef8522e0b9fe3d42a1e2))
* **api:** OpenAPI spec update via Stainless API ([#590](https://github.com/scaleapi/sgp-python/issues/590)) ([64345a2](https://github.com/scaleapi/sgp-python/commit/64345a2e36902f04a66a0ac902946adde981133b))
* **api:** OpenAPI spec update via Stainless API ([#591](https://github.com/scaleapi/sgp-python/issues/591)) ([83c90f2](https://github.com/scaleapi/sgp-python/commit/83c90f2f118a7706eb55ade68569cea3215eb9c5))
* **api:** OpenAPI spec update via Stainless API ([#592](https://github.com/scaleapi/sgp-python/issues/592)) ([e5c1016](https://github.com/scaleapi/sgp-python/commit/e5c10167c45182bea61a0dcc6253cfb5f3d5f089))
* **api:** OpenAPI spec update via Stainless API ([#593](https://github.com/scaleapi/sgp-python/issues/593)) ([688549a](https://github.com/scaleapi/sgp-python/commit/688549a412353165d7c25d77b13b44518f272309))
* **api:** OpenAPI spec update via Stainless API ([#594](https://github.com/scaleapi/sgp-python/issues/594)) ([7b334a4](https://github.com/scaleapi/sgp-python/commit/7b334a4fa6f004b2fed5d238de482af0e3c1e6b3))
* **api:** OpenAPI spec update via Stainless API ([#596](https://github.com/scaleapi/sgp-python/issues/596)) ([6502a9e](https://github.com/scaleapi/sgp-python/commit/6502a9e0a525400e95c0f3ea72a5f13f63f6181d))
* **api:** OpenAPI spec update via Stainless API ([#597](https://github.com/scaleapi/sgp-python/issues/597)) ([1afddbf](https://github.com/scaleapi/sgp-python/commit/1afddbfb07a1bb330596b59a3420a411cf162ff1))
* **api:** OpenAPI spec update via Stainless API ([#598](https://github.com/scaleapi/sgp-python/issues/598)) ([beb91d6](https://github.com/scaleapi/sgp-python/commit/beb91d6b3bb43529ea23b58eb762396483539857))
* **api:** OpenAPI spec update via Stainless API ([#599](https://github.com/scaleapi/sgp-python/issues/599)) ([35bdc3a](https://github.com/scaleapi/sgp-python/commit/35bdc3a80080f77e6b7e8e0559c3a1e819bdf4d0))
* **api:** OpenAPI spec update via Stainless API ([#600](https://github.com/scaleapi/sgp-python/issues/600)) ([a2121a4](https://github.com/scaleapi/sgp-python/commit/a2121a4e12570d0959b456e70b73ecbefd59c196))
* **api:** OpenAPI spec update via Stainless API ([#601](https://github.com/scaleapi/sgp-python/issues/601)) ([670bd37](https://github.com/scaleapi/sgp-python/commit/670bd37977644d38d26204530a4dbef729d1eba8))
* **api:** OpenAPI spec update via Stainless API ([#602](https://github.com/scaleapi/sgp-python/issues/602)) ([ef971e1](https://github.com/scaleapi/sgp-python/commit/ef971e1a5feafc29ce663713cb2000bfe27fe429))
* **api:** OpenAPI spec update via Stainless API ([#603](https://github.com/scaleapi/sgp-python/issues/603)) ([792530d](https://github.com/scaleapi/sgp-python/commit/792530d13a55ca148f22836fce93ef55b0e567ae))
* **api:** OpenAPI spec update via Stainless API ([#604](https://github.com/scaleapi/sgp-python/issues/604)) ([17abe1b](https://github.com/scaleapi/sgp-python/commit/17abe1b6e3a3ded4f7200f060f43b12220f8ac76))
* **api:** OpenAPI spec update via Stainless API ([#605](https://github.com/scaleapi/sgp-python/issues/605)) ([1778f7f](https://github.com/scaleapi/sgp-python/commit/1778f7f3f3b93851de6a9b3b2ae19443214be500))
* **api:** OpenAPI spec update via Stainless API ([#606](https://github.com/scaleapi/sgp-python/issues/606)) ([cec56a7](https://github.com/scaleapi/sgp-python/commit/cec56a713fcc0e3ec566292b9f3dd439d2e243bf))
* **api:** OpenAPI spec update via Stainless API ([#607](https://github.com/scaleapi/sgp-python/issues/607)) ([1739211](https://github.com/scaleapi/sgp-python/commit/17392113400c9251a1c20474263509c9fb4e0b98))
* **api:** OpenAPI spec update via Stainless API ([#608](https://github.com/scaleapi/sgp-python/issues/608)) ([38964fe](https://github.com/scaleapi/sgp-python/commit/38964fe042ca9421e033cf95d7de28373aa41866))
* **api:** OpenAPI spec update via Stainless API ([#609](https://github.com/scaleapi/sgp-python/issues/609)) ([155cafc](https://github.com/scaleapi/sgp-python/commit/155cafc1407d16bdd6fd5a30cce2510643c25e5c))
* **api:** OpenAPI spec update via Stainless API ([#610](https://github.com/scaleapi/sgp-python/issues/610)) ([4ea8fe7](https://github.com/scaleapi/sgp-python/commit/4ea8fe7c2ffb2da08aa85a6d1ecbc02938a3f396))
* **api:** OpenAPI spec update via Stainless API ([#611](https://github.com/scaleapi/sgp-python/issues/611)) ([f3ce74b](https://github.com/scaleapi/sgp-python/commit/f3ce74bf12f0bcffa484149e3f36811aa5d53669))
* **api:** OpenAPI spec update via Stainless API ([#612](https://github.com/scaleapi/sgp-python/issues/612)) ([44cc522](https://github.com/scaleapi/sgp-python/commit/44cc5227095f40547c5e5d82470a0d872d380196))
* **api:** OpenAPI spec update via Stainless API ([#613](https://github.com/scaleapi/sgp-python/issues/613)) ([ac1c70b](https://github.com/scaleapi/sgp-python/commit/ac1c70bb677c1446c4d41b73214b50b605288543))
* **api:** OpenAPI spec update via Stainless API ([#614](https://github.com/scaleapi/sgp-python/issues/614)) ([bbfb4c5](https://github.com/scaleapi/sgp-python/commit/bbfb4c5e5de72c607fcb51ed29104ca938afbaf8))
* **api:** OpenAPI spec update via Stainless API ([#615](https://github.com/scaleapi/sgp-python/issues/615)) ([12eab4a](https://github.com/scaleapi/sgp-python/commit/12eab4ada6eb96a1cab7f74a9b6603bbd15ddad8))
* **api:** OpenAPI spec update via Stainless API ([#616](https://github.com/scaleapi/sgp-python/issues/616)) ([d76d349](https://github.com/scaleapi/sgp-python/commit/d76d349e4124b0ec45032bd2cbc2371e23b00c2f))
* **api:** OpenAPI spec update via Stainless API ([#617](https://github.com/scaleapi/sgp-python/issues/617)) ([e2a4429](https://github.com/scaleapi/sgp-python/commit/e2a4429c30c3e069dbc9aa704c85aaa4ec18c484))
* **api:** OpenAPI spec update via Stainless API ([#618](https://github.com/scaleapi/sgp-python/issues/618)) ([4fdab57](https://github.com/scaleapi/sgp-python/commit/4fdab57aaad8d29141f16ca209f5fa2f1c7a401e))
* **api:** OpenAPI spec update via Stainless API ([#619](https://github.com/scaleapi/sgp-python/issues/619)) ([ffdf244](https://github.com/scaleapi/sgp-python/commit/ffdf244d8f5294d1872f743013c4a08f8af65778))
* **api:** OpenAPI spec update via Stainless API ([#620](https://github.com/scaleapi/sgp-python/issues/620)) ([7a27c9d](https://github.com/scaleapi/sgp-python/commit/7a27c9d3f28e27f14b7863cea474ade1e88a6063))
* **api:** OpenAPI spec update via Stainless API ([#621](https://github.com/scaleapi/sgp-python/issues/621)) ([e8d8c4a](https://github.com/scaleapi/sgp-python/commit/e8d8c4a0483eee08d7f2893f1e41bb5de79a03ff))
* **api:** OpenAPI spec update via Stainless API ([#622](https://github.com/scaleapi/sgp-python/issues/622)) ([7f34ce0](https://github.com/scaleapi/sgp-python/commit/7f34ce0717a97cf4a6ab38e880607c158676e385))
* **api:** OpenAPI spec update via Stainless API ([#623](https://github.com/scaleapi/sgp-python/issues/623)) ([d681dcd](https://github.com/scaleapi/sgp-python/commit/d681dcdd8ffe4405fedc831bf27efeebe2029f46))
* **api:** OpenAPI spec update via Stainless API ([#624](https://github.com/scaleapi/sgp-python/issues/624)) ([eefd2f4](https://github.com/scaleapi/sgp-python/commit/eefd2f4bd37d743702ba0ca30e645529fa0edfe8))
* **api:** OpenAPI spec update via Stainless API ([#625](https://github.com/scaleapi/sgp-python/issues/625)) ([8efe756](https://github.com/scaleapi/sgp-python/commit/8efe7567d60f81abdcac997960ad9e92b96f87b9))
* **api:** OpenAPI spec update via Stainless API ([#626](https://github.com/scaleapi/sgp-python/issues/626)) ([8ef7dd2](https://github.com/scaleapi/sgp-python/commit/8ef7dd2a47a337b5df94829eb6138423bab76074))
* **api:** OpenAPI spec update via Stainless API ([#627](https://github.com/scaleapi/sgp-python/issues/627)) ([fc2530c](https://github.com/scaleapi/sgp-python/commit/fc2530c3ea47d65ef9243251cb4aaae613c342bd))
* **api:** OpenAPI spec update via Stainless API ([#628](https://github.com/scaleapi/sgp-python/issues/628)) ([d0b63c6](https://github.com/scaleapi/sgp-python/commit/d0b63c6dac346a92ee6292050769406a1d620a5f))
* **api:** OpenAPI spec update via Stainless API ([#629](https://github.com/scaleapi/sgp-python/issues/629)) ([df72f69](https://github.com/scaleapi/sgp-python/commit/df72f698b79dee6ef07dfe56c1d278e24be8db52))
* **api:** OpenAPI spec update via Stainless API ([#634](https://github.com/scaleapi/sgp-python/issues/634)) ([716cf8f](https://github.com/scaleapi/sgp-python/commit/716cf8f72728f66f573f71f64ccd084e7139728c))
* **api:** OpenAPI spec update via Stainless API ([#636](https://github.com/scaleapi/sgp-python/issues/636)) ([e7479ad](https://github.com/scaleapi/sgp-python/commit/e7479ad11711740a949a13364597cf5650447303))
* **api:** OpenAPI spec update via Stainless API ([#638](https://github.com/scaleapi/sgp-python/issues/638)) ([f642b54](https://github.com/scaleapi/sgp-python/commit/f642b54963e222b166a4c4be565f0636de0745a0))
* **api:** OpenAPI spec update via Stainless API ([#640](https://github.com/scaleapi/sgp-python/issues/640)) ([51a3b38](https://github.com/scaleapi/sgp-python/commit/51a3b38c3398d466070b596fd22a1f525278a375))
* **api:** OpenAPI spec update via Stainless API ([#643](https://github.com/scaleapi/sgp-python/issues/643)) ([20d4fa7](https://github.com/scaleapi/sgp-python/commit/20d4fa7fa4e071b5a017ca0ccfbbabc8a48ef33a))
* **api:** OpenAPI spec update via Stainless API ([#644](https://github.com/scaleapi/sgp-python/issues/644)) ([754876f](https://github.com/scaleapi/sgp-python/commit/754876fc8917e3856d3d71b258436393ebb4a044))
* **api:** OpenAPI spec update via Stainless API ([#645](https://github.com/scaleapi/sgp-python/issues/645)) ([a2fcafc](https://github.com/scaleapi/sgp-python/commit/a2fcafccd3c5b53b97c8c3477703fe010f24057a))
* **api:** OpenAPI spec update via Stainless API ([#646](https://github.com/scaleapi/sgp-python/issues/646)) ([fe6f310](https://github.com/scaleapi/sgp-python/commit/fe6f310cb0637b8b2bc5b314ffb8e08d15dfd82b))
* **api:** OpenAPI spec update via Stainless API ([#647](https://github.com/scaleapi/sgp-python/issues/647)) ([a308a98](https://github.com/scaleapi/sgp-python/commit/a308a987daaba0edf3e2ea37c12d0205445f2a4e))
* **api:** OpenAPI spec update via Stainless API ([#648](https://github.com/scaleapi/sgp-python/issues/648)) ([134fadd](https://github.com/scaleapi/sgp-python/commit/134fadd720ed52c0d23f7dbe0ffc79c7852c3333))
* **api:** OpenAPI spec update via Stainless API ([#649](https://github.com/scaleapi/sgp-python/issues/649)) ([5b0a82a](https://github.com/scaleapi/sgp-python/commit/5b0a82a59d7167cc424a9cd45c8af10665a6193e))
* **api:** OpenAPI spec update via Stainless API ([#650](https://github.com/scaleapi/sgp-python/issues/650)) ([38f97b7](https://github.com/scaleapi/sgp-python/commit/38f97b7ca25e23656ec9954e7fb6e84c81ec7271))
* **api:** OpenAPI spec update via Stainless API ([#651](https://github.com/scaleapi/sgp-python/issues/651)) ([06025f6](https://github.com/scaleapi/sgp-python/commit/06025f616a10c90ed92dd0997ade7044ee11b800))
* **api:** OpenAPI spec update via Stainless API ([#652](https://github.com/scaleapi/sgp-python/issues/652)) ([4ae779b](https://github.com/scaleapi/sgp-python/commit/4ae779b3151f58eb69998e493d2ed4afd42e8570))
* **api:** OpenAPI spec update via Stainless API ([#653](https://github.com/scaleapi/sgp-python/issues/653)) ([f5bec0e](https://github.com/scaleapi/sgp-python/commit/f5bec0ee949b57fa98c8b4b79faf93d4fcf7edb7))
* **api:** OpenAPI spec update via Stainless API ([#654](https://github.com/scaleapi/sgp-python/issues/654)) ([b9b962c](https://github.com/scaleapi/sgp-python/commit/b9b962c5241c321f475cded92ec56e0444bf43da))
* **api:** OpenAPI spec update via Stainless API ([#655](https://github.com/scaleapi/sgp-python/issues/655)) ([6c327ce](https://github.com/scaleapi/sgp-python/commit/6c327ce689d9a52b755d37e8597f3a3973e8202e))
* **api:** OpenAPI spec update via Stainless API ([#656](https://github.com/scaleapi/sgp-python/issues/656)) ([3cbdbc2](https://github.com/scaleapi/sgp-python/commit/3cbdbc2e7e56b42752e072e2975b9da2e1e0b3a3))
* **api:** OpenAPI spec update via Stainless API ([#658](https://github.com/scaleapi/sgp-python/issues/658)) ([f027ab2](https://github.com/scaleapi/sgp-python/commit/f027ab2945d55ead056a08b41f87b76c61b3ca38))
* **api:** OpenAPI spec update via Stainless API ([#660](https://github.com/scaleapi/sgp-python/issues/660)) ([10787b4](https://github.com/scaleapi/sgp-python/commit/10787b4af7f3abf52d9e8965b1623630fe23d2d8))
* **api:** OpenAPI spec update via Stainless API ([#662](https://github.com/scaleapi/sgp-python/issues/662)) ([6dcb6cc](https://github.com/scaleapi/sgp-python/commit/6dcb6ccd8d93bf3186a694a00d6d9862296e6596))
* **api:** update via SDK Studio ([#595](https://github.com/scaleapi/sgp-python/issues/595)) ([c011ad6](https://github.com/scaleapi/sgp-python/commit/c011ad66e8cc67dc7d106a50ba4ee95bb8dfe97b))
* **api:** update via SDK Studio ([#631](https://github.com/scaleapi/sgp-python/issues/631)) ([e15b927](https://github.com/scaleapi/sgp-python/commit/e15b927b7d99a3faaeff2e922078fb8c4f057ba7))
* **api:** update via SDK Studio ([#632](https://github.com/scaleapi/sgp-python/issues/632)) ([1bfd700](https://github.com/scaleapi/sgp-python/commit/1bfd7004848cefcba6fe95d3f0ee77b24b85b81f))
* **api:** update via SDK Studio ([#633](https://github.com/scaleapi/sgp-python/issues/633)) ([88e5db9](https://github.com/scaleapi/sgp-python/commit/88e5db9e81fb8e77d9251d6578e65a385a71b371))
* **api:** update via SDK Studio ([#635](https://github.com/scaleapi/sgp-python/issues/635)) ([ffd8820](https://github.com/scaleapi/sgp-python/commit/ffd882080ff9a240284ea1cd6d507242325741b4))
* **api:** update via SDK Studio ([#637](https://github.com/scaleapi/sgp-python/issues/637)) ([b352fad](https://github.com/scaleapi/sgp-python/commit/b352fadb1da8f4aff3842974c1e9b192ce3663db))
* **api:** update via SDK Studio ([#639](https://github.com/scaleapi/sgp-python/issues/639)) ([dfeceae](https://github.com/scaleapi/sgp-python/commit/dfeceae29c009861fef8259df60de2508d330fd0))
* **api:** update via SDK Studio ([#641](https://github.com/scaleapi/sgp-python/issues/641)) ([9011b6a](https://github.com/scaleapi/sgp-python/commit/9011b6afe41827d339f0d278c0d70fa5bb96aefd))
* **api:** update via SDK Studio ([#642](https://github.com/scaleapi/sgp-python/issues/642)) ([c972dcd](https://github.com/scaleapi/sgp-python/commit/c972dcda61c05e7a2a180b5b7d37b61e5b30aa96))
* **api:** update via SDK Studio ([#659](https://github.com/scaleapi/sgp-python/issues/659)) ([a2a17f5](https://github.com/scaleapi/sgp-python/commit/a2a17f52a950873d428dea0a4dddca526e2b38bf))
* **api:** update via SDK Studio ([#663](https://github.com/scaleapi/sgp-python/issues/663)) ([4d09b6d](https://github.com/scaleapi/sgp-python/commit/4d09b6dbe235a78c44f4a25450a47df8086b1845))


### Bug Fixes

* `TestCaseVersionResponse` -&gt; `TestCase` ([3828170](https://github.com/scaleapi/sgp-python/commit/3828170514a81322aa466d6b89e764dfb6f9ac8f))


### Chores

* **internal:** add type construction helper ([#630](https://github.com/scaleapi/sgp-python/issues/630)) ([951a1be](https://github.com/scaleapi/sgp-python/commit/951a1be023142039f10d8ae88deb6afe02e3c782))

## 0.1.0-alpha.18 (2024-07-26)

Full Changelog: [v0.1.0-alpha.17...v0.1.0-alpha.18](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.17...v0.1.0-alpha.18)

### Features

* **api:** OpenAPI spec update via Stainless API ([#408](https://github.com/scaleapi/sgp-python/issues/408)) ([2301157](https://github.com/scaleapi/sgp-python/commit/2301157f505874c04a2cd3ab2c09034ed059d332))
* **api:** OpenAPI spec update via Stainless API ([#410](https://github.com/scaleapi/sgp-python/issues/410)) ([ddbed1a](https://github.com/scaleapi/sgp-python/commit/ddbed1a35d7059dcbb98284affc348566104ac78))
* **api:** OpenAPI spec update via Stainless API ([#411](https://github.com/scaleapi/sgp-python/issues/411)) ([a61c634](https://github.com/scaleapi/sgp-python/commit/a61c63405ad63e916bae53e8a3b40808e682ff1a))
* **api:** OpenAPI spec update via Stainless API ([#412](https://github.com/scaleapi/sgp-python/issues/412)) ([a3ba898](https://github.com/scaleapi/sgp-python/commit/a3ba8981d54953c9a30135f8568863d95ce55bea))
* **api:** OpenAPI spec update via Stainless API ([#413](https://github.com/scaleapi/sgp-python/issues/413)) ([fa32f31](https://github.com/scaleapi/sgp-python/commit/fa32f31a6d547e08d0c698a35a5d81f776e65cfc))
* **api:** OpenAPI spec update via Stainless API ([#414](https://github.com/scaleapi/sgp-python/issues/414)) ([88ff79d](https://github.com/scaleapi/sgp-python/commit/88ff79d74c59fb08ae24cdf6f71adac4a2b2b2ea))
* **api:** OpenAPI spec update via Stainless API ([#415](https://github.com/scaleapi/sgp-python/issues/415)) ([85c3f2b](https://github.com/scaleapi/sgp-python/commit/85c3f2b2ea11c1da02af3cde347f9accd3c30503))
* **api:** OpenAPI spec update via Stainless API ([#416](https://github.com/scaleapi/sgp-python/issues/416)) ([9826598](https://github.com/scaleapi/sgp-python/commit/9826598f5005cf1d3678c63f2cba7dc10fe42674))
* **api:** OpenAPI spec update via Stainless API ([#417](https://github.com/scaleapi/sgp-python/issues/417)) ([f0e52fe](https://github.com/scaleapi/sgp-python/commit/f0e52fe780da907072859eeab3832b9ff771e5d5))
* **api:** OpenAPI spec update via Stainless API ([#418](https://github.com/scaleapi/sgp-python/issues/418)) ([a31e093](https://github.com/scaleapi/sgp-python/commit/a31e0933a68ee42d41fe53dc0059e7b71fce059b))
* **api:** OpenAPI spec update via Stainless API ([#419](https://github.com/scaleapi/sgp-python/issues/419)) ([260f154](https://github.com/scaleapi/sgp-python/commit/260f154c7fbc8a87b39829035e86af4dbaf7ba85))
* **api:** OpenAPI spec update via Stainless API ([#420](https://github.com/scaleapi/sgp-python/issues/420)) ([441cf95](https://github.com/scaleapi/sgp-python/commit/441cf9510a190c54c441959f843db838544fe53a))
* **api:** OpenAPI spec update via Stainless API ([#421](https://github.com/scaleapi/sgp-python/issues/421)) ([6713e44](https://github.com/scaleapi/sgp-python/commit/6713e441780369e9a2b02330c2b487825e86d1a6))
* **api:** OpenAPI spec update via Stainless API ([#422](https://github.com/scaleapi/sgp-python/issues/422)) ([9dce42c](https://github.com/scaleapi/sgp-python/commit/9dce42cab63ce404f6c44bd431c92fef8a77adf6))
* **api:** OpenAPI spec update via Stainless API ([#423](https://github.com/scaleapi/sgp-python/issues/423)) ([5af7424](https://github.com/scaleapi/sgp-python/commit/5af7424d7a3db01402b85e84721f03d13f41c51d))
* **api:** OpenAPI spec update via Stainless API ([#424](https://github.com/scaleapi/sgp-python/issues/424)) ([1a89d26](https://github.com/scaleapi/sgp-python/commit/1a89d26e8adf0680b8ea5aeb69aeffcb176e607e))
* **api:** OpenAPI spec update via Stainless API ([#425](https://github.com/scaleapi/sgp-python/issues/425)) ([e252a6e](https://github.com/scaleapi/sgp-python/commit/e252a6e2100e7c461adcadf69c0a282706c71dac))
* **api:** OpenAPI spec update via Stainless API ([#426](https://github.com/scaleapi/sgp-python/issues/426)) ([f76ebd2](https://github.com/scaleapi/sgp-python/commit/f76ebd213477f4d7f0d4c24e3e770695eeb5a4bb))
* **api:** OpenAPI spec update via Stainless API ([#427](https://github.com/scaleapi/sgp-python/issues/427)) ([29c0980](https://github.com/scaleapi/sgp-python/commit/29c098093ce3b741b6fd589d727ced1f5474f8f6))
* **api:** OpenAPI spec update via Stainless API ([#428](https://github.com/scaleapi/sgp-python/issues/428)) ([497cd99](https://github.com/scaleapi/sgp-python/commit/497cd995ad7b87da697b78d6900fa92faad736a7))
* **api:** OpenAPI spec update via Stainless API ([#429](https://github.com/scaleapi/sgp-python/issues/429)) ([2dbe4eb](https://github.com/scaleapi/sgp-python/commit/2dbe4ebb2a63cf8f8bf84f9f58007266ded1c6aa))
* **api:** OpenAPI spec update via Stainless API ([#430](https://github.com/scaleapi/sgp-python/issues/430)) ([3ea8131](https://github.com/scaleapi/sgp-python/commit/3ea8131020dd267ff10748b9d575ee516f63221b))
* **api:** OpenAPI spec update via Stainless API ([#431](https://github.com/scaleapi/sgp-python/issues/431)) ([19cd230](https://github.com/scaleapi/sgp-python/commit/19cd2302cfab11593830190687b1337ac1829497))
* **api:** OpenAPI spec update via Stainless API ([#432](https://github.com/scaleapi/sgp-python/issues/432)) ([a8e098e](https://github.com/scaleapi/sgp-python/commit/a8e098ebfd883fe5bd77a49c4d0f62aab36b80b5))
* **api:** OpenAPI spec update via Stainless API ([#433](https://github.com/scaleapi/sgp-python/issues/433)) ([8f37c1b](https://github.com/scaleapi/sgp-python/commit/8f37c1ba2261bf7849020e9465ad540f3099cbfd))
* **api:** OpenAPI spec update via Stainless API ([#434](https://github.com/scaleapi/sgp-python/issues/434)) ([5fb780b](https://github.com/scaleapi/sgp-python/commit/5fb780b1ca15893745256aba093c7c122a9ecc3b))
* **api:** OpenAPI spec update via Stainless API ([#435](https://github.com/scaleapi/sgp-python/issues/435)) ([989a404](https://github.com/scaleapi/sgp-python/commit/989a4049c64b1d60db29ab00d28f145d8973e9e1))
* **api:** OpenAPI spec update via Stainless API ([#436](https://github.com/scaleapi/sgp-python/issues/436)) ([3571acd](https://github.com/scaleapi/sgp-python/commit/3571acd4fcb21ae559ad6c3552fc1f12b103abc3))
* **api:** OpenAPI spec update via Stainless API ([#437](https://github.com/scaleapi/sgp-python/issues/437)) ([e492bed](https://github.com/scaleapi/sgp-python/commit/e492bed212af62de4f09d318fb9a3649830235d9))
* **api:** OpenAPI spec update via Stainless API ([#438](https://github.com/scaleapi/sgp-python/issues/438)) ([244e343](https://github.com/scaleapi/sgp-python/commit/244e3438bd60aaa55f5c31e12984cb1cdd1f0896))
* **api:** OpenAPI spec update via Stainless API ([#439](https://github.com/scaleapi/sgp-python/issues/439)) ([3554b29](https://github.com/scaleapi/sgp-python/commit/3554b298ff5251aa7e91703ecf66cd84de1675ba))
* **api:** OpenAPI spec update via Stainless API ([#440](https://github.com/scaleapi/sgp-python/issues/440)) ([f5d080b](https://github.com/scaleapi/sgp-python/commit/f5d080be363092afea6635b59bba40ba23b09082))
* **api:** OpenAPI spec update via Stainless API ([#441](https://github.com/scaleapi/sgp-python/issues/441)) ([62cc1d0](https://github.com/scaleapi/sgp-python/commit/62cc1d0e7eea9d6c056aa9f78dd1d4c13f063a39))
* **api:** OpenAPI spec update via Stainless API ([#442](https://github.com/scaleapi/sgp-python/issues/442)) ([3329ef5](https://github.com/scaleapi/sgp-python/commit/3329ef509ef16a801a2f2f2a6bd4dba2d47fcc5b))
* **api:** OpenAPI spec update via Stainless API ([#443](https://github.com/scaleapi/sgp-python/issues/443)) ([24a114c](https://github.com/scaleapi/sgp-python/commit/24a114caa6df2518f8f4d1a577f65e628d2dd1a3))
* **api:** OpenAPI spec update via Stainless API ([#444](https://github.com/scaleapi/sgp-python/issues/444)) ([f9f88a4](https://github.com/scaleapi/sgp-python/commit/f9f88a45cc4cac0d692570c1bf62aaa24f9a8115))
* **api:** OpenAPI spec update via Stainless API ([#445](https://github.com/scaleapi/sgp-python/issues/445)) ([2f50f26](https://github.com/scaleapi/sgp-python/commit/2f50f26793edd3e3468bae5f6d1bfbf6d6a1dadc))
* **api:** OpenAPI spec update via Stainless API ([#446](https://github.com/scaleapi/sgp-python/issues/446)) ([3a9c67b](https://github.com/scaleapi/sgp-python/commit/3a9c67b93796e8ca0e672a4367f923aa819ccb63))
* **api:** OpenAPI spec update via Stainless API ([#447](https://github.com/scaleapi/sgp-python/issues/447)) ([134d011](https://github.com/scaleapi/sgp-python/commit/134d01195b39788e8a34d5ba0cd7307282bc1e00))
* **api:** OpenAPI spec update via Stainless API ([#448](https://github.com/scaleapi/sgp-python/issues/448)) ([5a30e7c](https://github.com/scaleapi/sgp-python/commit/5a30e7c2062fe1857acf9c61efd5f762c32f234a))
* **api:** OpenAPI spec update via Stainless API ([#449](https://github.com/scaleapi/sgp-python/issues/449)) ([45c7c20](https://github.com/scaleapi/sgp-python/commit/45c7c20de67af8c3b8770865c673046f6ce115a2))
* **api:** OpenAPI spec update via Stainless API ([#450](https://github.com/scaleapi/sgp-python/issues/450)) ([265505f](https://github.com/scaleapi/sgp-python/commit/265505fb76ec95dda52e53111a15a8911e2a3fc4))
* **api:** OpenAPI spec update via Stainless API ([#451](https://github.com/scaleapi/sgp-python/issues/451)) ([076ccd1](https://github.com/scaleapi/sgp-python/commit/076ccd166cbce9053c58d4aa40b2c0305ed48336))
* **api:** OpenAPI spec update via Stainless API ([#452](https://github.com/scaleapi/sgp-python/issues/452)) ([3120e84](https://github.com/scaleapi/sgp-python/commit/3120e841999b260bc4a882af9bcfee873d9efea8))
* **api:** OpenAPI spec update via Stainless API ([#453](https://github.com/scaleapi/sgp-python/issues/453)) ([1ef9bbe](https://github.com/scaleapi/sgp-python/commit/1ef9bbe1306176027feffb2cc2518514bdf9ae00))
* **api:** OpenAPI spec update via Stainless API ([#454](https://github.com/scaleapi/sgp-python/issues/454)) ([c02c787](https://github.com/scaleapi/sgp-python/commit/c02c7875f63ecde61dc88099403688be1c9560d4))
* **api:** OpenAPI spec update via Stainless API ([#455](https://github.com/scaleapi/sgp-python/issues/455)) ([d3c1a4a](https://github.com/scaleapi/sgp-python/commit/d3c1a4aa92ab99c466ad082f1b79d9f2b94f2ada))
* **api:** OpenAPI spec update via Stainless API ([#456](https://github.com/scaleapi/sgp-python/issues/456)) ([7af435b](https://github.com/scaleapi/sgp-python/commit/7af435b707f4c120b908e29891d7f32d27bd74d7))
* **api:** OpenAPI spec update via Stainless API ([#457](https://github.com/scaleapi/sgp-python/issues/457)) ([8f72069](https://github.com/scaleapi/sgp-python/commit/8f7206930deff60dcea0a7c2f466045fc655d0f1))
* **api:** OpenAPI spec update via Stainless API ([#458](https://github.com/scaleapi/sgp-python/issues/458)) ([7da5ef1](https://github.com/scaleapi/sgp-python/commit/7da5ef1b5686a730329b5bc0af0ea0befbd41125))
* **api:** OpenAPI spec update via Stainless API ([#459](https://github.com/scaleapi/sgp-python/issues/459)) ([9f75db4](https://github.com/scaleapi/sgp-python/commit/9f75db4f4ff6aae5fc54fbac35543622870213a6))
* **api:** OpenAPI spec update via Stainless API ([#460](https://github.com/scaleapi/sgp-python/issues/460)) ([19b6d92](https://github.com/scaleapi/sgp-python/commit/19b6d924c71ebf96540cd0fd72e89513f73ee3f0))
* **api:** OpenAPI spec update via Stainless API ([#461](https://github.com/scaleapi/sgp-python/issues/461)) ([3729940](https://github.com/scaleapi/sgp-python/commit/3729940e25d54b274f833cab717e36c33c0d0642))
* **api:** OpenAPI spec update via Stainless API ([#462](https://github.com/scaleapi/sgp-python/issues/462)) ([c29aa87](https://github.com/scaleapi/sgp-python/commit/c29aa87596840d23dae13d9d0052a2962f55ba2f))
* **api:** OpenAPI spec update via Stainless API ([#463](https://github.com/scaleapi/sgp-python/issues/463)) ([6c7b96a](https://github.com/scaleapi/sgp-python/commit/6c7b96aeb3d742a571b1de65524cb856a7bee91c))
* **api:** OpenAPI spec update via Stainless API ([#464](https://github.com/scaleapi/sgp-python/issues/464)) ([3566981](https://github.com/scaleapi/sgp-python/commit/3566981449d7ec9bfb0c8ee3f37a05c858c7df99))
* **api:** OpenAPI spec update via Stainless API ([#465](https://github.com/scaleapi/sgp-python/issues/465)) ([c78fdf4](https://github.com/scaleapi/sgp-python/commit/c78fdf4e6bd025729f562907ec8cf9cced19ef92))
* **api:** OpenAPI spec update via Stainless API ([#466](https://github.com/scaleapi/sgp-python/issues/466)) ([72ea929](https://github.com/scaleapi/sgp-python/commit/72ea929ae66477a1d8e7c3f7998f72ce4a18448a))
* **api:** OpenAPI spec update via Stainless API ([#467](https://github.com/scaleapi/sgp-python/issues/467)) ([7f9567b](https://github.com/scaleapi/sgp-python/commit/7f9567b62c3eeac79ec1882156edcb9ce03979e6))
* **api:** OpenAPI spec update via Stainless API ([#468](https://github.com/scaleapi/sgp-python/issues/468)) ([6afd63c](https://github.com/scaleapi/sgp-python/commit/6afd63c9c8d1c4e674d972a26bdc958b8355d41c))
* **api:** OpenAPI spec update via Stainless API ([#469](https://github.com/scaleapi/sgp-python/issues/469)) ([1bbc50e](https://github.com/scaleapi/sgp-python/commit/1bbc50ebecd3ef47a6a85ce123ae7e00042870ca))
* **api:** OpenAPI spec update via Stainless API ([#470](https://github.com/scaleapi/sgp-python/issues/470)) ([1877062](https://github.com/scaleapi/sgp-python/commit/1877062e42863eac1b60c99f567052e485287d25))
* **api:** OpenAPI spec update via Stainless API ([#471](https://github.com/scaleapi/sgp-python/issues/471)) ([96f9494](https://github.com/scaleapi/sgp-python/commit/96f9494c503c9f6bff2d50392803f27bc90bbef3))
* **api:** OpenAPI spec update via Stainless API ([#472](https://github.com/scaleapi/sgp-python/issues/472)) ([c113a09](https://github.com/scaleapi/sgp-python/commit/c113a09820fb934f429bfd13c0b7a0b223ca6a2f))
* **api:** OpenAPI spec update via Stainless API ([#473](https://github.com/scaleapi/sgp-python/issues/473)) ([a92db0b](https://github.com/scaleapi/sgp-python/commit/a92db0b82b02bb6acbc9e0c823428d7e7a9a17c2))
* **api:** OpenAPI spec update via Stainless API ([#474](https://github.com/scaleapi/sgp-python/issues/474)) ([55f1e7e](https://github.com/scaleapi/sgp-python/commit/55f1e7ed12871e691a424e6716403c5b79964cde))
* **api:** OpenAPI spec update via Stainless API ([#475](https://github.com/scaleapi/sgp-python/issues/475)) ([2c31dfb](https://github.com/scaleapi/sgp-python/commit/2c31dfbc4e6711ef5c78f0e645b5233e9f7f2358))
* **api:** OpenAPI spec update via Stainless API ([#476](https://github.com/scaleapi/sgp-python/issues/476)) ([e1b09fa](https://github.com/scaleapi/sgp-python/commit/e1b09fa1502ab325ace4d19a1ed3dfc4bb4ba179))
* **api:** OpenAPI spec update via Stainless API ([#477](https://github.com/scaleapi/sgp-python/issues/477)) ([59e25e7](https://github.com/scaleapi/sgp-python/commit/59e25e726a467b2ec83477f00b7b3e42ea8ff327))
* **api:** OpenAPI spec update via Stainless API ([#479](https://github.com/scaleapi/sgp-python/issues/479)) ([d992c9d](https://github.com/scaleapi/sgp-python/commit/d992c9d1a3ed7f5df49ef9793d0f83cc679bc6d1))
* **api:** OpenAPI spec update via Stainless API ([#480](https://github.com/scaleapi/sgp-python/issues/480)) ([189f1fb](https://github.com/scaleapi/sgp-python/commit/189f1fb9e7cdf58023e6f36591b33dab95022281))
* **api:** OpenAPI spec update via Stainless API ([#482](https://github.com/scaleapi/sgp-python/issues/482)) ([55c1426](https://github.com/scaleapi/sgp-python/commit/55c14262d2cbacad5d6eb2acaed896075ffb53bf))
* **api:** OpenAPI spec update via Stainless API ([#483](https://github.com/scaleapi/sgp-python/issues/483)) ([7befa0b](https://github.com/scaleapi/sgp-python/commit/7befa0b90ec33bbaa47e65dc7f25b63343616718))
* **api:** OpenAPI spec update via Stainless API ([#484](https://github.com/scaleapi/sgp-python/issues/484)) ([7dd49c2](https://github.com/scaleapi/sgp-python/commit/7dd49c24f02c78480a0881073e4d7872dc3f459c))
* **api:** OpenAPI spec update via Stainless API ([#485](https://github.com/scaleapi/sgp-python/issues/485)) ([f03c17d](https://github.com/scaleapi/sgp-python/commit/f03c17df6f21c45d9fdbeff4588b48f9114e96d8))
* **api:** OpenAPI spec update via Stainless API ([#486](https://github.com/scaleapi/sgp-python/issues/486)) ([26aa06e](https://github.com/scaleapi/sgp-python/commit/26aa06e9dfc2ea1676b6467925da7a4ab8b9aed1))
* **api:** OpenAPI spec update via Stainless API ([#487](https://github.com/scaleapi/sgp-python/issues/487)) ([e020582](https://github.com/scaleapi/sgp-python/commit/e0205828ac2ee78bf649d5060b0e6e12a3ea404a))
* **api:** OpenAPI spec update via Stainless API ([#488](https://github.com/scaleapi/sgp-python/issues/488)) ([977079a](https://github.com/scaleapi/sgp-python/commit/977079a4b5bb157c73d3629d0c82f43880d2d248))
* **api:** OpenAPI spec update via Stainless API ([#489](https://github.com/scaleapi/sgp-python/issues/489)) ([1ed983e](https://github.com/scaleapi/sgp-python/commit/1ed983e2cad36040797796633fb8af625118f014))
* **api:** OpenAPI spec update via Stainless API ([#490](https://github.com/scaleapi/sgp-python/issues/490)) ([6b83e0d](https://github.com/scaleapi/sgp-python/commit/6b83e0d1e4de29f36cb27599ae435d49676b57b1))
* **api:** OpenAPI spec update via Stainless API ([#491](https://github.com/scaleapi/sgp-python/issues/491)) ([7e12ae3](https://github.com/scaleapi/sgp-python/commit/7e12ae36dc71207755e961b9cfcd6d5d04223b11))
* **api:** OpenAPI spec update via Stainless API ([#492](https://github.com/scaleapi/sgp-python/issues/492)) ([14a185e](https://github.com/scaleapi/sgp-python/commit/14a185ef8245d0a6a35db8c35923a290c41db186))
* **api:** OpenAPI spec update via Stainless API ([#494](https://github.com/scaleapi/sgp-python/issues/494)) ([6af1ce9](https://github.com/scaleapi/sgp-python/commit/6af1ce91bd0d3ab6f88afc3aa788fa5de9e362fa))
* **api:** OpenAPI spec update via Stainless API ([#495](https://github.com/scaleapi/sgp-python/issues/495)) ([640edde](https://github.com/scaleapi/sgp-python/commit/640edde1693070f882ca17cdae1c4cb4185e2fa7))
* **api:** OpenAPI spec update via Stainless API ([#498](https://github.com/scaleapi/sgp-python/issues/498)) ([8eee6e2](https://github.com/scaleapi/sgp-python/commit/8eee6e27bd7f7d6556e5e0c02460dab92859f0f4))
* **api:** OpenAPI spec update via Stainless API ([#499](https://github.com/scaleapi/sgp-python/issues/499)) ([3577401](https://github.com/scaleapi/sgp-python/commit/35774014cc041e7fffd3526fbfb16a0c06a3d9d8))
* **api:** OpenAPI spec update via Stainless API ([#500](https://github.com/scaleapi/sgp-python/issues/500)) ([83c629c](https://github.com/scaleapi/sgp-python/commit/83c629ce6fd1fe7c6ed9aa242d864535a0879761))
* **api:** OpenAPI spec update via Stainless API ([#501](https://github.com/scaleapi/sgp-python/issues/501)) ([57762bd](https://github.com/scaleapi/sgp-python/commit/57762bd38007bee1a448b07724962d1b4695e6b2))
* **api:** OpenAPI spec update via Stainless API ([#502](https://github.com/scaleapi/sgp-python/issues/502)) ([52cc725](https://github.com/scaleapi/sgp-python/commit/52cc725f329e3d297411f30fca51793c4db96154))
* **api:** OpenAPI spec update via Stainless API ([#503](https://github.com/scaleapi/sgp-python/issues/503)) ([eec48f0](https://github.com/scaleapi/sgp-python/commit/eec48f041f445c16fc606eb3a005fcc20f453708))
* **api:** OpenAPI spec update via Stainless API ([#504](https://github.com/scaleapi/sgp-python/issues/504)) ([82c18d1](https://github.com/scaleapi/sgp-python/commit/82c18d122a2e00e1331355968d8e0a8de239bf8c))
* **api:** OpenAPI spec update via Stainless API ([#505](https://github.com/scaleapi/sgp-python/issues/505)) ([3e91d73](https://github.com/scaleapi/sgp-python/commit/3e91d737235e20c834242df854a6cda32d83c839))
* **api:** OpenAPI spec update via Stainless API ([#506](https://github.com/scaleapi/sgp-python/issues/506)) ([3da7aaf](https://github.com/scaleapi/sgp-python/commit/3da7aaf6ab09935007edef3064cd5ee969d33f92))
* **api:** OpenAPI spec update via Stainless API ([#507](https://github.com/scaleapi/sgp-python/issues/507)) ([f08a889](https://github.com/scaleapi/sgp-python/commit/f08a889bf634f38ca4bc7ae47ab810f4fe7bebfa))
* **api:** OpenAPI spec update via Stainless API ([#508](https://github.com/scaleapi/sgp-python/issues/508)) ([9ea2775](https://github.com/scaleapi/sgp-python/commit/9ea2775f5cf5c5385c41d8ca5ae48e9e9b3fa7b4))
* **api:** OpenAPI spec update via Stainless API ([#509](https://github.com/scaleapi/sgp-python/issues/509)) ([6eb08d5](https://github.com/scaleapi/sgp-python/commit/6eb08d5965173556b72f67c843616ffaf692a3c1))
* **api:** OpenAPI spec update via Stainless API ([#510](https://github.com/scaleapi/sgp-python/issues/510)) ([f9fd282](https://github.com/scaleapi/sgp-python/commit/f9fd282aadf4dc19ddd10887944e4137d41d8d64))
* **api:** OpenAPI spec update via Stainless API ([#511](https://github.com/scaleapi/sgp-python/issues/511)) ([6541c7d](https://github.com/scaleapi/sgp-python/commit/6541c7d529e2d1fb6530b217d714bb98759bfd7c))
* **api:** OpenAPI spec update via Stainless API ([#512](https://github.com/scaleapi/sgp-python/issues/512)) ([811dd25](https://github.com/scaleapi/sgp-python/commit/811dd2515db9b67c727b676623be78f1e3694fe8))
* **api:** OpenAPI spec update via Stainless API ([#513](https://github.com/scaleapi/sgp-python/issues/513)) ([65884bc](https://github.com/scaleapi/sgp-python/commit/65884bc75ee1a2a0d100fd2b71d38d68f439298b))
* **api:** OpenAPI spec update via Stainless API ([#514](https://github.com/scaleapi/sgp-python/issues/514)) ([85155ff](https://github.com/scaleapi/sgp-python/commit/85155ffa586e526c30f9520900fe9064cdcac3a1))
* **api:** OpenAPI spec update via Stainless API ([#515](https://github.com/scaleapi/sgp-python/issues/515)) ([f8987b9](https://github.com/scaleapi/sgp-python/commit/f8987b9c7b97d673df1561bcb9a1ed905638daa4))
* **api:** OpenAPI spec update via Stainless API ([#516](https://github.com/scaleapi/sgp-python/issues/516)) ([bf3f10b](https://github.com/scaleapi/sgp-python/commit/bf3f10b30b9c4ab8a2e3ff5d2412502889d04658))
* **api:** OpenAPI spec update via Stainless API ([#517](https://github.com/scaleapi/sgp-python/issues/517)) ([108278a](https://github.com/scaleapi/sgp-python/commit/108278a01092ab3f767a39437defceea8916abca))
* **api:** OpenAPI spec update via Stainless API ([#519](https://github.com/scaleapi/sgp-python/issues/519)) ([ad57639](https://github.com/scaleapi/sgp-python/commit/ad57639c77b86c3812bec3665a455d80cf80c35b))
* **api:** OpenAPI spec update via Stainless API ([#520](https://github.com/scaleapi/sgp-python/issues/520)) ([390e4a2](https://github.com/scaleapi/sgp-python/commit/390e4a256265e9b0b9d2e0605020bb1196ade950))
* **api:** OpenAPI spec update via Stainless API ([#521](https://github.com/scaleapi/sgp-python/issues/521)) ([1bb6071](https://github.com/scaleapi/sgp-python/commit/1bb607141655f360f37d79b7342b1e73cd691e6f))
* **api:** OpenAPI spec update via Stainless API ([#522](https://github.com/scaleapi/sgp-python/issues/522)) ([6f02d66](https://github.com/scaleapi/sgp-python/commit/6f02d66ec7506bbed3a76f75ae930be42353649d))
* **api:** OpenAPI spec update via Stainless API ([#523](https://github.com/scaleapi/sgp-python/issues/523)) ([6391af9](https://github.com/scaleapi/sgp-python/commit/6391af9e0a67e3365a856040fa49ed977ac64840))
* **api:** OpenAPI spec update via Stainless API ([#524](https://github.com/scaleapi/sgp-python/issues/524)) ([fc15d54](https://github.com/scaleapi/sgp-python/commit/fc15d54021c4df855ceafe2702cd44caea497c39))
* **api:** OpenAPI spec update via Stainless API ([#525](https://github.com/scaleapi/sgp-python/issues/525)) ([a0917d4](https://github.com/scaleapi/sgp-python/commit/a0917d47b70a4bcdda5d071ca7859c48a8732f56))
* **api:** OpenAPI spec update via Stainless API ([#526](https://github.com/scaleapi/sgp-python/issues/526)) ([8de6cb1](https://github.com/scaleapi/sgp-python/commit/8de6cb104df40ceb8c610ae5a2bf0c47d718c9d5))
* **api:** OpenAPI spec update via Stainless API ([#527](https://github.com/scaleapi/sgp-python/issues/527)) ([8e05d6b](https://github.com/scaleapi/sgp-python/commit/8e05d6bd5a15b9b8fe5f906c1767b10ca4c15396))
* **api:** OpenAPI spec update via Stainless API ([#528](https://github.com/scaleapi/sgp-python/issues/528)) ([cf0cb17](https://github.com/scaleapi/sgp-python/commit/cf0cb176face2ad22ec784e26b4abe68e223fd28))
* **api:** OpenAPI spec update via Stainless API ([#529](https://github.com/scaleapi/sgp-python/issues/529)) ([25a7966](https://github.com/scaleapi/sgp-python/commit/25a796635593ddf4ecd9deb30489f1f054983323))
* **api:** OpenAPI spec update via Stainless API ([#530](https://github.com/scaleapi/sgp-python/issues/530)) ([733194a](https://github.com/scaleapi/sgp-python/commit/733194aa3e1aaa44625f2e272b5bcae1d35f31f8))
* **api:** OpenAPI spec update via Stainless API ([#531](https://github.com/scaleapi/sgp-python/issues/531)) ([4577bdc](https://github.com/scaleapi/sgp-python/commit/4577bdcacea5500d5635a426d6a61f21fb3784ae))
* **api:** OpenAPI spec update via Stainless API ([#532](https://github.com/scaleapi/sgp-python/issues/532)) ([8c7dd39](https://github.com/scaleapi/sgp-python/commit/8c7dd399933aeaf96a3c6567f75acc34bda72723))
* **api:** OpenAPI spec update via Stainless API ([#533](https://github.com/scaleapi/sgp-python/issues/533)) ([5beec81](https://github.com/scaleapi/sgp-python/commit/5beec81363b19ba11c8341cb038c51fcff2118e0))
* **api:** OpenAPI spec update via Stainless API ([#534](https://github.com/scaleapi/sgp-python/issues/534)) ([60394fd](https://github.com/scaleapi/sgp-python/commit/60394fd5c6f56dad5b62393ee0453843bf5aea96))
* **api:** OpenAPI spec update via Stainless API ([#535](https://github.com/scaleapi/sgp-python/issues/535)) ([bdf60b3](https://github.com/scaleapi/sgp-python/commit/bdf60b3860109630f204aa635514b4ce9ceb3972))
* **api:** OpenAPI spec update via Stainless API ([#536](https://github.com/scaleapi/sgp-python/issues/536)) ([e5c9448](https://github.com/scaleapi/sgp-python/commit/e5c94487704d7ef100cb71256313430817c47130))
* **api:** OpenAPI spec update via Stainless API ([#537](https://github.com/scaleapi/sgp-python/issues/537)) ([0a82a63](https://github.com/scaleapi/sgp-python/commit/0a82a634e61fb09c80879152bdacd459fcd34d35))
* **api:** OpenAPI spec update via Stainless API ([#538](https://github.com/scaleapi/sgp-python/issues/538)) ([41a900d](https://github.com/scaleapi/sgp-python/commit/41a900d49d0670c5d4458d968f7cd4ec452bcb5a))
* **api:** OpenAPI spec update via Stainless API ([#539](https://github.com/scaleapi/sgp-python/issues/539)) ([79c0df8](https://github.com/scaleapi/sgp-python/commit/79c0df8aaecf4f2361fbc08ed079fe365eb042de))
* **api:** OpenAPI spec update via Stainless API ([#540](https://github.com/scaleapi/sgp-python/issues/540)) ([6f6c705](https://github.com/scaleapi/sgp-python/commit/6f6c705034db616e80aafbb7156e3c590e07d248))
* **api:** OpenAPI spec update via Stainless API ([#541](https://github.com/scaleapi/sgp-python/issues/541)) ([ca2fb15](https://github.com/scaleapi/sgp-python/commit/ca2fb15720829dc972aa198c5d6d1ebf55c54e8e))
* **api:** OpenAPI spec update via Stainless API ([#542](https://github.com/scaleapi/sgp-python/issues/542)) ([c8eee71](https://github.com/scaleapi/sgp-python/commit/c8eee713b3d24cf5f190777386d20a70203cdbba))
* **api:** OpenAPI spec update via Stainless API ([#543](https://github.com/scaleapi/sgp-python/issues/543)) ([4bdba4b](https://github.com/scaleapi/sgp-python/commit/4bdba4bf10ae0a6ff80bc571f5691af20cfaf553))
* **api:** OpenAPI spec update via Stainless API ([#544](https://github.com/scaleapi/sgp-python/issues/544)) ([2667cc2](https://github.com/scaleapi/sgp-python/commit/2667cc2a10a4e80abc09d8713b1efb2438fea177))
* **api:** OpenAPI spec update via Stainless API ([#545](https://github.com/scaleapi/sgp-python/issues/545)) ([547cf55](https://github.com/scaleapi/sgp-python/commit/547cf55c0e23be26dd0bb4d21bf3d392c02ad941))
* **api:** OpenAPI spec update via Stainless API ([#546](https://github.com/scaleapi/sgp-python/issues/546)) ([314d76a](https://github.com/scaleapi/sgp-python/commit/314d76a97c05c0d8e3502a86f2c285d827d85271))
* **api:** OpenAPI spec update via Stainless API ([#547](https://github.com/scaleapi/sgp-python/issues/547)) ([b2b2112](https://github.com/scaleapi/sgp-python/commit/b2b2112a7ab6a46dd7adcdff26dca5816d2e7251))
* **api:** OpenAPI spec update via Stainless API ([#548](https://github.com/scaleapi/sgp-python/issues/548)) ([ff2a015](https://github.com/scaleapi/sgp-python/commit/ff2a015f3de0fea84834fb2681a92327d25e6900))
* **api:** OpenAPI spec update via Stainless API ([#549](https://github.com/scaleapi/sgp-python/issues/549)) ([9957ed9](https://github.com/scaleapi/sgp-python/commit/9957ed9ae1da42dfb1d6aeb6c0d44115b5a026fb))
* **api:** OpenAPI spec update via Stainless API ([#550](https://github.com/scaleapi/sgp-python/issues/550)) ([a977893](https://github.com/scaleapi/sgp-python/commit/a977893164dcd5a26addece5748be40f788dd87e))
* **api:** OpenAPI spec update via Stainless API ([#551](https://github.com/scaleapi/sgp-python/issues/551)) ([11f7692](https://github.com/scaleapi/sgp-python/commit/11f7692b80df31a9d4dbf7afcf8ea384c696b728))
* **api:** OpenAPI spec update via Stainless API ([#552](https://github.com/scaleapi/sgp-python/issues/552)) ([e4be622](https://github.com/scaleapi/sgp-python/commit/e4be62247a96e7266620f51c2c117c087b9478f1))
* **api:** OpenAPI spec update via Stainless API ([#553](https://github.com/scaleapi/sgp-python/issues/553)) ([b123b0a](https://github.com/scaleapi/sgp-python/commit/b123b0ac449e6050dcd27bded990d1b87bec0f76))
* **api:** OpenAPI spec update via Stainless API ([#554](https://github.com/scaleapi/sgp-python/issues/554)) ([7128770](https://github.com/scaleapi/sgp-python/commit/712877028421f9c635bb0355df6c95924f56f914))
* **api:** OpenAPI spec update via Stainless API ([#555](https://github.com/scaleapi/sgp-python/issues/555)) ([ecce167](https://github.com/scaleapi/sgp-python/commit/ecce167eb7b69af7022b8227ff9c9ff69d8ba06a))
* **api:** OpenAPI spec update via Stainless API ([#556](https://github.com/scaleapi/sgp-python/issues/556)) ([5301d2c](https://github.com/scaleapi/sgp-python/commit/5301d2c38bffdf228129ffd8078244e862c185c8))
* **api:** OpenAPI spec update via Stainless API ([#557](https://github.com/scaleapi/sgp-python/issues/557)) ([ca3aabc](https://github.com/scaleapi/sgp-python/commit/ca3aabccd56ffebb2cb4d3ccd7f60ca5aee7d824))
* **api:** OpenAPI spec update via Stainless API ([#558](https://github.com/scaleapi/sgp-python/issues/558)) ([b24d0ef](https://github.com/scaleapi/sgp-python/commit/b24d0efce99221f05526c60215911a52bf26994a))
* **api:** OpenAPI spec update via Stainless API ([#559](https://github.com/scaleapi/sgp-python/issues/559)) ([1fea806](https://github.com/scaleapi/sgp-python/commit/1fea806600098724e8b8fc7a939bea4097c66342))
* **api:** OpenAPI spec update via Stainless API ([#560](https://github.com/scaleapi/sgp-python/issues/560)) ([9d8c3c8](https://github.com/scaleapi/sgp-python/commit/9d8c3c8726d6b936694f1e7cdbce66e4a729154b))
* **api:** OpenAPI spec update via Stainless API ([#561](https://github.com/scaleapi/sgp-python/issues/561)) ([4b541d9](https://github.com/scaleapi/sgp-python/commit/4b541d95e98703051aaff254feaba4b81b881384))
* **api:** OpenAPI spec update via Stainless API ([#562](https://github.com/scaleapi/sgp-python/issues/562)) ([fb5f48f](https://github.com/scaleapi/sgp-python/commit/fb5f48f43238678f49d7d63e79cda8dfccf0e9e7))
* **api:** OpenAPI spec update via Stainless API ([#563](https://github.com/scaleapi/sgp-python/issues/563)) ([84fcf74](https://github.com/scaleapi/sgp-python/commit/84fcf743fe85dab0b8fd4daa460e0afdddc68014))
* **api:** OpenAPI spec update via Stainless API ([#565](https://github.com/scaleapi/sgp-python/issues/565)) ([f6dade8](https://github.com/scaleapi/sgp-python/commit/f6dade8329883cad4f4b0679cf2fd414b152fc64))
* **api:** OpenAPI spec update via Stainless API ([#566](https://github.com/scaleapi/sgp-python/issues/566)) ([6730c76](https://github.com/scaleapi/sgp-python/commit/6730c761ceca8a9a8a568270a5e6d9c442ad111e))
* **api:** update via SDK Studio ([#496](https://github.com/scaleapi/sgp-python/issues/496)) ([9f5822d](https://github.com/scaleapi/sgp-python/commit/9f5822de37316202482d01b1b4ffc0d103ace806))
* **api:** update via SDK Studio ([#497](https://github.com/scaleapi/sgp-python/issues/497)) ([2b1cba6](https://github.com/scaleapi/sgp-python/commit/2b1cba62a5e2668281e1416753252ca11035349c))


### Chores

* fix error message import example ([#518](https://github.com/scaleapi/sgp-python/issues/518)) ([adbb702](https://github.com/scaleapi/sgp-python/commit/adbb702f0b3ffa7e95d86903fb18cd95bd2089c0))
* **internal:** refactor release doctor script ([#478](https://github.com/scaleapi/sgp-python/issues/478)) ([e3fa09e](https://github.com/scaleapi/sgp-python/commit/e3fa09e6e443bfb3e6483c8da9813bbb93ae20f8))
* **tests:** update prism version ([#493](https://github.com/scaleapi/sgp-python/issues/493)) ([8594836](https://github.com/scaleapi/sgp-python/commit/85948362f052449b41924cabed73f01db65eb798))

## 0.1.0-alpha.17 (2024-07-19)

Full Changelog: [v0.1.0-alpha.16...v0.1.0-alpha.17](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.16...v0.1.0-alpha.17)

### Features

* **api:** update via SDK Studio ([#404](https://github.com/scaleapi/sgp-python/issues/404)) ([100b5b7](https://github.com/scaleapi/sgp-python/commit/100b5b79c2e4f13df557bb0d8580b648f5010901))
* **api:** update via SDK Studio ([#406](https://github.com/scaleapi/sgp-python/issues/406)) ([7218421](https://github.com/scaleapi/sgp-python/commit/721842146738ced16542ce677e79291ee6a4e859))

## 0.1.0-alpha.16 (2024-07-19)

Full Changelog: [v0.1.0-alpha.15...v0.1.0-alpha.16](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.15...v0.1.0-alpha.16)

### Features

* **api:** OpenAPI spec update via Stainless API ([#366](https://github.com/scaleapi/sgp-python/issues/366)) ([3216f5d](https://github.com/scaleapi/sgp-python/commit/3216f5dcb5398702ad8231205041aa9c86a85004))
* **api:** OpenAPI spec update via Stainless API ([#368](https://github.com/scaleapi/sgp-python/issues/368)) ([511d413](https://github.com/scaleapi/sgp-python/commit/511d4137d6a6769b8d1ad1844112836a839b40c4))
* **api:** OpenAPI spec update via Stainless API ([#369](https://github.com/scaleapi/sgp-python/issues/369)) ([c9ce5cc](https://github.com/scaleapi/sgp-python/commit/c9ce5cce134ef3558f37b0c9954da373bbca43e6))
* **api:** OpenAPI spec update via Stainless API ([#370](https://github.com/scaleapi/sgp-python/issues/370)) ([0e2ccaf](https://github.com/scaleapi/sgp-python/commit/0e2ccaf2cd8b8a0f1fa0e32ac0d1c37c4a1bcbe0))
* **api:** OpenAPI spec update via Stainless API ([#371](https://github.com/scaleapi/sgp-python/issues/371)) ([5af9ea1](https://github.com/scaleapi/sgp-python/commit/5af9ea1428b42c6b381dcc7c2f896ac1fda94583))
* **api:** OpenAPI spec update via Stainless API ([#372](https://github.com/scaleapi/sgp-python/issues/372)) ([91fc4c0](https://github.com/scaleapi/sgp-python/commit/91fc4c09b24b22dace288247cf28bb109693bd1f))
* **api:** OpenAPI spec update via Stainless API ([#373](https://github.com/scaleapi/sgp-python/issues/373)) ([4d19bef](https://github.com/scaleapi/sgp-python/commit/4d19bef468e20da44fa44116d278b4038c99139e))
* **api:** OpenAPI spec update via Stainless API ([#374](https://github.com/scaleapi/sgp-python/issues/374)) ([9b73baf](https://github.com/scaleapi/sgp-python/commit/9b73baf78319b73cd4817a2e1e14e65b5d10e78b))
* **api:** OpenAPI spec update via Stainless API ([#375](https://github.com/scaleapi/sgp-python/issues/375)) ([e04bad9](https://github.com/scaleapi/sgp-python/commit/e04bad9e6074510dcc1ebfc9a1f905e813f81227))
* **api:** OpenAPI spec update via Stainless API ([#376](https://github.com/scaleapi/sgp-python/issues/376)) ([b40fd42](https://github.com/scaleapi/sgp-python/commit/b40fd42f9700169ae51d1351fed2c2e39e38c65a))
* **api:** OpenAPI spec update via Stainless API ([#377](https://github.com/scaleapi/sgp-python/issues/377)) ([f22b504](https://github.com/scaleapi/sgp-python/commit/f22b504cbd20d253a474c82d7a154e8f65574395))
* **api:** OpenAPI spec update via Stainless API ([#378](https://github.com/scaleapi/sgp-python/issues/378)) ([a8cd832](https://github.com/scaleapi/sgp-python/commit/a8cd832a7d47296cc957ce951649fda29e94f203))
* **api:** OpenAPI spec update via Stainless API ([#379](https://github.com/scaleapi/sgp-python/issues/379)) ([4de6acc](https://github.com/scaleapi/sgp-python/commit/4de6acc46c1ebfc185b4a0078478a04069892710))
* **api:** OpenAPI spec update via Stainless API ([#380](https://github.com/scaleapi/sgp-python/issues/380)) ([c802d01](https://github.com/scaleapi/sgp-python/commit/c802d01764370debd90f2b078ee6e69507679b41))
* **api:** OpenAPI spec update via Stainless API ([#381](https://github.com/scaleapi/sgp-python/issues/381)) ([febd8cb](https://github.com/scaleapi/sgp-python/commit/febd8cb27736a2ece76f231feb7c1b8b7b220d92))
* **api:** OpenAPI spec update via Stainless API ([#382](https://github.com/scaleapi/sgp-python/issues/382)) ([07199a4](https://github.com/scaleapi/sgp-python/commit/07199a452e0bf0a6169334cfb478a014ef444943))
* **api:** OpenAPI spec update via Stainless API ([#383](https://github.com/scaleapi/sgp-python/issues/383)) ([5c085c6](https://github.com/scaleapi/sgp-python/commit/5c085c6cb36ce873775d7cf48ecb159ba5d53e1d))
* **api:** OpenAPI spec update via Stainless API ([#384](https://github.com/scaleapi/sgp-python/issues/384)) ([bfbfa3d](https://github.com/scaleapi/sgp-python/commit/bfbfa3d885862ce46ac63dc2501955419e5264dc))
* **api:** OpenAPI spec update via Stainless API ([#385](https://github.com/scaleapi/sgp-python/issues/385)) ([b08eae5](https://github.com/scaleapi/sgp-python/commit/b08eae5abb1afba7d37dbd1fb7d11a9d665fd656))
* **api:** OpenAPI spec update via Stainless API ([#386](https://github.com/scaleapi/sgp-python/issues/386)) ([d852761](https://github.com/scaleapi/sgp-python/commit/d852761371133995e386e661ee62dd9b58ac7a41))
* **api:** OpenAPI spec update via Stainless API ([#387](https://github.com/scaleapi/sgp-python/issues/387)) ([06fdbe4](https://github.com/scaleapi/sgp-python/commit/06fdbe440ed4b427369cca986f3e34ac6e9c4020))
* **api:** OpenAPI spec update via Stainless API ([#388](https://github.com/scaleapi/sgp-python/issues/388)) ([3262322](https://github.com/scaleapi/sgp-python/commit/3262322363b71a7a0dbddfe6a3ae52d90e4aaf1f))
* **api:** OpenAPI spec update via Stainless API ([#389](https://github.com/scaleapi/sgp-python/issues/389)) ([fb6d197](https://github.com/scaleapi/sgp-python/commit/fb6d197957169de4b3f381dd4e1bb04d0dced3c8))
* **api:** OpenAPI spec update via Stainless API ([#390](https://github.com/scaleapi/sgp-python/issues/390)) ([b164d43](https://github.com/scaleapi/sgp-python/commit/b164d4336dbf9204105153b66d263cacef05780f))
* **api:** OpenAPI spec update via Stainless API ([#391](https://github.com/scaleapi/sgp-python/issues/391)) ([9730481](https://github.com/scaleapi/sgp-python/commit/97304815e958c032a65f5d52e03ee3b510b57902))
* **api:** OpenAPI spec update via Stainless API ([#392](https://github.com/scaleapi/sgp-python/issues/392)) ([3edc581](https://github.com/scaleapi/sgp-python/commit/3edc581b456660f3daf00eb14217c6655d739c66))
* **api:** OpenAPI spec update via Stainless API ([#393](https://github.com/scaleapi/sgp-python/issues/393)) ([6c4bfce](https://github.com/scaleapi/sgp-python/commit/6c4bfce84a064173ec57a30d8e3a883f04beb4a1))
* **api:** OpenAPI spec update via Stainless API ([#394](https://github.com/scaleapi/sgp-python/issues/394)) ([da48673](https://github.com/scaleapi/sgp-python/commit/da4867312dfc4fe696c37d4eb0c0901cde67de0e))
* **api:** OpenAPI spec update via Stainless API ([#395](https://github.com/scaleapi/sgp-python/issues/395)) ([298ffab](https://github.com/scaleapi/sgp-python/commit/298ffab48067f8865d2ac8b686a12f3e7d8542d0))
* **api:** OpenAPI spec update via Stainless API ([#396](https://github.com/scaleapi/sgp-python/issues/396)) ([1a8d3dc](https://github.com/scaleapi/sgp-python/commit/1a8d3dca432d8e1402fede1d3e50d1f61d8cd552))
* **api:** OpenAPI spec update via Stainless API ([#397](https://github.com/scaleapi/sgp-python/issues/397)) ([f28ed48](https://github.com/scaleapi/sgp-python/commit/f28ed481ac238f54d65a251277385824ced5a25e))
* **api:** OpenAPI spec update via Stainless API ([#398](https://github.com/scaleapi/sgp-python/issues/398)) ([7ff99fb](https://github.com/scaleapi/sgp-python/commit/7ff99fb2a4d152f08ebbf41976e9fe4fde0adf09))
* **api:** OpenAPI spec update via Stainless API ([#399](https://github.com/scaleapi/sgp-python/issues/399)) ([1ef25f2](https://github.com/scaleapi/sgp-python/commit/1ef25f223f44d9381595844bbb0ef2d8186236e7))
* **api:** OpenAPI spec update via Stainless API ([#400](https://github.com/scaleapi/sgp-python/issues/400)) ([62dd17e](https://github.com/scaleapi/sgp-python/commit/62dd17eadc0ba679c9b1f220415a318bd042de42))
* **api:** OpenAPI spec update via Stainless API ([#402](https://github.com/scaleapi/sgp-python/issues/402)) ([1f9e15a](https://github.com/scaleapi/sgp-python/commit/1f9e15a3e8eab0cf5a4d2f633308c895c31d6760))
* **api:** update via SDK Studio ([#401](https://github.com/scaleapi/sgp-python/issues/401)) ([633f608](https://github.com/scaleapi/sgp-python/commit/633f608267d12b16f7b6dec69ea4b02afa64b846))

## 0.1.0-alpha.15 (2024-07-17)

Full Changelog: [v0.1.0-alpha.14...v0.1.0-alpha.15](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.14...v0.1.0-alpha.15)

### Features

* **api:** OpenAPI spec update via Stainless API ([#362](https://github.com/scaleapi/sgp-python/issues/362)) ([c05c747](https://github.com/scaleapi/sgp-python/commit/c05c747dca59c4ea2b3b92fc5c6fc21a149226b5))
* **api:** update via SDK Studio ([#364](https://github.com/scaleapi/sgp-python/issues/364)) ([94e1393](https://github.com/scaleapi/sgp-python/commit/94e1393aa6489267ec1831de6abba8e64e091705))

## 0.1.0-alpha.14 (2024-07-17)

Full Changelog: [v0.1.0-alpha.13...v0.1.0-alpha.14](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.13...v0.1.0-alpha.14)

### Features

* **api:** OpenAPI spec update via Stainless API ([#160](https://github.com/scaleapi/sgp-python/issues/160)) ([bc09c00](https://github.com/scaleapi/sgp-python/commit/bc09c00f2c49d59e7dad51a715131bb9563aa10d))
* **api:** OpenAPI spec update via Stainless API ([#162](https://github.com/scaleapi/sgp-python/issues/162)) ([abe0d83](https://github.com/scaleapi/sgp-python/commit/abe0d83696b7aa40926aab2fd27cb4b53e7a83a0))
* **api:** OpenAPI spec update via Stainless API ([#163](https://github.com/scaleapi/sgp-python/issues/163)) ([590434e](https://github.com/scaleapi/sgp-python/commit/590434e59d5f206cf487f29f7bc28280c1594673))
* **api:** OpenAPI spec update via Stainless API ([#164](https://github.com/scaleapi/sgp-python/issues/164)) ([77521c0](https://github.com/scaleapi/sgp-python/commit/77521c08d1cc401396eca50ed3d95f9867b786b9))
* **api:** OpenAPI spec update via Stainless API ([#165](https://github.com/scaleapi/sgp-python/issues/165)) ([dbe9f3a](https://github.com/scaleapi/sgp-python/commit/dbe9f3aebd82a520e1d3d1dfd9cbbfbc465a7c5a))
* **api:** OpenAPI spec update via Stainless API ([#166](https://github.com/scaleapi/sgp-python/issues/166)) ([f39d2ab](https://github.com/scaleapi/sgp-python/commit/f39d2abb2ff034b04aa6ca3b179e7050276d80d0))
* **api:** OpenAPI spec update via Stainless API ([#167](https://github.com/scaleapi/sgp-python/issues/167)) ([af00385](https://github.com/scaleapi/sgp-python/commit/af00385d7c4128d956be970b20d5b9ff37279fe1))
* **api:** OpenAPI spec update via Stainless API ([#168](https://github.com/scaleapi/sgp-python/issues/168)) ([9e072ae](https://github.com/scaleapi/sgp-python/commit/9e072ae9d76b475fa9aa146d3f5b66adb56a905b))
* **api:** OpenAPI spec update via Stainless API ([#169](https://github.com/scaleapi/sgp-python/issues/169)) ([93dd13b](https://github.com/scaleapi/sgp-python/commit/93dd13bcedc42b751fdfbef0be9a90b5c612bdf3))
* **api:** OpenAPI spec update via Stainless API ([#170](https://github.com/scaleapi/sgp-python/issues/170)) ([09f39dc](https://github.com/scaleapi/sgp-python/commit/09f39dc761fb8bb9786b399fd8b0c082969e4b04))
* **api:** OpenAPI spec update via Stainless API ([#171](https://github.com/scaleapi/sgp-python/issues/171)) ([fbcdb21](https://github.com/scaleapi/sgp-python/commit/fbcdb21ff533564c9cf3616415a2c3848d9754c4))
* **api:** OpenAPI spec update via Stainless API ([#172](https://github.com/scaleapi/sgp-python/issues/172)) ([856c929](https://github.com/scaleapi/sgp-python/commit/856c92988225e51fb7975cc5541e527a21f469d0))
* **api:** OpenAPI spec update via Stainless API ([#173](https://github.com/scaleapi/sgp-python/issues/173)) ([813f76c](https://github.com/scaleapi/sgp-python/commit/813f76c01d750b6555ceb98d841fc617f6d10171))
* **api:** OpenAPI spec update via Stainless API ([#174](https://github.com/scaleapi/sgp-python/issues/174)) ([ac96c6e](https://github.com/scaleapi/sgp-python/commit/ac96c6eaea49f6bc92c2abc1454ce56e86eb24e6))
* **api:** OpenAPI spec update via Stainless API ([#175](https://github.com/scaleapi/sgp-python/issues/175)) ([a312ccb](https://github.com/scaleapi/sgp-python/commit/a312ccbcb859b97843e6893c79c750abcd206128))
* **api:** OpenAPI spec update via Stainless API ([#176](https://github.com/scaleapi/sgp-python/issues/176)) ([ad9f1d7](https://github.com/scaleapi/sgp-python/commit/ad9f1d7d27c4f5bbe26b38fe0117c91ad714a9f4))
* **api:** OpenAPI spec update via Stainless API ([#177](https://github.com/scaleapi/sgp-python/issues/177)) ([22509a3](https://github.com/scaleapi/sgp-python/commit/22509a36ff30d66e09441adb5c422e2f2c13c9f9))
* **api:** OpenAPI spec update via Stainless API ([#178](https://github.com/scaleapi/sgp-python/issues/178)) ([6f3f6b8](https://github.com/scaleapi/sgp-python/commit/6f3f6b81c2911bbd99b11fdb581fdbb6fc72884d))
* **api:** OpenAPI spec update via Stainless API ([#179](https://github.com/scaleapi/sgp-python/issues/179)) ([e1666d8](https://github.com/scaleapi/sgp-python/commit/e1666d8dc68437bec644e75d31cc102beff6faff))
* **api:** OpenAPI spec update via Stainless API ([#180](https://github.com/scaleapi/sgp-python/issues/180)) ([3e8615a](https://github.com/scaleapi/sgp-python/commit/3e8615afa4bbd8a613c7516013c6378b6c0353cc))
* **api:** OpenAPI spec update via Stainless API ([#181](https://github.com/scaleapi/sgp-python/issues/181)) ([42b0d83](https://github.com/scaleapi/sgp-python/commit/42b0d83e5049491e69504090de03060451db93ae))
* **api:** OpenAPI spec update via Stainless API ([#182](https://github.com/scaleapi/sgp-python/issues/182)) ([b3bf119](https://github.com/scaleapi/sgp-python/commit/b3bf11933b287dcded1b508d3eade3889aee2f2d))
* **api:** OpenAPI spec update via Stainless API ([#183](https://github.com/scaleapi/sgp-python/issues/183)) ([707d04d](https://github.com/scaleapi/sgp-python/commit/707d04d985894d54901c81693035b35332d9c1de))
* **api:** OpenAPI spec update via Stainless API ([#184](https://github.com/scaleapi/sgp-python/issues/184)) ([c606134](https://github.com/scaleapi/sgp-python/commit/c6061347b4f09c029d2acb9190ec3019156407a6))
* **api:** OpenAPI spec update via Stainless API ([#185](https://github.com/scaleapi/sgp-python/issues/185)) ([cf72938](https://github.com/scaleapi/sgp-python/commit/cf729383350fbd6bb165bf269379fbf8cd617398))
* **api:** OpenAPI spec update via Stainless API ([#186](https://github.com/scaleapi/sgp-python/issues/186)) ([e509281](https://github.com/scaleapi/sgp-python/commit/e50928193f7cf908a7c88096fbfca828438d8998))
* **api:** OpenAPI spec update via Stainless API ([#187](https://github.com/scaleapi/sgp-python/issues/187)) ([ebb80fc](https://github.com/scaleapi/sgp-python/commit/ebb80fcfae61e6095e28eb593abd1a149a4fadc1))
* **api:** OpenAPI spec update via Stainless API ([#188](https://github.com/scaleapi/sgp-python/issues/188)) ([3393384](https://github.com/scaleapi/sgp-python/commit/339338478fd2bd888439062535d6845c5951ef42))
* **api:** OpenAPI spec update via Stainless API ([#189](https://github.com/scaleapi/sgp-python/issues/189)) ([a6b7f00](https://github.com/scaleapi/sgp-python/commit/a6b7f00b2aa9cb2115837d368b16651262d74b23))
* **api:** OpenAPI spec update via Stainless API ([#190](https://github.com/scaleapi/sgp-python/issues/190)) ([4a3f6bc](https://github.com/scaleapi/sgp-python/commit/4a3f6bc8f48f920a23cbd66dba0ebb0267e91672))
* **api:** OpenAPI spec update via Stainless API ([#191](https://github.com/scaleapi/sgp-python/issues/191)) ([1c3c3d6](https://github.com/scaleapi/sgp-python/commit/1c3c3d67a618db1264c1435401c6a388abbd9847))
* **api:** OpenAPI spec update via Stainless API ([#192](https://github.com/scaleapi/sgp-python/issues/192)) ([f72ace9](https://github.com/scaleapi/sgp-python/commit/f72ace9db5edad507c3943fafbbbc1067dd7ddd4))
* **api:** OpenAPI spec update via Stainless API ([#193](https://github.com/scaleapi/sgp-python/issues/193)) ([e9ce0b3](https://github.com/scaleapi/sgp-python/commit/e9ce0b3791db2947db0549c4d8384cffd110fb1d))
* **api:** OpenAPI spec update via Stainless API ([#194](https://github.com/scaleapi/sgp-python/issues/194)) ([1c9918d](https://github.com/scaleapi/sgp-python/commit/1c9918dfdfc518a7ad6cee0be276462103b2f126))
* **api:** OpenAPI spec update via Stainless API ([#195](https://github.com/scaleapi/sgp-python/issues/195)) ([2d1c6ec](https://github.com/scaleapi/sgp-python/commit/2d1c6ec0b1095bad82c5de141e6ab985678127c5))
* **api:** OpenAPI spec update via Stainless API ([#196](https://github.com/scaleapi/sgp-python/issues/196)) ([350d109](https://github.com/scaleapi/sgp-python/commit/350d109e17e35fc0c470a76da597c19d20d89801))
* **api:** OpenAPI spec update via Stainless API ([#197](https://github.com/scaleapi/sgp-python/issues/197)) ([5218222](https://github.com/scaleapi/sgp-python/commit/52182221f691b55a35e0c4ec85f3238eb79b244f))
* **api:** OpenAPI spec update via Stainless API ([#198](https://github.com/scaleapi/sgp-python/issues/198)) ([1bae1e9](https://github.com/scaleapi/sgp-python/commit/1bae1e9044e2fc12a9fc4a23d315ea962c58bb72))
* **api:** OpenAPI spec update via Stainless API ([#199](https://github.com/scaleapi/sgp-python/issues/199)) ([f4413b2](https://github.com/scaleapi/sgp-python/commit/f4413b22aa2c00539b037628ac866b51db24bac8))
* **api:** OpenAPI spec update via Stainless API ([#200](https://github.com/scaleapi/sgp-python/issues/200)) ([be8df49](https://github.com/scaleapi/sgp-python/commit/be8df49292f57e229f3d7a31dda497825db6765f))
* **api:** OpenAPI spec update via Stainless API ([#201](https://github.com/scaleapi/sgp-python/issues/201)) ([9c37213](https://github.com/scaleapi/sgp-python/commit/9c372133b5103677abc4d68daeba1576c19dfd7a))
* **api:** OpenAPI spec update via Stainless API ([#202](https://github.com/scaleapi/sgp-python/issues/202)) ([c708588](https://github.com/scaleapi/sgp-python/commit/c708588d65d72f784bafa3c649efdcd1cd5ac01c))
* **api:** OpenAPI spec update via Stainless API ([#203](https://github.com/scaleapi/sgp-python/issues/203)) ([fb1695c](https://github.com/scaleapi/sgp-python/commit/fb1695c44e84819a4578e7b869f4fd50cc93fe77))
* **api:** OpenAPI spec update via Stainless API ([#204](https://github.com/scaleapi/sgp-python/issues/204)) ([cd4dab3](https://github.com/scaleapi/sgp-python/commit/cd4dab3cdf9cb6f49c3dee8ea4e33d4d0659de9c))
* **api:** OpenAPI spec update via Stainless API ([#205](https://github.com/scaleapi/sgp-python/issues/205)) ([0604f1a](https://github.com/scaleapi/sgp-python/commit/0604f1a73c58e21cc20a57c5c9f056a8e036d098))
* **api:** OpenAPI spec update via Stainless API ([#206](https://github.com/scaleapi/sgp-python/issues/206)) ([f076dec](https://github.com/scaleapi/sgp-python/commit/f076decfcb1d5c602615871d323cf8707db3990d))
* **api:** OpenAPI spec update via Stainless API ([#207](https://github.com/scaleapi/sgp-python/issues/207)) ([5a7deb5](https://github.com/scaleapi/sgp-python/commit/5a7deb5000c70fcd1908f72c443a21174ac9cc41))
* **api:** OpenAPI spec update via Stainless API ([#208](https://github.com/scaleapi/sgp-python/issues/208)) ([4c4b7fc](https://github.com/scaleapi/sgp-python/commit/4c4b7fc4cb7b1a5d0f700cad99cb076f274b1f09))
* **api:** OpenAPI spec update via Stainless API ([#209](https://github.com/scaleapi/sgp-python/issues/209)) ([30b83ea](https://github.com/scaleapi/sgp-python/commit/30b83ea0c650b89c69c0540bc6c89c9497ef31d7))
* **api:** OpenAPI spec update via Stainless API ([#210](https://github.com/scaleapi/sgp-python/issues/210)) ([8664d73](https://github.com/scaleapi/sgp-python/commit/8664d73e2ed215407f31ebeb448a9f961191c161))
* **api:** OpenAPI spec update via Stainless API ([#211](https://github.com/scaleapi/sgp-python/issues/211)) ([7dce090](https://github.com/scaleapi/sgp-python/commit/7dce090e4caa3323724530505af025e8ccd09a9c))
* **api:** OpenAPI spec update via Stainless API ([#212](https://github.com/scaleapi/sgp-python/issues/212)) ([4cd2e2b](https://github.com/scaleapi/sgp-python/commit/4cd2e2b7ca0b71d5ff7cfbbf3a7df225fc8af17d))
* **api:** OpenAPI spec update via Stainless API ([#213](https://github.com/scaleapi/sgp-python/issues/213)) ([a02bd93](https://github.com/scaleapi/sgp-python/commit/a02bd93104bc7def19919e0ce3f685ed5ed13ae3))
* **api:** OpenAPI spec update via Stainless API ([#214](https://github.com/scaleapi/sgp-python/issues/214)) ([ecb6ee8](https://github.com/scaleapi/sgp-python/commit/ecb6ee84926c192235cedcae4e2f092834d627ab))
* **api:** OpenAPI spec update via Stainless API ([#215](https://github.com/scaleapi/sgp-python/issues/215)) ([ee21ec6](https://github.com/scaleapi/sgp-python/commit/ee21ec678e61fbf1ecfd87172503762afa31bdf2))
* **api:** OpenAPI spec update via Stainless API ([#216](https://github.com/scaleapi/sgp-python/issues/216)) ([724b170](https://github.com/scaleapi/sgp-python/commit/724b170d2bc6e0bf2dffee0ae42e651f153aab57))
* **api:** OpenAPI spec update via Stainless API ([#217](https://github.com/scaleapi/sgp-python/issues/217)) ([2430683](https://github.com/scaleapi/sgp-python/commit/2430683246a3375f97cb9f6b55da19bb82a65fc4))
* **api:** OpenAPI spec update via Stainless API ([#218](https://github.com/scaleapi/sgp-python/issues/218)) ([8a8538c](https://github.com/scaleapi/sgp-python/commit/8a8538cdf09f85fd6910472585b1ac3d3de6d594))
* **api:** OpenAPI spec update via Stainless API ([#219](https://github.com/scaleapi/sgp-python/issues/219)) ([c6abb87](https://github.com/scaleapi/sgp-python/commit/c6abb87b0df80cd3a57a91d7f428a710d7504661))
* **api:** OpenAPI spec update via Stainless API ([#220](https://github.com/scaleapi/sgp-python/issues/220)) ([bc43d76](https://github.com/scaleapi/sgp-python/commit/bc43d76f5d235bdf2294709aeba48a6a0e005e5b))
* **api:** OpenAPI spec update via Stainless API ([#221](https://github.com/scaleapi/sgp-python/issues/221)) ([562a4e4](https://github.com/scaleapi/sgp-python/commit/562a4e4f2aa4ba0febc0df7b877c74b912683892))
* **api:** OpenAPI spec update via Stainless API ([#222](https://github.com/scaleapi/sgp-python/issues/222)) ([5bcf4d2](https://github.com/scaleapi/sgp-python/commit/5bcf4d2a0f5bc0408f33e0380739a8685cd9d239))
* **api:** OpenAPI spec update via Stainless API ([#223](https://github.com/scaleapi/sgp-python/issues/223)) ([4b3f8a3](https://github.com/scaleapi/sgp-python/commit/4b3f8a374c5fbff6c98ca54e21181c07026cd347))
* **api:** OpenAPI spec update via Stainless API ([#224](https://github.com/scaleapi/sgp-python/issues/224)) ([a68415f](https://github.com/scaleapi/sgp-python/commit/a68415f500481a060699d09807b933299b37ddab))
* **api:** OpenAPI spec update via Stainless API ([#225](https://github.com/scaleapi/sgp-python/issues/225)) ([345fe7a](https://github.com/scaleapi/sgp-python/commit/345fe7a9dce2516b05ed7714e68d6aa6cd31c5b9))
* **api:** OpenAPI spec update via Stainless API ([#226](https://github.com/scaleapi/sgp-python/issues/226)) ([7ad9b8a](https://github.com/scaleapi/sgp-python/commit/7ad9b8a31d3bbf42b690139d1515a840d993b264))
* **api:** OpenAPI spec update via Stainless API ([#227](https://github.com/scaleapi/sgp-python/issues/227)) ([1e4b1b2](https://github.com/scaleapi/sgp-python/commit/1e4b1b21ce73ad58fb292fe22389a247cdee23e1))
* **api:** OpenAPI spec update via Stainless API ([#228](https://github.com/scaleapi/sgp-python/issues/228)) ([0e78120](https://github.com/scaleapi/sgp-python/commit/0e781205d1fbf557ffdaf51dde15c7f526147aa1))
* **api:** OpenAPI spec update via Stainless API ([#229](https://github.com/scaleapi/sgp-python/issues/229)) ([ff1bcd5](https://github.com/scaleapi/sgp-python/commit/ff1bcd563369eede7644fe890eb75744b1f969fe))
* **api:** OpenAPI spec update via Stainless API ([#230](https://github.com/scaleapi/sgp-python/issues/230)) ([3f407f0](https://github.com/scaleapi/sgp-python/commit/3f407f0c01cca022eff95ca9ccca30f6d717727a))
* **api:** OpenAPI spec update via Stainless API ([#231](https://github.com/scaleapi/sgp-python/issues/231)) ([a21b1db](https://github.com/scaleapi/sgp-python/commit/a21b1db2a262f49005dc1b81594de360451c564e))
* **api:** OpenAPI spec update via Stainless API ([#232](https://github.com/scaleapi/sgp-python/issues/232)) ([0b3916f](https://github.com/scaleapi/sgp-python/commit/0b3916f2e43d5669e24f2c797ad99b33916c81cc))
* **api:** OpenAPI spec update via Stainless API ([#233](https://github.com/scaleapi/sgp-python/issues/233)) ([4612254](https://github.com/scaleapi/sgp-python/commit/4612254f1a1105c7f92e7b77728def9351a8243f))
* **api:** OpenAPI spec update via Stainless API ([#234](https://github.com/scaleapi/sgp-python/issues/234)) ([b8ca935](https://github.com/scaleapi/sgp-python/commit/b8ca93572cdd5964398bada0c2880c1b55d55296))
* **api:** OpenAPI spec update via Stainless API ([#235](https://github.com/scaleapi/sgp-python/issues/235)) ([be03594](https://github.com/scaleapi/sgp-python/commit/be0359472ea2f91bf195500e1d79de66c79da87e))
* **api:** OpenAPI spec update via Stainless API ([#236](https://github.com/scaleapi/sgp-python/issues/236)) ([9e1d52e](https://github.com/scaleapi/sgp-python/commit/9e1d52e7e3fbe5cbccb9067b4119d588cbabd666))
* **api:** OpenAPI spec update via Stainless API ([#237](https://github.com/scaleapi/sgp-python/issues/237)) ([e805cfc](https://github.com/scaleapi/sgp-python/commit/e805cfcebed9da08276119d01e7ab9e78bf77c57))
* **api:** OpenAPI spec update via Stainless API ([#238](https://github.com/scaleapi/sgp-python/issues/238)) ([44adce8](https://github.com/scaleapi/sgp-python/commit/44adce83b778268370554c0107fbdf4434e61c51))
* **api:** OpenAPI spec update via Stainless API ([#239](https://github.com/scaleapi/sgp-python/issues/239)) ([1a84863](https://github.com/scaleapi/sgp-python/commit/1a8486371b0dac11bd9a9649c2b6f0a5f6a30f27))
* **api:** OpenAPI spec update via Stainless API ([#240](https://github.com/scaleapi/sgp-python/issues/240)) ([171b094](https://github.com/scaleapi/sgp-python/commit/171b094596f4aae2ac321a48b3c92abd7517792f))
* **api:** OpenAPI spec update via Stainless API ([#241](https://github.com/scaleapi/sgp-python/issues/241)) ([c70b68d](https://github.com/scaleapi/sgp-python/commit/c70b68db43f541b38f57bf36c64874858ec93535))
* **api:** OpenAPI spec update via Stainless API ([#242](https://github.com/scaleapi/sgp-python/issues/242)) ([a9049e0](https://github.com/scaleapi/sgp-python/commit/a9049e0353d01ca04e4b51717a42cb44b2fea86e))
* **api:** OpenAPI spec update via Stainless API ([#243](https://github.com/scaleapi/sgp-python/issues/243)) ([39145b2](https://github.com/scaleapi/sgp-python/commit/39145b2b6e1c28f8ed3fc55024e52e79f470c483))
* **api:** OpenAPI spec update via Stainless API ([#244](https://github.com/scaleapi/sgp-python/issues/244)) ([9da5aab](https://github.com/scaleapi/sgp-python/commit/9da5aab53dd67ef0161cf2d35761d97a3453cf29))
* **api:** OpenAPI spec update via Stainless API ([#245](https://github.com/scaleapi/sgp-python/issues/245)) ([3246889](https://github.com/scaleapi/sgp-python/commit/324688915634c93fa9b28b6ff7465156b2c933e1))
* **api:** OpenAPI spec update via Stainless API ([#246](https://github.com/scaleapi/sgp-python/issues/246)) ([9ea8605](https://github.com/scaleapi/sgp-python/commit/9ea8605d88448574bc732b108cc0afb875475d48))
* **api:** OpenAPI spec update via Stainless API ([#247](https://github.com/scaleapi/sgp-python/issues/247)) ([4bfa98b](https://github.com/scaleapi/sgp-python/commit/4bfa98b8ee35d41a16f8e2ee98878ced9ade559f))
* **api:** OpenAPI spec update via Stainless API ([#248](https://github.com/scaleapi/sgp-python/issues/248)) ([957648b](https://github.com/scaleapi/sgp-python/commit/957648b72bbf9cc6578c096ad158b0d33f4c2524))
* **api:** OpenAPI spec update via Stainless API ([#249](https://github.com/scaleapi/sgp-python/issues/249)) ([5f092c5](https://github.com/scaleapi/sgp-python/commit/5f092c570fe52d098256880bd93a579aabcc5241))
* **api:** OpenAPI spec update via Stainless API ([#250](https://github.com/scaleapi/sgp-python/issues/250)) ([303ba74](https://github.com/scaleapi/sgp-python/commit/303ba746a9deb1412edeedfe98859ad6f8b4d650))
* **api:** OpenAPI spec update via Stainless API ([#251](https://github.com/scaleapi/sgp-python/issues/251)) ([670f093](https://github.com/scaleapi/sgp-python/commit/670f0939adbf1d36913187edc514c9abd7685855))
* **api:** OpenAPI spec update via Stainless API ([#252](https://github.com/scaleapi/sgp-python/issues/252)) ([a3dccd8](https://github.com/scaleapi/sgp-python/commit/a3dccd847d5d2773c1864fa4d5568ed3b4cbff25))
* **api:** OpenAPI spec update via Stainless API ([#253](https://github.com/scaleapi/sgp-python/issues/253)) ([49c91f6](https://github.com/scaleapi/sgp-python/commit/49c91f61e3816dd8ce901dbd65db3b46d552ed8c))
* **api:** OpenAPI spec update via Stainless API ([#254](https://github.com/scaleapi/sgp-python/issues/254)) ([a5e4b7b](https://github.com/scaleapi/sgp-python/commit/a5e4b7bd4597d4ba1e33b806d29df03c0f1d8839))
* **api:** OpenAPI spec update via Stainless API ([#255](https://github.com/scaleapi/sgp-python/issues/255)) ([b96c9d6](https://github.com/scaleapi/sgp-python/commit/b96c9d69b596375449dae3522d4d5e5c0758eb69))
* **api:** OpenAPI spec update via Stainless API ([#256](https://github.com/scaleapi/sgp-python/issues/256)) ([b020b87](https://github.com/scaleapi/sgp-python/commit/b020b8737a09658ef9f1715b38427250723348ad))
* **api:** OpenAPI spec update via Stainless API ([#257](https://github.com/scaleapi/sgp-python/issues/257)) ([1d3454c](https://github.com/scaleapi/sgp-python/commit/1d3454c4fb59175db01439704471dd2a4b0804f1))
* **api:** OpenAPI spec update via Stainless API ([#258](https://github.com/scaleapi/sgp-python/issues/258)) ([633be8f](https://github.com/scaleapi/sgp-python/commit/633be8f397593ed590cbddf10d997c5718b9eb98))
* **api:** OpenAPI spec update via Stainless API ([#259](https://github.com/scaleapi/sgp-python/issues/259)) ([a97bf9f](https://github.com/scaleapi/sgp-python/commit/a97bf9f147014ef2d299c05117836717ec9c405f))
* **api:** OpenAPI spec update via Stainless API ([#260](https://github.com/scaleapi/sgp-python/issues/260)) ([961a9f4](https://github.com/scaleapi/sgp-python/commit/961a9f40adbb2feb25998e6cf28720191b4969bc))
* **api:** OpenAPI spec update via Stainless API ([#261](https://github.com/scaleapi/sgp-python/issues/261)) ([71ba3ea](https://github.com/scaleapi/sgp-python/commit/71ba3ea1127b3b8c1a0387569957383b21999f89))
* **api:** OpenAPI spec update via Stainless API ([#262](https://github.com/scaleapi/sgp-python/issues/262)) ([013c16b](https://github.com/scaleapi/sgp-python/commit/013c16b306749d1b18ff888af7405341c8abfe88))
* **api:** OpenAPI spec update via Stainless API ([#263](https://github.com/scaleapi/sgp-python/issues/263)) ([3532096](https://github.com/scaleapi/sgp-python/commit/3532096bbcec8efb77a7399dc97eff62b6956c99))
* **api:** OpenAPI spec update via Stainless API ([#264](https://github.com/scaleapi/sgp-python/issues/264)) ([711dee5](https://github.com/scaleapi/sgp-python/commit/711dee5c939b574e5f3e9237bf178eb939c3ca7e))
* **api:** OpenAPI spec update via Stainless API ([#265](https://github.com/scaleapi/sgp-python/issues/265)) ([2db458e](https://github.com/scaleapi/sgp-python/commit/2db458ee64f1c2401cf304835b080a6273512bad))
* **api:** OpenAPI spec update via Stainless API ([#266](https://github.com/scaleapi/sgp-python/issues/266)) ([5abe0be](https://github.com/scaleapi/sgp-python/commit/5abe0bea39fe07742377d9c3fe16f263821db840))
* **api:** OpenAPI spec update via Stainless API ([#267](https://github.com/scaleapi/sgp-python/issues/267)) ([b66b9c2](https://github.com/scaleapi/sgp-python/commit/b66b9c24cb0b8f04dc55c7e01394cf49e8585b73))
* **api:** OpenAPI spec update via Stainless API ([#268](https://github.com/scaleapi/sgp-python/issues/268)) ([9e0c6d0](https://github.com/scaleapi/sgp-python/commit/9e0c6d031b31923e9494d547a8f88ad6544827cd))
* **api:** OpenAPI spec update via Stainless API ([#269](https://github.com/scaleapi/sgp-python/issues/269)) ([51eab77](https://github.com/scaleapi/sgp-python/commit/51eab77a0a07163efca58d8131f2722a903924c1))
* **api:** OpenAPI spec update via Stainless API ([#270](https://github.com/scaleapi/sgp-python/issues/270)) ([6e1eb03](https://github.com/scaleapi/sgp-python/commit/6e1eb031a3ca0bf8b9731909edbb4753e6af36f8))
* **api:** OpenAPI spec update via Stainless API ([#271](https://github.com/scaleapi/sgp-python/issues/271)) ([4f9d632](https://github.com/scaleapi/sgp-python/commit/4f9d632b70e0e8d3b27f4b9923b4c79139e0bff3))
* **api:** OpenAPI spec update via Stainless API ([#272](https://github.com/scaleapi/sgp-python/issues/272)) ([7998bb3](https://github.com/scaleapi/sgp-python/commit/7998bb3da8d24ab9891a6f8090113e70ece3de73))
* **api:** OpenAPI spec update via Stainless API ([#273](https://github.com/scaleapi/sgp-python/issues/273)) ([4e701a4](https://github.com/scaleapi/sgp-python/commit/4e701a489fc3626f3a4341b2e3c2cbec677e7530))
* **api:** OpenAPI spec update via Stainless API ([#274](https://github.com/scaleapi/sgp-python/issues/274)) ([f0fad82](https://github.com/scaleapi/sgp-python/commit/f0fad82edb7f0aefebd9c8e23f7d0abc845cf00c))
* **api:** OpenAPI spec update via Stainless API ([#275](https://github.com/scaleapi/sgp-python/issues/275)) ([5032720](https://github.com/scaleapi/sgp-python/commit/503272011ce50384577efc18e7bbc236feaf1317))
* **api:** OpenAPI spec update via Stainless API ([#276](https://github.com/scaleapi/sgp-python/issues/276)) ([499b07b](https://github.com/scaleapi/sgp-python/commit/499b07b53c80789c30cc8f1c1293fdbac09b7de1))
* **api:** OpenAPI spec update via Stainless API ([#277](https://github.com/scaleapi/sgp-python/issues/277)) ([2db68f3](https://github.com/scaleapi/sgp-python/commit/2db68f318e6aee9d8f4370688a6b535d4708c66c))
* **api:** OpenAPI spec update via Stainless API ([#278](https://github.com/scaleapi/sgp-python/issues/278)) ([220c183](https://github.com/scaleapi/sgp-python/commit/220c18354ba0eff852413701afb35342a90e2a43))
* **api:** OpenAPI spec update via Stainless API ([#279](https://github.com/scaleapi/sgp-python/issues/279)) ([a8e6ab3](https://github.com/scaleapi/sgp-python/commit/a8e6ab35dd4a77e29d466d5133b8edcdc071748c))
* **api:** OpenAPI spec update via Stainless API ([#280](https://github.com/scaleapi/sgp-python/issues/280)) ([7d8b713](https://github.com/scaleapi/sgp-python/commit/7d8b71343e4ca49397984b6b43cde486c1f2b297))
* **api:** OpenAPI spec update via Stainless API ([#281](https://github.com/scaleapi/sgp-python/issues/281)) ([4a99e3d](https://github.com/scaleapi/sgp-python/commit/4a99e3d87844793a7aca14da460abda299d7abc6))
* **api:** OpenAPI spec update via Stainless API ([#282](https://github.com/scaleapi/sgp-python/issues/282)) ([0d41e9d](https://github.com/scaleapi/sgp-python/commit/0d41e9d4999cfffccd1c6ad7549b28790710b56e))
* **api:** OpenAPI spec update via Stainless API ([#283](https://github.com/scaleapi/sgp-python/issues/283)) ([959f087](https://github.com/scaleapi/sgp-python/commit/959f0872728934d34efd9a86d587a0f79ccd0526))
* **api:** OpenAPI spec update via Stainless API ([#284](https://github.com/scaleapi/sgp-python/issues/284)) ([3980a1f](https://github.com/scaleapi/sgp-python/commit/3980a1f2406be9d3cdb076e2099c765cdc54ce22))
* **api:** OpenAPI spec update via Stainless API ([#285](https://github.com/scaleapi/sgp-python/issues/285)) ([aa091b9](https://github.com/scaleapi/sgp-python/commit/aa091b99ee919a13266be22e6487b18f9b3e8aeb))
* **api:** OpenAPI spec update via Stainless API ([#286](https://github.com/scaleapi/sgp-python/issues/286)) ([2c10d8e](https://github.com/scaleapi/sgp-python/commit/2c10d8ecb5ec2fd43de5438e38536682ab341d1a))
* **api:** OpenAPI spec update via Stainless API ([#287](https://github.com/scaleapi/sgp-python/issues/287)) ([069f631](https://github.com/scaleapi/sgp-python/commit/069f63105d4826854e3ecf72c2514350b5548ecc))
* **api:** OpenAPI spec update via Stainless API ([#288](https://github.com/scaleapi/sgp-python/issues/288)) ([ad4856b](https://github.com/scaleapi/sgp-python/commit/ad4856b2b7023e00f313cbd9f7ae528d45c7b014))
* **api:** OpenAPI spec update via Stainless API ([#289](https://github.com/scaleapi/sgp-python/issues/289)) ([64a7b88](https://github.com/scaleapi/sgp-python/commit/64a7b888b150b6ed94b1fd43a480677f20975d12))
* **api:** OpenAPI spec update via Stainless API ([#290](https://github.com/scaleapi/sgp-python/issues/290)) ([9f406e7](https://github.com/scaleapi/sgp-python/commit/9f406e74d520aa87190d6532cf3dbacbc8619423))
* **api:** OpenAPI spec update via Stainless API ([#291](https://github.com/scaleapi/sgp-python/issues/291)) ([be20126](https://github.com/scaleapi/sgp-python/commit/be2012616d2cc629faa75bb784e0aff46a30416f))
* **api:** OpenAPI spec update via Stainless API ([#292](https://github.com/scaleapi/sgp-python/issues/292)) ([37ac1ce](https://github.com/scaleapi/sgp-python/commit/37ac1ce1200c67be247d34f008621516e1020f9a))
* **api:** OpenAPI spec update via Stainless API ([#293](https://github.com/scaleapi/sgp-python/issues/293)) ([88b562f](https://github.com/scaleapi/sgp-python/commit/88b562f7b10a678882ab11fee4d3bd067775d86e))
* **api:** OpenAPI spec update via Stainless API ([#294](https://github.com/scaleapi/sgp-python/issues/294)) ([de2db37](https://github.com/scaleapi/sgp-python/commit/de2db37d36de2de57ceeb92be0d6bf16cd0e3f7e))
* **api:** OpenAPI spec update via Stainless API ([#295](https://github.com/scaleapi/sgp-python/issues/295)) ([d7f264a](https://github.com/scaleapi/sgp-python/commit/d7f264a717e7d0e6b5de788e63241b1bb20957fe))
* **api:** OpenAPI spec update via Stainless API ([#296](https://github.com/scaleapi/sgp-python/issues/296)) ([60e43fc](https://github.com/scaleapi/sgp-python/commit/60e43fce6caf421c7a4a1d6b1b53a18990845a73))
* **api:** OpenAPI spec update via Stainless API ([#297](https://github.com/scaleapi/sgp-python/issues/297)) ([c05fe1c](https://github.com/scaleapi/sgp-python/commit/c05fe1c5f8c6c4a6bf0973d0bcfd4cd70d8362c6))
* **api:** OpenAPI spec update via Stainless API ([#298](https://github.com/scaleapi/sgp-python/issues/298)) ([6c97d8a](https://github.com/scaleapi/sgp-python/commit/6c97d8a5c4c4ec6e5c986550bcc25b8fb4fd1611))
* **api:** OpenAPI spec update via Stainless API ([#299](https://github.com/scaleapi/sgp-python/issues/299)) ([56df17f](https://github.com/scaleapi/sgp-python/commit/56df17f8569ba5446456ed491b78ab4fde8879e3))
* **api:** OpenAPI spec update via Stainless API ([#300](https://github.com/scaleapi/sgp-python/issues/300)) ([2573750](https://github.com/scaleapi/sgp-python/commit/2573750b7597e75e1c75d06835da8ecc0982bfb1))
* **api:** OpenAPI spec update via Stainless API ([#301](https://github.com/scaleapi/sgp-python/issues/301)) ([22ec0a8](https://github.com/scaleapi/sgp-python/commit/22ec0a8aa04d974625dd07be5d0a66b79180a65b))
* **api:** OpenAPI spec update via Stainless API ([#302](https://github.com/scaleapi/sgp-python/issues/302)) ([e34ba11](https://github.com/scaleapi/sgp-python/commit/e34ba1150afb73056a6b4ceae9e55b581780c978))
* **api:** OpenAPI spec update via Stainless API ([#303](https://github.com/scaleapi/sgp-python/issues/303)) ([2487687](https://github.com/scaleapi/sgp-python/commit/24876877c3b5faca59e3ebb26e6366b16552bd63))
* **api:** OpenAPI spec update via Stainless API ([#304](https://github.com/scaleapi/sgp-python/issues/304)) ([58e068d](https://github.com/scaleapi/sgp-python/commit/58e068d73fe02267d6f80b327afbb79b26ce549b))
* **api:** OpenAPI spec update via Stainless API ([#305](https://github.com/scaleapi/sgp-python/issues/305)) ([b160095](https://github.com/scaleapi/sgp-python/commit/b160095558346ee76d9a3af32cab842b8d0eb592))
* **api:** OpenAPI spec update via Stainless API ([#306](https://github.com/scaleapi/sgp-python/issues/306)) ([f4664b3](https://github.com/scaleapi/sgp-python/commit/f4664b3e6f7cf6ad0aaf938802ee0a523fbc3fa5))
* **api:** OpenAPI spec update via Stainless API ([#307](https://github.com/scaleapi/sgp-python/issues/307)) ([f9a218e](https://github.com/scaleapi/sgp-python/commit/f9a218e302e75978a87d776f53710a57713ba4f7))
* **api:** OpenAPI spec update via Stainless API ([#308](https://github.com/scaleapi/sgp-python/issues/308)) ([1f4cfc2](https://github.com/scaleapi/sgp-python/commit/1f4cfc2536d0bc77fc2c5aaefb11497d9a8a9ae1))
* **api:** OpenAPI spec update via Stainless API ([#309](https://github.com/scaleapi/sgp-python/issues/309)) ([2c9a5dd](https://github.com/scaleapi/sgp-python/commit/2c9a5ddc5b81c4f18dceecccc7142cc8adde8f40))
* **api:** OpenAPI spec update via Stainless API ([#310](https://github.com/scaleapi/sgp-python/issues/310)) ([cce9c18](https://github.com/scaleapi/sgp-python/commit/cce9c183278dd85ba8b3bb0b77588d3c00be9181))
* **api:** OpenAPI spec update via Stainless API ([#311](https://github.com/scaleapi/sgp-python/issues/311)) ([486c66b](https://github.com/scaleapi/sgp-python/commit/486c66b589c9da975023e9aa90976eb202a3c8cb))
* **api:** OpenAPI spec update via Stainless API ([#312](https://github.com/scaleapi/sgp-python/issues/312)) ([cd2264f](https://github.com/scaleapi/sgp-python/commit/cd2264fc520e704714870fb6af860ad0b65d98ba))
* **api:** OpenAPI spec update via Stainless API ([#313](https://github.com/scaleapi/sgp-python/issues/313)) ([6a27535](https://github.com/scaleapi/sgp-python/commit/6a27535356a6024f1af4de8bf084db5efef89f37))
* **api:** OpenAPI spec update via Stainless API ([#314](https://github.com/scaleapi/sgp-python/issues/314)) ([7d32064](https://github.com/scaleapi/sgp-python/commit/7d3206440aa60f962adaca72f3ad61638b255412))
* **api:** OpenAPI spec update via Stainless API ([#315](https://github.com/scaleapi/sgp-python/issues/315)) ([f463f86](https://github.com/scaleapi/sgp-python/commit/f463f8654ec3fd0823938872ee23b094958cbf57))
* **api:** OpenAPI spec update via Stainless API ([#316](https://github.com/scaleapi/sgp-python/issues/316)) ([11f1201](https://github.com/scaleapi/sgp-python/commit/11f12014bfcf79045813d4475d935015fa59793a))
* **api:** OpenAPI spec update via Stainless API ([#317](https://github.com/scaleapi/sgp-python/issues/317)) ([8d1e707](https://github.com/scaleapi/sgp-python/commit/8d1e707b693d36e52c0be309a60482fb45d371f3))
* **api:** OpenAPI spec update via Stainless API ([#318](https://github.com/scaleapi/sgp-python/issues/318)) ([2c458fb](https://github.com/scaleapi/sgp-python/commit/2c458fbe246831e0c9ec647b7af11af2c0c4c585))
* **api:** OpenAPI spec update via Stainless API ([#319](https://github.com/scaleapi/sgp-python/issues/319)) ([0fffb1f](https://github.com/scaleapi/sgp-python/commit/0fffb1f8becb843aa9f4d4613f1b80358998062d))
* **api:** OpenAPI spec update via Stainless API ([#320](https://github.com/scaleapi/sgp-python/issues/320)) ([ca44f86](https://github.com/scaleapi/sgp-python/commit/ca44f8651348b70e3ba3acab4f0e19aeef915bf8))
* **api:** OpenAPI spec update via Stainless API ([#321](https://github.com/scaleapi/sgp-python/issues/321)) ([f0cf3ba](https://github.com/scaleapi/sgp-python/commit/f0cf3ba76e398f5c84bcd1e27ec2a57a1fcbdfe0))
* **api:** OpenAPI spec update via Stainless API ([#322](https://github.com/scaleapi/sgp-python/issues/322)) ([28c1c50](https://github.com/scaleapi/sgp-python/commit/28c1c500abb380f44a70ac9540395c6cb580384d))
* **api:** OpenAPI spec update via Stainless API ([#323](https://github.com/scaleapi/sgp-python/issues/323)) ([c25cee5](https://github.com/scaleapi/sgp-python/commit/c25cee53dfe244b520390b58a8d08b717c7db9d9))
* **api:** OpenAPI spec update via Stainless API ([#324](https://github.com/scaleapi/sgp-python/issues/324)) ([bdf1b0c](https://github.com/scaleapi/sgp-python/commit/bdf1b0c9350b0b16dca732a3d7804de01dd867d6))
* **api:** OpenAPI spec update via Stainless API ([#325](https://github.com/scaleapi/sgp-python/issues/325)) ([b57d12a](https://github.com/scaleapi/sgp-python/commit/b57d12a92f6c32b737f2a5acdde014f8543b2e79))
* **api:** OpenAPI spec update via Stainless API ([#326](https://github.com/scaleapi/sgp-python/issues/326)) ([722eb67](https://github.com/scaleapi/sgp-python/commit/722eb6764cf16d87ff4561079884557e154bebf4))
* **api:** OpenAPI spec update via Stainless API ([#327](https://github.com/scaleapi/sgp-python/issues/327)) ([0f59d88](https://github.com/scaleapi/sgp-python/commit/0f59d88a7187944c9e3bbb11abf51fab7e787454))
* **api:** OpenAPI spec update via Stainless API ([#328](https://github.com/scaleapi/sgp-python/issues/328)) ([c9065e3](https://github.com/scaleapi/sgp-python/commit/c9065e36371b9e8894b1da3f16c1e73a83b31af4))
* **api:** OpenAPI spec update via Stainless API ([#329](https://github.com/scaleapi/sgp-python/issues/329)) ([359916d](https://github.com/scaleapi/sgp-python/commit/359916dbc03fed36a10171e44dc3d24b5ed526c7))
* **api:** OpenAPI spec update via Stainless API ([#330](https://github.com/scaleapi/sgp-python/issues/330)) ([51925f1](https://github.com/scaleapi/sgp-python/commit/51925f1c65033ca11b3177b902a1e8008bbde5ef))
* **api:** OpenAPI spec update via Stainless API ([#331](https://github.com/scaleapi/sgp-python/issues/331)) ([3e83cbb](https://github.com/scaleapi/sgp-python/commit/3e83cbbfb253c6ed9b3afa8b19214e86216bfa4d))
* **api:** OpenAPI spec update via Stainless API ([#332](https://github.com/scaleapi/sgp-python/issues/332)) ([a7e66f2](https://github.com/scaleapi/sgp-python/commit/a7e66f2565037edb64c7cdc51676760ac53791b5))
* **api:** OpenAPI spec update via Stainless API ([#333](https://github.com/scaleapi/sgp-python/issues/333)) ([fa6b5e9](https://github.com/scaleapi/sgp-python/commit/fa6b5e978de883d58d4fb1c4a36a5a65ec554ddc))
* **api:** OpenAPI spec update via Stainless API ([#334](https://github.com/scaleapi/sgp-python/issues/334)) ([c48d8c7](https://github.com/scaleapi/sgp-python/commit/c48d8c7cffa732651ba54cc5966ee0ee1c9eb740))
* **api:** OpenAPI spec update via Stainless API ([#335](https://github.com/scaleapi/sgp-python/issues/335)) ([ac62cd0](https://github.com/scaleapi/sgp-python/commit/ac62cd0a9da0a86247b2a8dbf34024cd41db23e5))
* **api:** OpenAPI spec update via Stainless API ([#336](https://github.com/scaleapi/sgp-python/issues/336)) ([f87a9aa](https://github.com/scaleapi/sgp-python/commit/f87a9aa65740c0a80fa93b87c7ae978b32266527))
* **api:** OpenAPI spec update via Stainless API ([#337](https://github.com/scaleapi/sgp-python/issues/337)) ([befe06e](https://github.com/scaleapi/sgp-python/commit/befe06e3ed4c2879abb94af9c5ab78ddb6c3f684))
* **api:** OpenAPI spec update via Stainless API ([#338](https://github.com/scaleapi/sgp-python/issues/338)) ([232a6b7](https://github.com/scaleapi/sgp-python/commit/232a6b79369973eaff5349971aed4801aa0c04c4))
* **api:** OpenAPI spec update via Stainless API ([#339](https://github.com/scaleapi/sgp-python/issues/339)) ([7530a90](https://github.com/scaleapi/sgp-python/commit/7530a90797a7e2bb71aa4c99e5b634d924e489c7))
* **api:** OpenAPI spec update via Stainless API ([#340](https://github.com/scaleapi/sgp-python/issues/340)) ([9cd011e](https://github.com/scaleapi/sgp-python/commit/9cd011e6b3e6a22eed58b4a3b0c538cecf9c09ad))
* **api:** OpenAPI spec update via Stainless API ([#341](https://github.com/scaleapi/sgp-python/issues/341)) ([f1ed862](https://github.com/scaleapi/sgp-python/commit/f1ed862e35148740e774933a621a51417c868195))
* **api:** OpenAPI spec update via Stainless API ([#342](https://github.com/scaleapi/sgp-python/issues/342)) ([a3b430b](https://github.com/scaleapi/sgp-python/commit/a3b430b9b75b81834828503d181ee1e795852605))
* **api:** OpenAPI spec update via Stainless API ([#343](https://github.com/scaleapi/sgp-python/issues/343)) ([6b43ffe](https://github.com/scaleapi/sgp-python/commit/6b43ffe2ff337872ca41a7c0b0a9aeba8ec1e70f))
* **api:** OpenAPI spec update via Stainless API ([#344](https://github.com/scaleapi/sgp-python/issues/344)) ([b85d3f5](https://github.com/scaleapi/sgp-python/commit/b85d3f5f98e6166588b82e80e6d0a827d7a2a075))
* **api:** OpenAPI spec update via Stainless API ([#345](https://github.com/scaleapi/sgp-python/issues/345)) ([b72c0b9](https://github.com/scaleapi/sgp-python/commit/b72c0b9856744b51522264f43db8b545a86eb166))
* **api:** OpenAPI spec update via Stainless API ([#346](https://github.com/scaleapi/sgp-python/issues/346)) ([936fdc2](https://github.com/scaleapi/sgp-python/commit/936fdc2031c6a5dd68cd6eeb634474de9b9a2fa7))
* **api:** OpenAPI spec update via Stainless API ([#347](https://github.com/scaleapi/sgp-python/issues/347)) ([a6d44cb](https://github.com/scaleapi/sgp-python/commit/a6d44cbb5c75fc883a8d977d868615dae6ccc154))
* **api:** OpenAPI spec update via Stainless API ([#348](https://github.com/scaleapi/sgp-python/issues/348)) ([af1751f](https://github.com/scaleapi/sgp-python/commit/af1751f1b657aa2c4c5ac05a93218b8b8ff91b0e))
* **api:** OpenAPI spec update via Stainless API ([#349](https://github.com/scaleapi/sgp-python/issues/349)) ([e344c01](https://github.com/scaleapi/sgp-python/commit/e344c01e215fbb7b6fda82c36201241e91e89baf))
* **api:** OpenAPI spec update via Stainless API ([#350](https://github.com/scaleapi/sgp-python/issues/350)) ([36f98b3](https://github.com/scaleapi/sgp-python/commit/36f98b3769a460eee98e7bb1f5b934e624f97908))
* **api:** OpenAPI spec update via Stainless API ([#351](https://github.com/scaleapi/sgp-python/issues/351)) ([8ef100c](https://github.com/scaleapi/sgp-python/commit/8ef100c52acc7602742e23aff23b9547128007c3))
* **api:** OpenAPI spec update via Stainless API ([#352](https://github.com/scaleapi/sgp-python/issues/352)) ([762be28](https://github.com/scaleapi/sgp-python/commit/762be2838967bb5ef271df0838751f2cce99d14c))
* **api:** OpenAPI spec update via Stainless API ([#353](https://github.com/scaleapi/sgp-python/issues/353)) ([5460eac](https://github.com/scaleapi/sgp-python/commit/5460eacc4d6e369c3cd55cd1fbf98986ccc63e74))
* **api:** OpenAPI spec update via Stainless API ([#354](https://github.com/scaleapi/sgp-python/issues/354)) ([072db30](https://github.com/scaleapi/sgp-python/commit/072db30f8c913d812f19ece6033ef186e1251b74))
* **api:** OpenAPI spec update via Stainless API ([#355](https://github.com/scaleapi/sgp-python/issues/355)) ([43b301c](https://github.com/scaleapi/sgp-python/commit/43b301c63e80a883f632db8aff45d092e9868101))
* **api:** OpenAPI spec update via Stainless API ([#356](https://github.com/scaleapi/sgp-python/issues/356)) ([b980b90](https://github.com/scaleapi/sgp-python/commit/b980b904ca75f48a8f47de1471a4f02016844b2b))
* **api:** OpenAPI spec update via Stainless API ([#357](https://github.com/scaleapi/sgp-python/issues/357)) ([b5b24d2](https://github.com/scaleapi/sgp-python/commit/b5b24d279cd11b4851ce556bbb16eb1b3acd75b7))
* **api:** OpenAPI spec update via Stainless API ([#358](https://github.com/scaleapi/sgp-python/issues/358)) ([d6195c7](https://github.com/scaleapi/sgp-python/commit/d6195c7bf784edb3b9a32612af6e75012af8002b))

## 0.1.0-alpha.13 (2024-07-08)

Full Changelog: [v0.1.0-alpha.12...v0.1.0-alpha.13](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.12...v0.1.0-alpha.13)

### Features

* **api:** OpenAPI spec update via Stainless API ([#156](https://github.com/scaleapi/sgp-python/issues/156)) ([c75e538](https://github.com/scaleapi/sgp-python/commit/c75e538b7cbb3dfae903a073bc6c11d5c87c1805))
* **api:** update via SDK Studio ([#158](https://github.com/scaleapi/sgp-python/issues/158)) ([2761ea1](https://github.com/scaleapi/sgp-python/commit/2761ea19a3d5a38c4cdde91e00600c1cffac4319))

## 0.1.0-alpha.12 (2024-07-08)

Full Changelog: [v0.1.0-alpha.11...v0.1.0-alpha.12](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.11...v0.1.0-alpha.12)

### Features

* **api:** update via SDK Studio ([#154](https://github.com/scaleapi/sgp-python/issues/154)) ([2b59025](https://github.com/scaleapi/sgp-python/commit/2b59025c340632a1bc896f3245b7cf5a6b37bdaf))
* **api:** update via SDK Studio ([#155](https://github.com/scaleapi/sgp-python/issues/155)) ([5578b0a](https://github.com/scaleapi/sgp-python/commit/5578b0a3b9964553fe32dc530b9cf13a3938f515))

## 0.1.0-alpha.11 (2024-07-08)

Full Changelog: [v0.1.0-alpha.10...v0.1.0-alpha.11](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.10...v0.1.0-alpha.11)

### Features

* **api:** OpenAPI spec update via Stainless API ([#100](https://github.com/scaleapi/sgp-python/issues/100)) ([e37d609](https://github.com/scaleapi/sgp-python/commit/e37d6094328ee4928c6f17ca675a5c581ce6cd2c))
* **api:** OpenAPI spec update via Stainless API ([#101](https://github.com/scaleapi/sgp-python/issues/101)) ([53b1ba5](https://github.com/scaleapi/sgp-python/commit/53b1ba57cf60cb60955516b19e0fa4cf49a94063))
* **api:** OpenAPI spec update via Stainless API ([#102](https://github.com/scaleapi/sgp-python/issues/102)) ([2302cb9](https://github.com/scaleapi/sgp-python/commit/2302cb9868d7d5a06e54f605c5cf458cb51d212a))
* **api:** OpenAPI spec update via Stainless API ([#103](https://github.com/scaleapi/sgp-python/issues/103)) ([019115d](https://github.com/scaleapi/sgp-python/commit/019115d47f36c9e7b9e2587b8978b3449cacbf2e))
* **api:** OpenAPI spec update via Stainless API ([#104](https://github.com/scaleapi/sgp-python/issues/104)) ([b7bf42a](https://github.com/scaleapi/sgp-python/commit/b7bf42a30e78102d9efe47b8da3fa9bc99847a0e))
* **api:** OpenAPI spec update via Stainless API ([#105](https://github.com/scaleapi/sgp-python/issues/105)) ([420f7ea](https://github.com/scaleapi/sgp-python/commit/420f7eac15fceea3cc92cdf8c88a2c1fb9e95cf4))
* **api:** OpenAPI spec update via Stainless API ([#106](https://github.com/scaleapi/sgp-python/issues/106)) ([e672604](https://github.com/scaleapi/sgp-python/commit/e672604772c71ec8ed2cb0f461187aed5a2d0ebe))
* **api:** OpenAPI spec update via Stainless API ([#107](https://github.com/scaleapi/sgp-python/issues/107)) ([7d0a4f0](https://github.com/scaleapi/sgp-python/commit/7d0a4f0e95506ec50ca4ce5bc297003a17550588))
* **api:** OpenAPI spec update via Stainless API ([#108](https://github.com/scaleapi/sgp-python/issues/108)) ([d66fcc7](https://github.com/scaleapi/sgp-python/commit/d66fcc75899a3e05c171ba9a4d48afdf3cd0eb8f))
* **api:** OpenAPI spec update via Stainless API ([#109](https://github.com/scaleapi/sgp-python/issues/109)) ([c8bc9e6](https://github.com/scaleapi/sgp-python/commit/c8bc9e69c83816b29bddbc404d43eacf92d03edc))
* **api:** OpenAPI spec update via Stainless API ([#110](https://github.com/scaleapi/sgp-python/issues/110)) ([23a4c06](https://github.com/scaleapi/sgp-python/commit/23a4c064c297c1b72e686f5d57c1c243610c0e13))
* **api:** OpenAPI spec update via Stainless API ([#111](https://github.com/scaleapi/sgp-python/issues/111)) ([1243551](https://github.com/scaleapi/sgp-python/commit/12435518f036ce6b47af4a069c93b395ff6e77ee))
* **api:** OpenAPI spec update via Stainless API ([#112](https://github.com/scaleapi/sgp-python/issues/112)) ([7e59246](https://github.com/scaleapi/sgp-python/commit/7e592468d80930568acbf7cfa5006601d9d80a2d))
* **api:** OpenAPI spec update via Stainless API ([#113](https://github.com/scaleapi/sgp-python/issues/113)) ([55175df](https://github.com/scaleapi/sgp-python/commit/55175df640098ee336fb4c7261a7a20e4d872fa3))
* **api:** OpenAPI spec update via Stainless API ([#114](https://github.com/scaleapi/sgp-python/issues/114)) ([23e90a7](https://github.com/scaleapi/sgp-python/commit/23e90a72cff8f94cf29d6110f4b44f4c791d271b))
* **api:** OpenAPI spec update via Stainless API ([#115](https://github.com/scaleapi/sgp-python/issues/115)) ([8a991be](https://github.com/scaleapi/sgp-python/commit/8a991be2533397f73b243de3d3c7cce20bc02f6a))
* **api:** OpenAPI spec update via Stainless API ([#116](https://github.com/scaleapi/sgp-python/issues/116)) ([461d4a5](https://github.com/scaleapi/sgp-python/commit/461d4a531d482109738ef5a59318d2fb21263d35))
* **api:** OpenAPI spec update via Stainless API ([#117](https://github.com/scaleapi/sgp-python/issues/117)) ([c588677](https://github.com/scaleapi/sgp-python/commit/c588677329bb85da691b54be13dff8a62083ecaa))
* **api:** OpenAPI spec update via Stainless API ([#118](https://github.com/scaleapi/sgp-python/issues/118)) ([d0da8e8](https://github.com/scaleapi/sgp-python/commit/d0da8e83f206f17de5d4b20dd031e0b9596239e2))
* **api:** OpenAPI spec update via Stainless API ([#119](https://github.com/scaleapi/sgp-python/issues/119)) ([ed1a459](https://github.com/scaleapi/sgp-python/commit/ed1a4592a0c66d0402044427c1bc01ffacb02984))
* **api:** OpenAPI spec update via Stainless API ([#120](https://github.com/scaleapi/sgp-python/issues/120)) ([07618b8](https://github.com/scaleapi/sgp-python/commit/07618b864e356fbe74227afba8dc4295dad74c83))
* **api:** OpenAPI spec update via Stainless API ([#121](https://github.com/scaleapi/sgp-python/issues/121)) ([35f8cd0](https://github.com/scaleapi/sgp-python/commit/35f8cd0e5805409fc6262bab472cac854532b98e))
* **api:** OpenAPI spec update via Stainless API ([#122](https://github.com/scaleapi/sgp-python/issues/122)) ([c6018ea](https://github.com/scaleapi/sgp-python/commit/c6018ea8b355547602a2661fab502d867f06d35a))
* **api:** OpenAPI spec update via Stainless API ([#123](https://github.com/scaleapi/sgp-python/issues/123)) ([f282534](https://github.com/scaleapi/sgp-python/commit/f28253437bab067c2cfbadc9ed96ed442baabde4))
* **api:** OpenAPI spec update via Stainless API ([#124](https://github.com/scaleapi/sgp-python/issues/124)) ([23c29fd](https://github.com/scaleapi/sgp-python/commit/23c29fd99bf3357f076504ac23410fbe371d15f0))
* **api:** OpenAPI spec update via Stainless API ([#125](https://github.com/scaleapi/sgp-python/issues/125)) ([ef1c723](https://github.com/scaleapi/sgp-python/commit/ef1c72340a4970dec91255074a75977227c3c24e))
* **api:** OpenAPI spec update via Stainless API ([#126](https://github.com/scaleapi/sgp-python/issues/126)) ([ddaf56f](https://github.com/scaleapi/sgp-python/commit/ddaf56f17ea5612254bec316ef004fbab10777a4))
* **api:** OpenAPI spec update via Stainless API ([#127](https://github.com/scaleapi/sgp-python/issues/127)) ([04e41ee](https://github.com/scaleapi/sgp-python/commit/04e41ee5fb113b3fc32daba9aa7f54830696cf78))
* **api:** OpenAPI spec update via Stainless API ([#128](https://github.com/scaleapi/sgp-python/issues/128)) ([817c635](https://github.com/scaleapi/sgp-python/commit/817c63574bd172cb2c1610eda51b4c736d788dde))
* **api:** OpenAPI spec update via Stainless API ([#129](https://github.com/scaleapi/sgp-python/issues/129)) ([dede50a](https://github.com/scaleapi/sgp-python/commit/dede50aad21528abf1ab94b1c8cf4b3241da5d44))
* **api:** OpenAPI spec update via Stainless API ([#130](https://github.com/scaleapi/sgp-python/issues/130)) ([b21e2d3](https://github.com/scaleapi/sgp-python/commit/b21e2d3e542f1329e58ba9cfe0220d607d7e6223))
* **api:** OpenAPI spec update via Stainless API ([#131](https://github.com/scaleapi/sgp-python/issues/131)) ([1b87369](https://github.com/scaleapi/sgp-python/commit/1b873699a14f7e5ab216bc4efad05b99de121665))
* **api:** OpenAPI spec update via Stainless API ([#132](https://github.com/scaleapi/sgp-python/issues/132)) ([4526b4b](https://github.com/scaleapi/sgp-python/commit/4526b4b2b4c0d92ff07346ff3027306288d02017))
* **api:** OpenAPI spec update via Stainless API ([#133](https://github.com/scaleapi/sgp-python/issues/133)) ([9dcaeb7](https://github.com/scaleapi/sgp-python/commit/9dcaeb75f98a2cc4c9c54f7870352e0bf2dd05fe))
* **api:** OpenAPI spec update via Stainless API ([#134](https://github.com/scaleapi/sgp-python/issues/134)) ([db4c89c](https://github.com/scaleapi/sgp-python/commit/db4c89c70077b2b9a404cfeac321ada94a7c84cb))
* **api:** OpenAPI spec update via Stainless API ([#135](https://github.com/scaleapi/sgp-python/issues/135)) ([5a61cac](https://github.com/scaleapi/sgp-python/commit/5a61cac6c5464333292c4ad2ce9e0e20654d3da7))
* **api:** OpenAPI spec update via Stainless API ([#136](https://github.com/scaleapi/sgp-python/issues/136)) ([eaaf6af](https://github.com/scaleapi/sgp-python/commit/eaaf6aff766e8ed47db1951a7d2d21cf775f0ca9))
* **api:** OpenAPI spec update via Stainless API ([#137](https://github.com/scaleapi/sgp-python/issues/137)) ([c959596](https://github.com/scaleapi/sgp-python/commit/c959596e4e75cebc7757c3c958c32a9feb6b6cab))
* **api:** OpenAPI spec update via Stainless API ([#138](https://github.com/scaleapi/sgp-python/issues/138)) ([c3d2d90](https://github.com/scaleapi/sgp-python/commit/c3d2d90d4dad87fe4ac12d1ee3fa97976d0ceb4e))
* **api:** OpenAPI spec update via Stainless API ([#139](https://github.com/scaleapi/sgp-python/issues/139)) ([7521368](https://github.com/scaleapi/sgp-python/commit/75213681655d481bfe13248e16ecf9547391b9b4))
* **api:** OpenAPI spec update via Stainless API ([#140](https://github.com/scaleapi/sgp-python/issues/140)) ([299f800](https://github.com/scaleapi/sgp-python/commit/299f800968b2afca7a4406527c5ee04e8ec6fc83))
* **api:** OpenAPI spec update via Stainless API ([#141](https://github.com/scaleapi/sgp-python/issues/141)) ([2e4817e](https://github.com/scaleapi/sgp-python/commit/2e4817ea433831b0f04fe74fa93f952a1b714172))
* **api:** OpenAPI spec update via Stainless API ([#142](https://github.com/scaleapi/sgp-python/issues/142)) ([b1979ec](https://github.com/scaleapi/sgp-python/commit/b1979ec8860661b1dabb9f2d00216da031fdf4da))
* **api:** OpenAPI spec update via Stainless API ([#143](https://github.com/scaleapi/sgp-python/issues/143)) ([9a759d8](https://github.com/scaleapi/sgp-python/commit/9a759d8b6e30c0cf5a0c61d49da5ff5004c3b3a4))
* **api:** OpenAPI spec update via Stainless API ([#144](https://github.com/scaleapi/sgp-python/issues/144)) ([2ea3de8](https://github.com/scaleapi/sgp-python/commit/2ea3de85e5d768d4ddc91339c003e3feade56cbe))
* **api:** OpenAPI spec update via Stainless API ([#145](https://github.com/scaleapi/sgp-python/issues/145)) ([c032f60](https://github.com/scaleapi/sgp-python/commit/c032f60ac1d020661a39357ca00393ae5195a9fe))
* **api:** OpenAPI spec update via Stainless API ([#146](https://github.com/scaleapi/sgp-python/issues/146)) ([0e81994](https://github.com/scaleapi/sgp-python/commit/0e819942c132f9f7bc2001919b3a4ccfe986f9d0))
* **api:** OpenAPI spec update via Stainless API ([#147](https://github.com/scaleapi/sgp-python/issues/147)) ([eaa44eb](https://github.com/scaleapi/sgp-python/commit/eaa44eb53e4d5ba519d804ded8f1ace2ccfe3de9))
* **api:** OpenAPI spec update via Stainless API ([#148](https://github.com/scaleapi/sgp-python/issues/148)) ([0225eed](https://github.com/scaleapi/sgp-python/commit/0225eed47dacf99385fb6001826838daca0d86d1))
* **api:** OpenAPI spec update via Stainless API ([#47](https://github.com/scaleapi/sgp-python/issues/47)) ([24c8c0a](https://github.com/scaleapi/sgp-python/commit/24c8c0acf5563b7e2984fffdefeca024879d3b31))
* **api:** OpenAPI spec update via Stainless API ([#49](https://github.com/scaleapi/sgp-python/issues/49)) ([992a84d](https://github.com/scaleapi/sgp-python/commit/992a84dfb181a86ea10e9e979bc5205398c86f2f))
* **api:** OpenAPI spec update via Stainless API ([#50](https://github.com/scaleapi/sgp-python/issues/50)) ([9e5e034](https://github.com/scaleapi/sgp-python/commit/9e5e0343994a60210df4a44e72012c34b3e474be))
* **api:** OpenAPI spec update via Stainless API ([#51](https://github.com/scaleapi/sgp-python/issues/51)) ([928cc2d](https://github.com/scaleapi/sgp-python/commit/928cc2dd3ffb1b9f78e3d4662715a22917147191))
* **api:** OpenAPI spec update via Stainless API ([#52](https://github.com/scaleapi/sgp-python/issues/52)) ([1e45744](https://github.com/scaleapi/sgp-python/commit/1e45744ef3bf15ff69bb2b2718f4ba5fa9df3179))
* **api:** OpenAPI spec update via Stainless API ([#53](https://github.com/scaleapi/sgp-python/issues/53)) ([b9f915a](https://github.com/scaleapi/sgp-python/commit/b9f915ad1d531532e9a2c3f1ecd6518595c9c4ba))
* **api:** OpenAPI spec update via Stainless API ([#54](https://github.com/scaleapi/sgp-python/issues/54)) ([c1f42be](https://github.com/scaleapi/sgp-python/commit/c1f42be1588e793178e7ca4b77541f7a8a688079))
* **api:** OpenAPI spec update via Stainless API ([#55](https://github.com/scaleapi/sgp-python/issues/55)) ([ffac552](https://github.com/scaleapi/sgp-python/commit/ffac5529ec4bb86a206b137da3238659bcbfdb9a))
* **api:** OpenAPI spec update via Stainless API ([#56](https://github.com/scaleapi/sgp-python/issues/56)) ([174e0a8](https://github.com/scaleapi/sgp-python/commit/174e0a88e12c21a35648b1590acbc2b1cac96d9f))
* **api:** OpenAPI spec update via Stainless API ([#57](https://github.com/scaleapi/sgp-python/issues/57)) ([72e1f19](https://github.com/scaleapi/sgp-python/commit/72e1f193248383172f33d29bd4212358bb66f6ad))
* **api:** OpenAPI spec update via Stainless API ([#58](https://github.com/scaleapi/sgp-python/issues/58)) ([85ffd1d](https://github.com/scaleapi/sgp-python/commit/85ffd1dd4c5fb13cfa51f5f0728af1b4bbd89813))
* **api:** OpenAPI spec update via Stainless API ([#59](https://github.com/scaleapi/sgp-python/issues/59)) ([90c8e58](https://github.com/scaleapi/sgp-python/commit/90c8e58575485ae768fda39c3ecdfb0ded1f08b6))
* **api:** OpenAPI spec update via Stainless API ([#60](https://github.com/scaleapi/sgp-python/issues/60)) ([d9e00d3](https://github.com/scaleapi/sgp-python/commit/d9e00d33da7d737917822585b7a205adc772b3aa))
* **api:** OpenAPI spec update via Stainless API ([#61](https://github.com/scaleapi/sgp-python/issues/61)) ([b0f3657](https://github.com/scaleapi/sgp-python/commit/b0f3657341ba41fb90646ebc8014b228da5d4472))
* **api:** OpenAPI spec update via Stainless API ([#62](https://github.com/scaleapi/sgp-python/issues/62)) ([de9ab65](https://github.com/scaleapi/sgp-python/commit/de9ab6597309661678b350d67fbd112eb5483830))
* **api:** OpenAPI spec update via Stainless API ([#63](https://github.com/scaleapi/sgp-python/issues/63)) ([9bdbb9f](https://github.com/scaleapi/sgp-python/commit/9bdbb9f63fc3daadd0cc4596b0a4f8b51d66252f))
* **api:** OpenAPI spec update via Stainless API ([#64](https://github.com/scaleapi/sgp-python/issues/64)) ([fde2b21](https://github.com/scaleapi/sgp-python/commit/fde2b21f27c9358cad364bda39e9e6539898f28f))
* **api:** OpenAPI spec update via Stainless API ([#65](https://github.com/scaleapi/sgp-python/issues/65)) ([c820b54](https://github.com/scaleapi/sgp-python/commit/c820b545124481efccb0fb27b0c5635d2c005aed))
* **api:** OpenAPI spec update via Stainless API ([#66](https://github.com/scaleapi/sgp-python/issues/66)) ([b07b45b](https://github.com/scaleapi/sgp-python/commit/b07b45bcf38ff30a95a6c53f7732a18cf3f33e43))
* **api:** OpenAPI spec update via Stainless API ([#67](https://github.com/scaleapi/sgp-python/issues/67)) ([5968f3f](https://github.com/scaleapi/sgp-python/commit/5968f3ffea31a9f0667e77cc88f21892131fa1bd))
* **api:** OpenAPI spec update via Stainless API ([#68](https://github.com/scaleapi/sgp-python/issues/68)) ([a1d946e](https://github.com/scaleapi/sgp-python/commit/a1d946ea48a0ba30ab90a3be4ce99e040de2c593))
* **api:** OpenAPI spec update via Stainless API ([#69](https://github.com/scaleapi/sgp-python/issues/69)) ([9745911](https://github.com/scaleapi/sgp-python/commit/97459114100a9ff153fb97a645ebe324e9928a5b))
* **api:** OpenAPI spec update via Stainless API ([#70](https://github.com/scaleapi/sgp-python/issues/70)) ([8be54d7](https://github.com/scaleapi/sgp-python/commit/8be54d7cd534c9c01ffa9c246a75851b01065268))
* **api:** OpenAPI spec update via Stainless API ([#71](https://github.com/scaleapi/sgp-python/issues/71)) ([102380b](https://github.com/scaleapi/sgp-python/commit/102380b5f3bb0f09b725a4cf698f2f255fe2e6d7))
* **api:** OpenAPI spec update via Stainless API ([#72](https://github.com/scaleapi/sgp-python/issues/72)) ([7a22df4](https://github.com/scaleapi/sgp-python/commit/7a22df442d135c7af6a8c9ec94198c5026bcc2d3))
* **api:** OpenAPI spec update via Stainless API ([#73](https://github.com/scaleapi/sgp-python/issues/73)) ([e589d76](https://github.com/scaleapi/sgp-python/commit/e589d762a94018ea93a132628c8be7248e261980))
* **api:** OpenAPI spec update via Stainless API ([#74](https://github.com/scaleapi/sgp-python/issues/74)) ([70c56ed](https://github.com/scaleapi/sgp-python/commit/70c56edbde19f83d3b14d7fc3234630effa9f8be))
* **api:** OpenAPI spec update via Stainless API ([#75](https://github.com/scaleapi/sgp-python/issues/75)) ([0c1f855](https://github.com/scaleapi/sgp-python/commit/0c1f855cda264cfeb55958ed5b2e746b5e24ba6d))
* **api:** OpenAPI spec update via Stainless API ([#76](https://github.com/scaleapi/sgp-python/issues/76)) ([2513122](https://github.com/scaleapi/sgp-python/commit/25131220d817bcfc451806beaff1b45a2a66ad1e))
* **api:** OpenAPI spec update via Stainless API ([#77](https://github.com/scaleapi/sgp-python/issues/77)) ([282ded5](https://github.com/scaleapi/sgp-python/commit/282ded5690dd74a49157a321923ba90ef4fcdf83))
* **api:** OpenAPI spec update via Stainless API ([#78](https://github.com/scaleapi/sgp-python/issues/78)) ([79b82ec](https://github.com/scaleapi/sgp-python/commit/79b82ecd981191c21b52593f45e59421d56e13b7))
* **api:** OpenAPI spec update via Stainless API ([#79](https://github.com/scaleapi/sgp-python/issues/79)) ([695494a](https://github.com/scaleapi/sgp-python/commit/695494af58fe8fbcb200963aaf6ffbc218aafbd6))
* **api:** OpenAPI spec update via Stainless API ([#80](https://github.com/scaleapi/sgp-python/issues/80)) ([344a211](https://github.com/scaleapi/sgp-python/commit/344a21108ffaba60d45ad8b5a85c2ba52a803e38))
* **api:** OpenAPI spec update via Stainless API ([#81](https://github.com/scaleapi/sgp-python/issues/81)) ([c51cc7f](https://github.com/scaleapi/sgp-python/commit/c51cc7fdc14e58e49cbba8e4b1b35ac2b8178a02))
* **api:** OpenAPI spec update via Stainless API ([#82](https://github.com/scaleapi/sgp-python/issues/82)) ([d107298](https://github.com/scaleapi/sgp-python/commit/d10729868c629a43fe4400460a109e22b6c6f621))
* **api:** OpenAPI spec update via Stainless API ([#83](https://github.com/scaleapi/sgp-python/issues/83)) ([342c085](https://github.com/scaleapi/sgp-python/commit/342c0858bf8cf59055560dba25c0f9fb50266c95))
* **api:** OpenAPI spec update via Stainless API ([#84](https://github.com/scaleapi/sgp-python/issues/84)) ([44eaa34](https://github.com/scaleapi/sgp-python/commit/44eaa34016cb870cfdf43b7125c142aa8e4ee261))
* **api:** OpenAPI spec update via Stainless API ([#85](https://github.com/scaleapi/sgp-python/issues/85)) ([44be44f](https://github.com/scaleapi/sgp-python/commit/44be44f00dc9f61ce103037365dc750c1a6d992a))
* **api:** OpenAPI spec update via Stainless API ([#86](https://github.com/scaleapi/sgp-python/issues/86)) ([889e6c7](https://github.com/scaleapi/sgp-python/commit/889e6c7368556f389ac0025db283464da53aef54))
* **api:** OpenAPI spec update via Stainless API ([#87](https://github.com/scaleapi/sgp-python/issues/87)) ([5b4d98f](https://github.com/scaleapi/sgp-python/commit/5b4d98fe45db66a54a5eabe051e5e5d6cd457a64))
* **api:** OpenAPI spec update via Stainless API ([#88](https://github.com/scaleapi/sgp-python/issues/88)) ([40bad8a](https://github.com/scaleapi/sgp-python/commit/40bad8a97882cfa9acb4b8d57f99262e65643927))
* **api:** OpenAPI spec update via Stainless API ([#89](https://github.com/scaleapi/sgp-python/issues/89)) ([3a521a3](https://github.com/scaleapi/sgp-python/commit/3a521a3ac8c62a0294eff96fb54a432773d2c867))
* **api:** OpenAPI spec update via Stainless API ([#90](https://github.com/scaleapi/sgp-python/issues/90)) ([5edfae2](https://github.com/scaleapi/sgp-python/commit/5edfae25c23093f468e5b1367bae378a47b38afd))
* **api:** OpenAPI spec update via Stainless API ([#91](https://github.com/scaleapi/sgp-python/issues/91)) ([f8ea605](https://github.com/scaleapi/sgp-python/commit/f8ea605dfa2c464ba63ac886bce63816e1e4bf7b))
* **api:** OpenAPI spec update via Stainless API ([#92](https://github.com/scaleapi/sgp-python/issues/92)) ([d787edf](https://github.com/scaleapi/sgp-python/commit/d787edfb5d5b6b59d57a604ca5fd5a0461d9bebb))
* **api:** OpenAPI spec update via Stainless API ([#93](https://github.com/scaleapi/sgp-python/issues/93)) ([ad127aa](https://github.com/scaleapi/sgp-python/commit/ad127aa194c89f86eff2155514f21ce096eb45e6))
* **api:** OpenAPI spec update via Stainless API ([#94](https://github.com/scaleapi/sgp-python/issues/94)) ([4295086](https://github.com/scaleapi/sgp-python/commit/42950863231e30d06c7b7ea515c45ab94c08286c))
* **api:** OpenAPI spec update via Stainless API ([#95](https://github.com/scaleapi/sgp-python/issues/95)) ([2c8ae14](https://github.com/scaleapi/sgp-python/commit/2c8ae146ecf3de59109ca5cecb3b95ad100264f5))
* **api:** OpenAPI spec update via Stainless API ([#96](https://github.com/scaleapi/sgp-python/issues/96)) ([c8e21e2](https://github.com/scaleapi/sgp-python/commit/c8e21e2d2e6a73c57fd9e100ea029c11d2e2a51a))
* **api:** OpenAPI spec update via Stainless API ([#97](https://github.com/scaleapi/sgp-python/issues/97)) ([af79299](https://github.com/scaleapi/sgp-python/commit/af792995d040fd8241badf927c885806b0e632e3))
* **api:** OpenAPI spec update via Stainless API ([#98](https://github.com/scaleapi/sgp-python/issues/98)) ([f51e184](https://github.com/scaleapi/sgp-python/commit/f51e184419be85bfe27488c917f0035522004a0d))
* **api:** OpenAPI spec update via Stainless API ([#99](https://github.com/scaleapi/sgp-python/issues/99)) ([e6de68a](https://github.com/scaleapi/sgp-python/commit/e6de68a0bb6a65d3eb8b7f8134f6b58752c4655f))
* **api:** update via SDK Studio ([#150](https://github.com/scaleapi/sgp-python/issues/150)) ([6c6b9b3](https://github.com/scaleapi/sgp-python/commit/6c6b9b3bdfae4819d199f67a2843ff898b3b47d9))
* **api:** update via SDK Studio ([#152](https://github.com/scaleapi/sgp-python/issues/152)) ([1726070](https://github.com/scaleapi/sgp-python/commit/1726070f0e12ded68c04ff4ef0dbede2d23c6c44))
* **api:** update via SDK Studio ([#45](https://github.com/scaleapi/sgp-python/issues/45)) ([ef9d310](https://github.com/scaleapi/sgp-python/commit/ef9d3102600ca2c6476fbca4ee5565256e5f0cba))
* **api:** update via SDK Studio ([#48](https://github.com/scaleapi/sgp-python/issues/48)) ([33befc4](https://github.com/scaleapi/sgp-python/commit/33befc4c3480d6aabd906f1333748067970f7005))


### Chores

* update SDK settings ([#149](https://github.com/scaleapi/sgp-python/issues/149)) ([6149769](https://github.com/scaleapi/sgp-python/commit/61497699c4b68deb7df8bdfe0a4c4c6ec0b69c8d))
* update SDK settings ([#151](https://github.com/scaleapi/sgp-python/issues/151)) ([a85e6c2](https://github.com/scaleapi/sgp-python/commit/a85e6c2f5eb4431850b5d7d109eec37ee856352b))

## 0.1.0-alpha.10 (2024-07-04)

Full Changelog: [v0.1.0-alpha.9...v0.1.0-alpha.10](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.9...v0.1.0-alpha.10)

### Features

* **api:** update via SDK Studio ([#42](https://github.com/scaleapi/sgp-python/issues/42)) ([7e14c94](https://github.com/scaleapi/sgp-python/commit/7e14c940c17718ee8cbe02ba6d121e3448a46182))

## 0.1.0-alpha.9 (2024-07-04)

Full Changelog: [v0.1.0-alpha.8...v0.1.0-alpha.9](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.8...v0.1.0-alpha.9)

### Features

* **api:** OpenAPI spec update via Stainless API ([#36](https://github.com/scaleapi/sgp-python/issues/36)) ([45332c3](https://github.com/scaleapi/sgp-python/commit/45332c39e3e4d7bda5a8ea287b9f0f69a34c8dd8))
* **api:** OpenAPI spec update via Stainless API ([#38](https://github.com/scaleapi/sgp-python/issues/38)) ([76518e2](https://github.com/scaleapi/sgp-python/commit/76518e2b1a22dae34a2be95bc1cd04f66006d854))
* **api:** OpenAPI spec update via Stainless API ([#39](https://github.com/scaleapi/sgp-python/issues/39)) ([ac546db](https://github.com/scaleapi/sgp-python/commit/ac546db2650e39ff15a6b11263b68b1fbfe463d4))
* **api:** OpenAPI spec update via Stainless API ([#40](https://github.com/scaleapi/sgp-python/issues/40)) ([e5029ce](https://github.com/scaleapi/sgp-python/commit/e5029ce1407c725df2265c343358ac96673ff48a))
* **api:** update via SDK Studio ([#41](https://github.com/scaleapi/sgp-python/issues/41)) ([eac3b5d](https://github.com/scaleapi/sgp-python/commit/eac3b5d0b6665889cbb32c6b3443005242febd26))

## 0.1.0-alpha.8 (2024-07-04)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* **api:** OpenAPI spec update via Stainless API ([#35](https://github.com/scaleapi/sgp-python/issues/35)) ([896b81b](https://github.com/scaleapi/sgp-python/commit/896b81b2ee4b356a904585dc26e87aca0e15a227))
* **api:** update via SDK Studio ([#32](https://github.com/scaleapi/sgp-python/issues/32)) ([e47fae1](https://github.com/scaleapi/sgp-python/commit/e47fae100e30c40c85187eb1fbd1dd99a380ae64))

## 0.1.0-alpha.7 (2024-07-04)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** update via SDK Studio ([#29](https://github.com/scaleapi/sgp-python/issues/29)) ([7adfb76](https://github.com/scaleapi/sgp-python/commit/7adfb76e9c28ac9d33a4c6603026e0b086bb731c))

## 0.1.0-alpha.6 (2024-07-04)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** update via SDK Studio ([#24](https://github.com/scaleapi/sgp-python/issues/24)) ([fead088](https://github.com/scaleapi/sgp-python/commit/fead0884a8ebbea6ca645152452c8e4960b30044))
* **api:** update via SDK Studio ([#26](https://github.com/scaleapi/sgp-python/issues/26)) ([a3b72ee](https://github.com/scaleapi/sgp-python/commit/a3b72ee35698610b5adfa4c4be881a7eed728a56))

## 0.1.0-alpha.5 (2024-07-04)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/scaleapi/sgp-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** OpenAPI spec update via Stainless API ([#15](https://github.com/scaleapi/sgp-python/issues/15)) ([7a8b443](https://github.com/scaleapi/sgp-python/commit/7a8b44379fa71c1d400bda091fb98604629011f4))
* **api:** OpenAPI spec update via Stainless API ([#21](https://github.com/scaleapi/sgp-python/issues/21)) ([ca3cc4c](https://github.com/scaleapi/sgp-python/commit/ca3cc4c1da20e2197b30d846fab8e289cac064bc))
* **api:** OpenAPI spec update via Stainless API ([#8](https://github.com/scaleapi/sgp-python/issues/8)) ([a8fc3ed](https://github.com/scaleapi/sgp-python/commit/a8fc3ed5374b6ee8bb49bc88a9d2aecad2f19cfe))
* **api:** update via SDK Studio ([#10](https://github.com/scaleapi/sgp-python/issues/10)) ([4f64dca](https://github.com/scaleapi/sgp-python/commit/4f64dcad327bd2bb90775eb94a42888133f77b7b))
* **api:** update via SDK Studio ([#19](https://github.com/scaleapi/sgp-python/issues/19)) ([995d21b](https://github.com/scaleapi/sgp-python/commit/995d21b024c46b082846fc10338b79c7ce51b4d7))
* **api:** update via SDK Studio ([#23](https://github.com/scaleapi/sgp-python/issues/23)) ([afff419](https://github.com/scaleapi/sgp-python/commit/afff419283ae1f34caa2b2628e337d89e6d4fbec))
* **api:** update via SDK Studio ([#3](https://github.com/scaleapi/sgp-python/issues/3)) ([bc1f81c](https://github.com/scaleapi/sgp-python/commit/bc1f81c8da42dfb322b8dff9426aa8d1fc30dc32))
* **api:** update via SDK Studio ([#5](https://github.com/scaleapi/sgp-python/issues/5)) ([790c9a9](https://github.com/scaleapi/sgp-python/commit/790c9a906eba5efc092cc947b70e477db8c37de7))
* **api:** update via SDK Studio ([#6](https://github.com/scaleapi/sgp-python/issues/6)) ([9c67646](https://github.com/scaleapi/sgp-python/commit/9c67646eadb1c965495c846930ac8d34c15ceaae))


### Chores

* go live ([#1](https://github.com/scaleapi/sgp-python/issues/1)) ([df038fd](https://github.com/scaleapi/sgp-python/commit/df038fdb21d0ccd3ee2bc59926c2a781817dd129))
* update SDK settings ([#11](https://github.com/scaleapi/sgp-python/issues/11)) ([2623d94](https://github.com/scaleapi/sgp-python/commit/2623d94f585d8fdf8cbcb7f9b9c20664d7b50fa4))
* update SDK settings ([#13](https://github.com/scaleapi/sgp-python/issues/13)) ([6038356](https://github.com/scaleapi/sgp-python/commit/6038356b7bb203e2444109ddb503c3c4dd903dd9))
* update SDK settings ([#14](https://github.com/scaleapi/sgp-python/issues/14)) ([f1c911d](https://github.com/scaleapi/sgp-python/commit/f1c911d17568fac7c4d18008434900fb1c5b3b89))

## 0.1.0-alpha.1 (2024-06-24)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/anishxyz/sgp-py/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** OpenAPI spec update via Stainless API ([e455087](https://github.com/anishxyz/sgp-py/commit/e455087db23b8a6f51a13c3f1fc9e8c4f30a694c))
* **api:** OpenAPI spec update via Stainless API ([f4cca17](https://github.com/anishxyz/sgp-py/commit/f4cca17e9e7bc377b3bc77f0e31e8534a5a6ef8b))
* **api:** OpenAPI spec update via Stainless API ([#6](https://github.com/anishxyz/sgp-py/issues/6)) ([99d679c](https://github.com/anishxyz/sgp-py/commit/99d679cc7272ee03b5cef428679c505f79c4f371))
* **api:** OpenAPI spec update via Stainless API ([#7](https://github.com/anishxyz/sgp-py/issues/7)) ([017b664](https://github.com/anishxyz/sgp-py/commit/017b664d764ad12038efaff14582e86d555ad9fc))
* **api:** OpenAPI spec update via Stainless API ([#8](https://github.com/anishxyz/sgp-py/issues/8)) ([950da62](https://github.com/anishxyz/sgp-py/commit/950da629e44c9a6a874bcd7cefd657e77e1b6411))
* **api:** update via SDK Studio ([ccb64a8](https://github.com/anishxyz/sgp-py/commit/ccb64a8ecf1117cf243f1ec2e335788c6ea03816))


### Chores

* configure new SDK language ([0baa18f](https://github.com/anishxyz/sgp-py/commit/0baa18fae3ba9744c6e6b63a4d2a4d735b71dfde))
* go live ([#4](https://github.com/anishxyz/sgp-py/issues/4)) ([52c2be6](https://github.com/anishxyz/sgp-py/commit/52c2be63fe9a683e8a7f0194dade56cb3ccbbfe9))
* update SDK settings ([498519e](https://github.com/anishxyz/sgp-py/commit/498519e96388cf2318320a6ba9e2dc65136c39a2))
